//
// Copyright (c) 1997, 2012, Oracle and/or its affiliates. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_x86_32.hpp"
#include "adfiles/ad_x86_32.hpp"
#include "memory/allocation.inline.hpp"
#include "asm/assembler.hpp"
#include "code/vmreg.hpp"
#include "gc_interface/collectedHeap.inline.hpp"
#include "oops/compiledICHolderOop.hpp"
#include "oops/markOop.hpp"
#include "oops/methodOop.hpp"
#include "oops/oop.inline.hpp"
#include "oops/oop.inline2.hpp"
#include "opto/cfgnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/biasedLocking.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "assembler_x86.inline.hpp"
#include "nativeInst_x86.hpp"
#include "vmreg_x86.inline.hpp"

//SourceForm

#line 243 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

#define   RELOC_IMM32    Assembler::imm_operand
#define   RELOC_DISP32   Assembler::disp32_operand

#define __ _masm.

// How to find the high register of a Long pair, given the low register
#define   HIGH_FROM_LOW(x) ((x)+2)

// These masks are used to provide 128-bit aligned bitmasks to the XMM
// instructions, to allow sign-masking or sign-bit flipping.  They allow
// fast versions of NegF/NegD and AbsF/AbsD.

// Note: 'double' and 'long long' have 32-bits alignment on x86.
static jlong* double_quadword(jlong *adr, jlong lo, jlong hi) {
  // Use the expression (adr)&(~0xF) to provide 128-bits aligned address
  // of 128-bits operands for SSE instructions.
  jlong *operand = (jlong*)(((uintptr_t)adr)&((uintptr_t)(~0xF)));
  // Store the value to a 128-bits operand.
  operand[0] = lo;
  operand[1] = hi;
  return operand;
}

// Buffer for 128-bits masks used by SSE instructions.
static jlong fp_signmask_pool[(4+1)*2]; // 4*128bits(data) + 128bits(alignment)

// Static initialization during VM startup.
static jlong *float_signmask_pool  = double_quadword(&fp_signmask_pool[1*2], CONST64(0x7FFFFFFF7FFFFFFF), CONST64(0x7FFFFFFF7FFFFFFF));
static jlong *double_signmask_pool = double_quadword(&fp_signmask_pool[2*2], CONST64(0x7FFFFFFFFFFFFFFF), CONST64(0x7FFFFFFFFFFFFFFF));
static jlong *float_signflip_pool  = double_quadword(&fp_signmask_pool[3*2], CONST64(0x8000000080000000), CONST64(0x8000000080000000));
static jlong *double_signflip_pool = double_quadword(&fp_signmask_pool[4*2], CONST64(0x8000000000000000), CONST64(0x8000000000000000));

// Offset hacking within calls.
static int pre_call_FPU_size() {
  if (Compile::current()->in_24_bit_fp_mode())
    return 6; // fldcw
  return 0;
}

static int preserve_SP_size() {
  return 2;  // op, rm(reg/reg)
}

// !!!!! Special hack to get all type of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.
int MachCallStaticJavaNode::ret_addr_offset() {
  int offset = 5 + pre_call_FPU_size();  // 5 bytes from start of call to where return address points
  if (_method_handle_invoke)
    offset += preserve_SP_size();
  return offset;
}

int MachCallDynamicJavaNode::ret_addr_offset() {
  return 10 + pre_call_FPU_size();  // 10 bytes from start of call to where return address points
}

static int sizeof_FFree_Float_Stack_All = -1;

int MachCallRuntimeNode::ret_addr_offset() {
  assert(sizeof_FFree_Float_Stack_All != -1, "must have been emitted already");
  return sizeof_FFree_Float_Stack_All + 5 + pre_call_FPU_size();
}

// Indicate if the safepoint node needs the polling page as an input.
// Since x86 does have absolute addressing, it doesn't.
bool SafePointNode::needs_polling_address_input() {
  return false;
}

//
// Compute padding required for nodes which need alignment
//

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallStaticJavaDirectNode::compute_padding(int current_offset) const {
  current_offset += pre_call_FPU_size();  // skip fldcw, if any
  current_offset += 1;      // skip call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallStaticJavaHandleNode::compute_padding(int current_offset) const {
  current_offset += pre_call_FPU_size();  // skip fldcw, if any
  current_offset += preserve_SP_size();   // skip mov rbp, rsp
  current_offset += 1;      // skip call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// The address of the call instruction needs to be 4-byte aligned to
// ensure that it does not span a cache line so that it can be patched.
int CallDynamicJavaDirectNode::compute_padding(int current_offset) const {
  current_offset += pre_call_FPU_size();  // skip fldcw, if any
  current_offset += 5;      // skip MOV instruction
  current_offset += 1;      // skip call opcode byte
  return round_to(current_offset, alignment_required()) - current_offset;
}

// EMIT_RM()
void emit_rm(CodeBuffer &cbuf, int f1, int f2, int f3) {
  unsigned char c = (unsigned char)((f1 << 6) | (f2 << 3) | f3);
  cbuf.insts()->emit_int8(c);
}

// EMIT_CC()
void emit_cc(CodeBuffer &cbuf, int f1, int f2) {
  unsigned char c = (unsigned char)( f1 | f2 );
  cbuf.insts()->emit_int8(c);
}

// EMIT_OPCODE()
void emit_opcode(CodeBuffer &cbuf, int code) {
  cbuf.insts()->emit_int8((unsigned char) code);
}

// EMIT_OPCODE() w/ relocation information
void emit_opcode(CodeBuffer &cbuf, int code, relocInfo::relocType reloc, int offset = 0) {
  cbuf.relocate(cbuf.insts_mark() + offset, reloc);
  emit_opcode(cbuf, code);
}

// EMIT_D8()
void emit_d8(CodeBuffer &cbuf, int d8) {
  cbuf.insts()->emit_int8((unsigned char) d8);
}

// EMIT_D16()
void emit_d16(CodeBuffer &cbuf, int d16) {
  cbuf.insts()->emit_int16(d16);
}

// EMIT_D32()
void emit_d32(CodeBuffer &cbuf, int d32) {
  cbuf.insts()->emit_int32(d32);
}

// emit 32 bit value and construct relocation entry from relocInfo::relocType
void emit_d32_reloc(CodeBuffer &cbuf, int d32, relocInfo::relocType reloc,
        int format) {
  cbuf.relocate(cbuf.insts_mark(), reloc, format);
  cbuf.insts()->emit_int32(d32);
}

// emit 32 bit value and construct relocation entry from RelocationHolder
void emit_d32_reloc(CodeBuffer &cbuf, int d32, RelocationHolder const& rspec,
        int format) {
#ifdef ASSERT
  if (rspec.reloc()->type() == relocInfo::oop_type && d32 != 0 && d32 != (int)Universe::non_oop_word()) {
    assert(oop(d32)->is_oop() && (ScavengeRootsInCode || !oop(d32)->is_scavengable()), "cannot embed scavengable oops in code");
  }
#endif
  cbuf.relocate(cbuf.insts_mark(), rspec, format);
  cbuf.insts()->emit_int32(d32);
}

// Access stack slot for load or store
void store_to_stackslot(CodeBuffer &cbuf, int opcode, int rm_field, int disp) {
  emit_opcode( cbuf, opcode );               // (e.g., FILD   [ESP+src])
  if( -128 <= disp && disp <= 127 ) {
    emit_rm( cbuf, 0x01, rm_field, ESP_enc );  // R/M byte
    emit_rm( cbuf, 0x00, ESP_enc, ESP_enc);    // SIB byte
    emit_d8 (cbuf, disp);     // Displacement  // R/M byte
  } else {
    emit_rm( cbuf, 0x02, rm_field, ESP_enc );  // R/M byte
    emit_rm( cbuf, 0x00, ESP_enc, ESP_enc);    // SIB byte
    emit_d32(cbuf, disp);     // Displacement  // R/M byte
  }
}

   // eRegI ereg, memory mem) %{    // emit_reg_mem
void encode_RegMem( CodeBuffer &cbuf, int reg_encoding, int base, int index, int scale, int displace, bool displace_is_oop ) {
  // There is no index & no scale, use form without SIB byte
  if ((index == 0x4) &&
      (scale == 0) && (base != ESP_enc)) {
    // If no displacement, mode is 0x0; unless base is [EBP]
    if ( (displace == 0) && (base != EBP_enc) ) {
      emit_rm(cbuf, 0x0, reg_encoding, base);
    }
    else {                    // If 8-bit displacement, mode 0x1
      if ((displace >= -128) && (displace <= 127)
          && !(displace_is_oop) ) {
        emit_rm(cbuf, 0x1, reg_encoding, base);
        emit_d8(cbuf, displace);
      }
      else {                  // If 32-bit displacement
        if (base == -1) { // Special flag for absolute address
          emit_rm(cbuf, 0x0, reg_encoding, 0x5);
          // (manual lies; no SIB needed here)
          if ( displace_is_oop ) {
            emit_d32_reloc(cbuf, displace, relocInfo::oop_type, 1);
          } else {
            emit_d32      (cbuf, displace);
          }
        }
        else {                // Normal base + offset
          emit_rm(cbuf, 0x2, reg_encoding, base);
          if ( displace_is_oop ) {
            emit_d32_reloc(cbuf, displace, relocInfo::oop_type, 1);
          } else {
            emit_d32      (cbuf, displace);
          }
        }
      }
    }
  }
  else {                      // Else, encode with the SIB byte
    // If no displacement, mode is 0x0; unless base is [EBP]
    if (displace == 0 && (base != EBP_enc)) {  // If no displacement
      emit_rm(cbuf, 0x0, reg_encoding, 0x4);
      emit_rm(cbuf, scale, index, base);
    }
    else {                    // If 8-bit displacement, mode 0x1
      if ((displace >= -128) && (displace <= 127)
          && !(displace_is_oop) ) {
        emit_rm(cbuf, 0x1, reg_encoding, 0x4);
        emit_rm(cbuf, scale, index, base);
        emit_d8(cbuf, displace);
      }
      else {                  // If 32-bit displacement
        if (base == 0x04 ) {
          emit_rm(cbuf, 0x2, reg_encoding, 0x4);
          emit_rm(cbuf, scale, index, 0x04);
        } else {
          emit_rm(cbuf, 0x2, reg_encoding, 0x4);
          emit_rm(cbuf, scale, index, base);
        }
        if ( displace_is_oop ) {
          emit_d32_reloc(cbuf, displace, relocInfo::oop_type, 1);
        } else {
          emit_d32      (cbuf, displace);
        }
      }
    }
  }
}


void encode_Copy( CodeBuffer &cbuf, int dst_encoding, int src_encoding ) {
  if( dst_encoding == src_encoding ) {
    // reg-reg copy, use an empty encoding
  } else {
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, dst_encoding, src_encoding );
  }
}

void emit_cmpfp_fixup(MacroAssembler& _masm) {
  Label exit;
  __ jccb(Assembler::noParity, exit);
  __ pushf();
  //
  // comiss/ucomiss instructions set ZF,PF,CF flags and
  // zero OF,AF,SF for NaN values.
  // Fixup flags by zeroing ZF,PF so that compare of NaN
  // values returns 'less than' result (CF is set).
  // Leave the rest of flags unchanged.
  //
  //    7 6 5 4 3 2 1 0
  //   |S|Z|r|A|r|P|r|C|  (r - reserved bit)
  //    0 0 1 0 1 0 1 1   (0x2B)
  //
  __ andl(Address(rsp, 0), 0xffffff2b);
  __ popf();
  __ bind(exit);
}

void emit_cmpfp3(MacroAssembler& _masm, Register dst) {
  Label done;
  __ movl(dst, -1);
  __ jcc(Assembler::parity, done);
  __ jcc(Assembler::below, done);
  __ setb(Assembler::notEqual, dst);
  __ movzbl(dst, dst);
  __ bind(done);
}


//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = RegMask::Empty;

int Compile::ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Empty encoding
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("# MachConstantBaseNode (empty encoding)");
}
#endif


//=============================================================================
#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  Compile* C = ra_->C;

  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove wordSize for return addr which is already pushed.
  framesize -= wordSize;

  if (C->need_stack_bang(framesize)) {
    framesize -= wordSize;
    st->print("# stack bang");
    st->print("\n\t");
    st->print("PUSH   EBP\t# Save EBP");
    if (framesize) {
      st->print("\n\t");
      st->print("SUB    ESP, #%d\t# Create frame",framesize);
    }
  } else {
    st->print("SUB    ESP, #%d\t# Create frame",framesize);
    st->print("\n\t");
    framesize -= wordSize;
    st->print("MOV    [ESP + #%d], EBP\t# Save EBP",framesize);
  }

  if (VerifyStackAtCalls) {
    st->print("\n\t");
    framesize -= wordSize;
    st->print("MOV    [ESP + #%d], 0xBADB100D\t# Majik cookie for stack depth check",framesize);
  }

  if( C->in_24_bit_fp_mode() ) {
    st->print("\n\t");
    st->print("FLDCW  \t# load 24 bit fpu control word");
  }
  if (UseSSE >= 2 && VerifyFPU) {
    st->print("\n\t");
    st->print("# verify FPU stack (must be clean on entry)");
  }

#ifdef ASSERT
  if (VerifyStackAtCalls) {
    st->print("\n\t");
    st->print("# stack alignment check");
  }
#endif
  st->cr();
}
#endif


void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);

  int framesize = C->frame_slots() << LogBytesPerInt;

  __ verified_entry(framesize, C->need_stack_bang(framesize), C->in_24_bit_fp_mode());

  C->set_frame_complete(cbuf.insts_size());

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    Compile::ConstantTable& constant_table = C->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_); // too many variables; just compute it the hard way
}

int MachPrologNode::reloc() const {
  return 0; // a large enough number
}

//=============================================================================
#ifndef PRODUCT
void MachEpilogNode::format( PhaseRegAlloc *ra_, outputStream* st ) const {
  Compile *C = ra_->C;
  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove two words for return addr and rbp,
  framesize -= 2*wordSize;

  if( C->in_24_bit_fp_mode() ) {
    st->print("FLDCW  standard control word");
    st->cr(); st->print("\t");
  }
  if( framesize ) {
    st->print("ADD    ESP,%d\t# Destroy frame",framesize);
    st->cr(); st->print("\t");
  }
  st->print_cr("POPL   EBP"); st->print("\t");
  if( do_polling() && C->is_method_compilation() ) {
    st->print("TEST   PollPage,EAX\t! Poll Safepoint");
    st->cr(); st->print("\t");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile *C = ra_->C;

  // If method set FPU control word, restore to standard control word
  if( C->in_24_bit_fp_mode() ) {
    MacroAssembler masm(&cbuf);
    masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
  }

  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove two words for return addr and rbp,
  framesize -= 2*wordSize;

  // Note that VerifyStackAtCalls' Majik cookie does not change the frame size popped here

  if( framesize >= 128 ) {
    emit_opcode(cbuf, 0x81); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d32(cbuf, framesize);
  }
  else if( framesize ) {
    emit_opcode(cbuf, 0x83); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, framesize);
  }

  emit_opcode(cbuf, 0x58 | EBP_enc);

  if( do_polling() && C->is_method_compilation() ) {
    cbuf.relocate(cbuf.insts_end(), relocInfo::poll_return_type, 0);
    emit_opcode(cbuf,0x85);
    emit_rm(cbuf, 0x0, EAX_enc, 0x5); // EAX
    emit_d32(cbuf, (intptr_t)os::get_polling_page());
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  Compile *C = ra_->C;
  // If method set FPU control word, restore to standard control word
  int size = C->in_24_bit_fp_mode() ? 6 : 0;
  if( do_polling() && C->is_method_compilation() ) size += 6;

  int framesize = C->frame_slots() << LogBytesPerInt;
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  // Remove two words for return addr and rbp,
  framesize -= 2*wordSize;

  size++; // popl rbp,

  if( framesize >= 128 ) {
    size += 6;
  } else {
    size += framesize ? 3 : 0;
  }
  return size;
}

int MachEpilogNode::reloc() const {
  return 0; // a large enough number
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

int MachEpilogNode::safepoint_offset() const { return 0; }

//=============================================================================

enum RC { rc_bad, rc_int, rc_float, rc_xmm, rc_stack };
static enum RC rc_class( OptoReg::Name reg ) {

  if( !OptoReg::is_valid(reg)  ) return rc_bad;
  if (OptoReg::is_stack(reg)) return rc_stack;

  VMReg r = OptoReg::as_VMReg(reg);
  if (r->is_Register()) return rc_int;
  if (r->is_FloatRegister()) {
    assert(UseSSE < 2, "shouldn't be used in SSE2+ mode");
    return rc_float;
  }
  assert(r->is_XMMRegister(), "must be");
  return rc_xmm;
}

static int impl_helper( CodeBuffer *cbuf, bool do_size, bool is_load, int offset, int reg,
                        int opcode, const char *op_str, int size, outputStream* st ) {
  if( cbuf ) {
    emit_opcode  (*cbuf, opcode );
    encode_RegMem(*cbuf, Matcher::_regEncode[reg], ESP_enc, 0x4, 0, offset, false);
#ifndef PRODUCT
  } else if( !do_size ) {
    if( size != 0 ) st->print("\n\t");
    if( opcode == 0x8B || opcode == 0x89 ) { // MOV
      if( is_load ) st->print("%s   %s,[ESP + #%d]",op_str,Matcher::regName[reg],offset);
      else          st->print("%s   [ESP + #%d],%s",op_str,offset,Matcher::regName[reg]);
    } else { // FLD, FST, PUSH, POP
      st->print("%s [ESP + #%d]",op_str,offset);
    }
#endif
  }
  int offset_size = (offset == 0) ? 0 : ((offset <= 127) ? 1 : 4);
  return size+3+offset_size;
}

// Helper for XMM registers.  Extra opcode bits, limited syntax.
static int impl_x_helper( CodeBuffer *cbuf, bool do_size, bool is_load,
                         int offset, int reg_lo, int reg_hi, int size, outputStream* st ) {
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    if (reg_lo+1 == reg_hi) { // double move?
      if (is_load) {
        __ movdbl(as_XMMRegister(Matcher::_regEncode[reg_lo]), Address(rsp, offset));
      } else {
        __ movdbl(Address(rsp, offset), as_XMMRegister(Matcher::_regEncode[reg_lo]));
      }
    } else {
      if (is_load) {
        __ movflt(as_XMMRegister(Matcher::_regEncode[reg_lo]), Address(rsp, offset));
      } else {
        __ movflt(Address(rsp, offset), as_XMMRegister(Matcher::_regEncode[reg_lo]));
      }
    }
#ifndef PRODUCT
  } else if (!do_size) {
    if (size != 0) st->print("\n\t");
    if (reg_lo+1 == reg_hi) { // double move?
      if (is_load) st->print("%s %s,[ESP + #%d]",
                              UseXmmLoadAndClearUpper ? "MOVSD " : "MOVLPD",
                              Matcher::regName[reg_lo], offset);
      else         st->print("MOVSD  [ESP + #%d],%s",
                              offset, Matcher::regName[reg_lo]);
    } else {
      if (is_load) st->print("MOVSS  %s,[ESP + #%d]",
                              Matcher::regName[reg_lo], offset);
      else         st->print("MOVSS  [ESP + #%d],%s",
                              offset, Matcher::regName[reg_lo]);
    }
#endif
  }
  int offset_size = (offset == 0) ? 0 : ((offset <= 127) ? 1 : 4);
  // VEX_2bytes prefix is used if UseAVX > 0, so it takes the same 2 bytes.
  return size+5+offset_size;
}


static int impl_movx_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                            int src_hi, int dst_hi, int size, outputStream* st ) {
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    if (src_lo+1 == src_hi && dst_lo+1 == dst_hi) { // double move?
      __ movdbl(as_XMMRegister(Matcher::_regEncode[dst_lo]),
                as_XMMRegister(Matcher::_regEncode[src_lo]));
    } else {
      __ movflt(as_XMMRegister(Matcher::_regEncode[dst_lo]),
                as_XMMRegister(Matcher::_regEncode[src_lo]));
    }
#ifndef PRODUCT
  } else if (!do_size) {
    if (size != 0) st->print("\n\t");
    if (UseXmmRegToRegMoveAll) {//Use movaps,movapd to move between xmm registers
      if (src_lo+1 == src_hi && dst_lo+1 == dst_hi) { // double move?
        st->print("MOVAPD %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      } else {
        st->print("MOVAPS %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      }
    } else {
      if( src_lo+1 == src_hi && dst_lo+1 == dst_hi ) { // double move?
        st->print("MOVSD  %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      } else {
        st->print("MOVSS  %s,%s",Matcher::regName[dst_lo],Matcher::regName[src_lo]);
      }
    }
#endif
  }
  // VEX_2bytes prefix is used if UseAVX > 0, and it takes the same 2 bytes.
  // Only MOVAPS SSE prefix uses 1 byte.
  int sz = 4;
  if (!(src_lo+1 == src_hi && dst_lo+1 == dst_hi) &&
      UseXmmRegToRegMoveAll && (UseAVX == 0)) sz = 3;
  return size + sz;
}

static int impl_movgpr2x_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                            int src_hi, int dst_hi, int size, outputStream* st ) {
  // 32-bit
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    __ movdl(as_XMMRegister(Matcher::_regEncode[dst_lo]),
             as_Register(Matcher::_regEncode[src_lo]));
#ifndef PRODUCT
  } else if (!do_size) {
    st->print("movdl   %s, %s\t# spill", Matcher::regName[dst_lo], Matcher::regName[src_lo]);
#endif
  }
  return 4;
}


static int impl_movx2gpr_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int dst_lo,
                                 int src_hi, int dst_hi, int size, outputStream* st ) {
  // 32-bit
  if (cbuf) {
    MacroAssembler _masm(cbuf);
    __ movdl(as_Register(Matcher::_regEncode[dst_lo]),
             as_XMMRegister(Matcher::_regEncode[src_lo]));
#ifndef PRODUCT
  } else if (!do_size) {
    st->print("movdl   %s, %s\t# spill", Matcher::regName[dst_lo], Matcher::regName[src_lo]);
#endif
  }
  return 4;
}

static int impl_mov_helper( CodeBuffer *cbuf, bool do_size, int src, int dst, int size, outputStream* st ) {
  if( cbuf ) {
    emit_opcode(*cbuf, 0x8B );
    emit_rm    (*cbuf, 0x3, Matcher::_regEncode[dst], Matcher::_regEncode[src] );
#ifndef PRODUCT
  } else if( !do_size ) {
    if( size != 0 ) st->print("\n\t");
    st->print("MOV    %s,%s",Matcher::regName[dst],Matcher::regName[src]);
#endif
  }
  return size+2;
}

static int impl_fp_store_helper( CodeBuffer *cbuf, bool do_size, int src_lo, int src_hi, int dst_lo, int dst_hi,
                                 int offset, int size, outputStream* st ) {
  if( src_lo != FPR1L_num ) {      // Move value to top of FP stack, if not already there
    if( cbuf ) {
      emit_opcode( *cbuf, 0xD9 );  // FLD (i.e., push it)
      emit_d8( *cbuf, 0xC0-1+Matcher::_regEncode[src_lo] );
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("FLD    %s",Matcher::regName[src_lo]);
#endif
    }
    size += 2;
  }

  int st_op = (src_lo != FPR1L_num) ? EBX_num /*store & pop*/ : EDX_num /*store no pop*/;
  const char *op_str;
  int op;
  if( src_lo+1 == src_hi && dst_lo+1 == dst_hi ) { // double store?
    op_str = (src_lo != FPR1L_num) ? "FSTP_D" : "FST_D ";
    op = 0xDD;
  } else {                   // 32-bit store
    op_str = (src_lo != FPR1L_num) ? "FSTP_S" : "FST_S ";
    op = 0xD9;
    assert( !OptoReg::is_valid(src_hi) && !OptoReg::is_valid(dst_hi), "no non-adjacent float-stores" );
  }

  return impl_helper(cbuf,do_size,false,offset,st_op,op,op_str,size, st);
}

uint MachSpillCopyNode::implementation( CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream* st ) const {
  // Get registers to move
  OptoReg::Name src_second = ra_->get_reg_second(in(1));
  OptoReg::Name src_first = ra_->get_reg_first(in(1));
  OptoReg::Name dst_second = ra_->get_reg_second(this );
  OptoReg::Name dst_first = ra_->get_reg_first(this );

  enum RC src_second_rc = rc_class(src_second);
  enum RC src_first_rc = rc_class(src_first);
  enum RC dst_second_rc = rc_class(dst_second);
  enum RC dst_first_rc = rc_class(dst_first);

  assert( OptoReg::is_valid(src_first) && OptoReg::is_valid(dst_first), "must move at least 1 register" );

  // Generate spill code!
  int size = 0;

  if( src_first == dst_first && src_second == dst_second )
    return size;            // Self copy, no move

  // --------------------------------------
  // Check for mem-mem move.  push/pop to move.
  if( src_first_rc == rc_stack && dst_first_rc == rc_stack ) {
    if( src_second == dst_first ) { // overlapping stack copy ranges
      assert( src_second_rc == rc_stack && dst_second_rc == rc_stack, "we only expect a stk-stk copy here" );
      size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_second),ESI_num,0xFF,"PUSH  ",size, st);
      size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_second),EAX_num,0x8F,"POP   ",size, st);
      src_second_rc = dst_second_rc = rc_bad;  // flag as already moved the second bits
    }
    // move low bits
    size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_first),ESI_num,0xFF,"PUSH  ",size, st);
    size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_first),EAX_num,0x8F,"POP   ",size, st);
    if( src_second_rc == rc_stack && dst_second_rc == rc_stack ) { // mov second bits
      size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_second),ESI_num,0xFF,"PUSH  ",size, st);
      size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_second),EAX_num,0x8F,"POP   ",size, st);
    }
    return size;
  }

  // --------------------------------------
  // Check for integer reg-reg copy
  if( src_first_rc == rc_int && dst_first_rc == rc_int )
    size = impl_mov_helper(cbuf,do_size,src_first,dst_first,size, st);

  // Check for integer store
  if( src_first_rc == rc_int && dst_first_rc == rc_stack )
    size = impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_first),src_first,0x89,"MOV ",size, st);

  // Check for integer load
  if( dst_first_rc == rc_int && src_first_rc == rc_stack )
    size = impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_first),dst_first,0x8B,"MOV ",size, st);

  // Check for integer reg-xmm reg copy
  if( src_first_rc == rc_int && dst_first_rc == rc_xmm ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad),
            "no 64 bit integer-float reg moves" );
    return impl_movgpr2x_helper(cbuf,do_size,src_first,dst_first,src_second, dst_second, size, st);
  }
  // --------------------------------------
  // Check for float reg-reg copy
  if( src_first_rc == rc_float && dst_first_rc == rc_float ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad) ||
            (src_first+1 == src_second && dst_first+1 == dst_second), "no non-adjacent float-moves" );
    if( cbuf ) {

      // Note the mucking with the register encode to compensate for the 0/1
      // indexing issue mentioned in a comment in the reg_def sections
      // for FPR registers many lines above here.

      if( src_first != FPR1L_num ) {
        emit_opcode  (*cbuf, 0xD9 );           // FLD    ST(i)
        emit_d8      (*cbuf, 0xC0+Matcher::_regEncode[src_first]-1 );
        emit_opcode  (*cbuf, 0xDD );           // FSTP   ST(i)
        emit_d8      (*cbuf, 0xD8+Matcher::_regEncode[dst_first] );
     } else {
        emit_opcode  (*cbuf, 0xDD );           // FST    ST(i)
        emit_d8      (*cbuf, 0xD0+Matcher::_regEncode[dst_first]-1 );
     }
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      if( src_first != FPR1L_num ) st->print("FLD    %s\n\tFSTP   %s",Matcher::regName[src_first],Matcher::regName[dst_first]);
      else                      st->print(             "FST    %s",                            Matcher::regName[dst_first]);
#endif
    }
    return size + ((src_first != FPR1L_num) ? 2+2 : 2);
  }

  // Check for float store
  if( src_first_rc == rc_float && dst_first_rc == rc_stack ) {
    return impl_fp_store_helper(cbuf,do_size,src_first,src_second,dst_first,dst_second,ra_->reg2offset(dst_first),size, st);
  }

  // Check for float load
  if( dst_first_rc == rc_float && src_first_rc == rc_stack ) {
    int offset = ra_->reg2offset(src_first);
    const char *op_str;
    int op;
    if( src_first+1 == src_second && dst_first+1 == dst_second ) { // double load?
      op_str = "FLD_D";
      op = 0xDD;
    } else {                   // 32-bit load
      op_str = "FLD_S";
      op = 0xD9;
      assert( src_second_rc == rc_bad && dst_second_rc == rc_bad, "no non-adjacent float-loads" );
    }
    if( cbuf ) {
      emit_opcode  (*cbuf, op );
      encode_RegMem(*cbuf, 0x0, ESP_enc, 0x4, 0, offset, false);
      emit_opcode  (*cbuf, 0xDD );           // FSTP   ST(i)
      emit_d8      (*cbuf, 0xD8+Matcher::_regEncode[dst_first] );
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("%s  ST,[ESP + #%d]\n\tFSTP   %s",op_str, offset,Matcher::regName[dst_first]);
#endif
    }
    int offset_size = (offset == 0) ? 0 : ((offset <= 127) ? 1 : 4);
    return size + 3+offset_size+2;
  }

  // Check for xmm reg-reg copy
  if( src_first_rc == rc_xmm && dst_first_rc == rc_xmm ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad) ||
            (src_first+1 == src_second && dst_first+1 == dst_second),
            "no non-adjacent float-moves" );
    return impl_movx_helper(cbuf,do_size,src_first,dst_first,src_second, dst_second, size, st);
  }

  // Check for xmm reg-integer reg copy
  if( src_first_rc == rc_xmm && dst_first_rc == rc_int ) {
    assert( (src_second_rc == rc_bad && dst_second_rc == rc_bad),
            "no 64 bit float-integer reg moves" );
    return impl_movx2gpr_helper(cbuf,do_size,src_first,dst_first,src_second, dst_second, size, st);
  }

  // Check for xmm store
  if( src_first_rc == rc_xmm && dst_first_rc == rc_stack ) {
    return impl_x_helper(cbuf,do_size,false,ra_->reg2offset(dst_first),src_first, src_second, size, st);
  }

  // Check for float xmm load
  if( dst_first_rc == rc_xmm && src_first_rc == rc_stack ) {
    return impl_x_helper(cbuf,do_size,true ,ra_->reg2offset(src_first),dst_first, dst_second, size, st);
  }

  // Copy from float reg to xmm reg
  if( dst_first_rc == rc_xmm && src_first_rc == rc_float ) {
    // copy to the top of stack from floating point reg
    // and use LEA to preserve flags
    if( cbuf ) {
      emit_opcode(*cbuf,0x8D);  // LEA  ESP,[ESP-8]
      emit_rm(*cbuf, 0x1, ESP_enc, 0x04);
      emit_rm(*cbuf, 0x0, 0x04, ESP_enc);
      emit_d8(*cbuf,0xF8);
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("LEA    ESP,[ESP-8]");
#endif
    }
    size += 4;

    size = impl_fp_store_helper(cbuf,do_size,src_first,src_second,dst_first,dst_second,0,size, st);

    // Copy from the temp memory to the xmm reg.
    size = impl_x_helper(cbuf,do_size,true ,0,dst_first, dst_second, size, st);

    if( cbuf ) {
      emit_opcode(*cbuf,0x8D);  // LEA  ESP,[ESP+8]
      emit_rm(*cbuf, 0x1, ESP_enc, 0x04);
      emit_rm(*cbuf, 0x0, 0x04, ESP_enc);
      emit_d8(*cbuf,0x08);
#ifndef PRODUCT
    } else if( !do_size ) {
      if( size != 0 ) st->print("\n\t");
      st->print("LEA    ESP,[ESP+8]");
#endif
    }
    size += 4;
    return size;
  }

  assert( size > 0, "missed a case" );

  // --------------------------------------------------------------------
  // Check for second bits still needing moving.
  if( src_second == dst_second )
    return size;               // Self copy; no move
  assert( src_second_rc != rc_bad && dst_second_rc != rc_bad, "src_second & dst_second cannot be Bad" );

  // Check for second word int-int move
  if( src_second_rc == rc_int && dst_second_rc == rc_int )
    return impl_mov_helper(cbuf,do_size,src_second,dst_second,size, st);

  // Check for second word integer store
  if( src_second_rc == rc_int && dst_second_rc == rc_stack )
    return impl_helper(cbuf,do_size,false,ra_->reg2offset(dst_second),src_second,0x89,"MOV ",size, st);

  // Check for second word integer load
  if( dst_second_rc == rc_int && src_second_rc == rc_stack )
    return impl_helper(cbuf,do_size,true ,ra_->reg2offset(src_second),dst_second,0x8B,"MOV ",size, st);


  Unimplemented();
}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream* st) const {
  implementation( NULL, ra_, false, st );
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation( &cbuf, ra_, false, NULL );
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return implementation( NULL, ra_, true, NULL );
}


//=============================================================================
#ifndef PRODUCT
void BoxLockNode::format( PhaseRegAlloc *ra_, outputStream* st ) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("LEA    %s,[ESP + #%d]",Matcher::regName[reg],offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_encode(this);
  if( offset >= 128 ) {
    emit_opcode(cbuf, 0x8D);      // LEA  reg,[SP+offset]
    emit_rm(cbuf, 0x2, reg, 0x04);
    emit_rm(cbuf, 0x0, 0x04, ESP_enc);
    emit_d32(cbuf, offset);
  }
  else {
    emit_opcode(cbuf, 0x8D);      // LEA  reg,[SP+offset]
    emit_rm(cbuf, 0x1, reg, 0x04);
    emit_rm(cbuf, 0x0, 0x04, ESP_enc);
    emit_d8(cbuf, offset);
  }
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  if( offset >= 128 ) {
    return 7;
  }
  else {
    return 4;
  }
}

//=============================================================================

// emit call stub, compiled java to interpreter
void emit_java_to_interp(CodeBuffer &cbuf ) {
  // Stub is fixed up when the corresponding call is converted from calling
  // compiled code to calling interpreted code.
  // mov rbx,0
  // jmp -1

  address mark = cbuf.insts_mark();  // get mark within main instrs section

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a stub.
  MacroAssembler _masm(&cbuf);

  address base =
  __ start_a_stub(Compile::MAX_stubs_size);
  if (base == NULL)  return;  // CodeBuffer::expand failed
  // static stub relocation stores the instruction address of the call
  __ relocate(static_stub_Relocation::spec(mark), RELOC_IMM32);
  // static stub relocation also tags the methodOop in the code-stream.
  __ movoop(rbx, (jobject)NULL);  // method is zapped till fixup time
  // This is recognized as unresolved by relocs/nativeInst/ic code
  __ jump(RuntimeAddress(__ pc()));

  __ end_a_stub();
  // Update current stubs pointer and restore insts_end.
}
// size of call stub, compiled java to interpretor
uint size_java_to_interp() {
  return 10;  // movl; jmp
}
// relocation entries for call stub, compiled java to interpretor
uint reloc_java_to_interp() {
  return 4;  // 3 in emit_java_to_interp + 1 in Java_Static_Call
}

//=============================================================================
#ifndef PRODUCT
void MachUEPNode::format( PhaseRegAlloc *ra_, outputStream* st ) const {
  st->print_cr(  "CMP    EAX,[ECX+4]\t# Inline cache check");
  st->print_cr("\tJNE    SharedRuntime::handle_ic_miss_stub");
  st->print_cr("\tNOP");
  st->print_cr("\tNOP");
  if( !OptoBreakpoint )
    st->print_cr("\tNOP");
}
#endif

void MachUEPNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  MacroAssembler masm(&cbuf);
#ifdef ASSERT
  uint insts_size = cbuf.insts_size();
#endif
  masm.cmpptr(rax, Address(rcx, oopDesc::klass_offset_in_bytes()));
  masm.jump_cc(Assembler::notEqual,
               RuntimeAddress(SharedRuntime::get_ic_miss_stub()));
  /* WARNING these NOPs are critical so that verified entry point is properly
     aligned for patching by NativeJump::patch_verified_entry() */
  int nops_cnt = 2;
  if( !OptoBreakpoint ) // Leave space for int3
     nops_cnt += 1;
  masm.nop(nops_cnt);

  assert(cbuf.insts_size() - insts_size == size(ra_), "checking code size of inline cache node");
}

uint MachUEPNode::size(PhaseRegAlloc *ra_) const {
  return OptoBreakpoint ? 11 : 12;
}


//=============================================================================
uint size_exception_handler() {
  // NativeCall instruction size is the same as NativeJump.
  // exception handler starts out as jump and can be patched to
  // a call be deoptimization.  (4932387)
  // Note that this value is also credited (in output.cpp) to
  // the size of the code section.
  return NativeJump::instruction_size;
}

// Emit exception handler code.  Stuff framesize into a register
// and call a VM stub routine.
int emit_exception_handler(CodeBuffer& cbuf) {

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base =
  __ start_a_stub(size_exception_handler());
  if (base == NULL)  return 0;  // CodeBuffer::expand failed
  int offset = __ offset();
  __ jump(RuntimeAddress(OptoRuntime::exception_blob()->entry_point()));
  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");
  __ end_a_stub();
  return offset;
}

uint size_deopt_handler() {
  // NativeCall instruction size is the same as NativeJump.
  // exception handler starts out as jump and can be patched to
  // a call be deoptimization.  (4932387)
  // Note that this value is also credited (in output.cpp) to
  // the size of the code section.
  return 5 + NativeJump::instruction_size; // pushl(); jmp;
}

// Emit deopt handler code.
int emit_deopt_handler(CodeBuffer& cbuf) {

  // Note that the code buffer's insts_mark is always relative to insts.
  // That's why we must use the macroassembler to generate a handler.
  MacroAssembler _masm(&cbuf);
  address base =
  __ start_a_stub(size_exception_handler());
  if (base == NULL)  return 0;  // CodeBuffer::expand failed
  int offset = __ offset();
  InternalAddress here(__ pc());
  __ pushptr(here.addr());

  __ jump(RuntimeAddress(SharedRuntime::deopt_blob()->unpack()));
  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");
  __ end_a_stub();
  return offset;
}


const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  return true;  // Per default match rules are supported.
}

int Matcher::regnum_to_fpu_offset(int regnum) {
  return regnum - 32; // The FP registers are in the second chunk
}

// This is UltraSparc specific, true just means we have fast l2f conversion
const bool Matcher::convL2FSupported(void) {
  return true;
}

// Vector width in bytes
const uint Matcher::vector_width_in_bytes(void) {
  return UseSSE >= 2 ? 8 : 0;
}

// Vector ideal reg
const uint Matcher::vector_ideal_reg(void) {
  return Op_RegD;
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.
  // On 86 a branch displacement is calculated relative to address
  // of a next instruction.
  offset -= br_size;

  // the short version of jmpConUCF2 contains multiple branches,
  // making the reach slightly less
  if (rule == jmpConUCF2_rule)
    return (-126 <= offset && offset <= 125);
  return (-128 <= offset && offset <= 127);
}

const bool Matcher::isSimpleConstant64(jlong value) {
  // Will one (StoreL ConL) be cheaper than two (StoreI ConI)?.
  return false;
}

// The ecx parameter to rep stos for the ClearArray node is in dwords.
const bool Matcher::init_array_count_is_in_bytes = false;

// Threshold size for cleararray.
const int Matcher::init_array_short_size = 8 * BytesPerLong;

// Needs 2 CMOV's for longs.
const int Matcher::long_cmove_cost() { return 1; }

// No CMOVF/CMOVD with SSE/SSE2
const int Matcher::float_cmove_cost() { return (UseSSE>=1) ? ConditionalMoveLimit : 0; }

// Should the Matcher clone shifts on addressing modes, expecting them to
// be subsumed into complex addressing expressions or compute them into
// registers?  True for Intel but false for most RISCs
const bool Matcher::clone_shift_expressions = true;

// Do we need to mask the count passed to shift instructions or does
// the cpu only look at the lower 5/6 bits anyway?
const bool Matcher::need_masked_shift_count = false;

bool Matcher::narrow_oop_use_complex_address() {
  ShouldNotCallThis();
  return true;
}


// Is it better to copy float constants, or load them directly from memory?
// Intel can load a float constant from a direct address, requiring no
// extra registers.  Most RISCs will have to materialize an address into a
// register first, so they would do better to copy the constant from stack.
const bool Matcher::rematerialize_float_constants = true;

// If CPU can load and store mis-aligned doubles directly then no fixup is
// needed.  Else we split the double into 2 integer pieces and move it
// piece-by-piece.  Only happens when passing doubles into C code as the
// Java calling convention forces doubles to be aligned.
const bool Matcher::misaligned_doubles_ok = true;


void Matcher::pd_implicit_null_fixup(MachNode *node, uint idx) {
  // Get the memory operand from the node
  uint numopnds = node->num_opnds();        // Virtual call for number of operands
  uint skipped  = node->oper_input_base();  // Sum of leaves skipped so far
  assert( idx >= skipped, "idx too low in pd_implicit_null_fixup" );
  uint opcnt     = 1;                 // First operand
  uint num_edges = node->_opnds[1]->num_edges(); // leaves for first operand
  while( idx >= skipped+num_edges ) {
    skipped += num_edges;
    opcnt++;                          // Bump operand count
    assert( opcnt < numopnds, "Accessing non-existent operand" );
    num_edges = node->_opnds[opcnt]->num_edges(); // leaves for next operand
  }

  MachOper *memory = node->_opnds[opcnt];
  MachOper *new_memory = NULL;
  switch (memory->opcode()) {
  case DIRECT:
  case INDOFFSET32X:
    // No transformation necessary.
    return;
  case INDIRECT:
    new_memory = new (C) indirect_win95_safeOper( );
    break;
  case INDOFFSET8:
    new_memory = new (C) indOffset8_win95_safeOper(memory->disp(NULL, NULL, 0));
    break;
  case INDOFFSET32:
    new_memory = new (C) indOffset32_win95_safeOper(memory->disp(NULL, NULL, 0));
    break;
  case INDINDEXOFFSET:
    new_memory = new (C) indIndexOffset_win95_safeOper(memory->disp(NULL, NULL, 0));
    break;
  case INDINDEXSCALE:
    new_memory = new (C) indIndexScale_win95_safeOper(memory->scale());
    break;
  case INDINDEXSCALEOFFSET:
    new_memory = new (C) indIndexScaleOffset_win95_safeOper(memory->scale(), memory->disp(NULL, NULL, 0));
    break;
  case LOAD_LONG_INDIRECT:
  case LOAD_LONG_INDOFFSET32:
    // Does not use EBP as address register, use { EDX, EBX, EDI, ESI}
    return;
  default:
    assert(false, "unexpected memory operand in pd_implicit_null_fixup()");
    return;
  }
  node->_opnds[opcnt] = new_memory;
}

// Advertise here if the CPU requires explicit rounding operations
// to implement the UseStrictFP mode.
const bool Matcher::strict_fp_requires_explicit_rounding = true;

// Are floats conerted to double when stored to stack during deoptimization?
// On x32 it is stored with convertion only when FPU is used for floats.
bool Matcher::float_in_double() { return (UseSSE == 0); }

// Do ints take an entire long register or just half?
const bool Matcher::int_in_long = false;

// Return whether or not this register is ever used as an argument.  This
// function is used on startup to build the trampoline stubs in generateOptoStub.
// Registers not mentioned will be killed by the VM call in the trampoline, and
// arguments in those registers not be available to the callee.
bool Matcher::can_be_java_arg( int reg ) {
  if(  reg == ECX_num   || reg == EDX_num   ) return true;
  if( (reg == XMM0a_num || reg == XMM1a_num) && UseSSE>=1 ) return true;
  if( (reg == XMM0b_num || reg == XMM1b_num) && UseSSE>=2 ) return true;
  return false;
}

bool Matcher::is_spillable_arg( int reg ) {
  return can_be_java_arg(reg);
}

bool Matcher::use_asm_for_ldiv_by_con( jlong divisor ) {
  // Use hardware integer DIV instruction when
  // it is faster than a code which use multiply.
  // Only when constant divisor fits into 32 bit
  // (min_jint is excluded to get only correct
  // positive 32 bit values from negative).
  return VM_Version::has_fast_idiv() &&
         (divisor == (int)divisor && divisor != min_jint);
}

// Register for DIVI projection of divmodI
RegMask Matcher::divI_proj_mask() {
  return EAX_REG_mask();
}

// Register for MODI projection of divmodI
RegMask Matcher::modI_proj_mask() {
  return EDX_REG_mask();
}

// Register for DIVL projection of divmodL
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return EBP_REG_mask();
}

// Returns true if the high 32 bits of the value is known to be zero.
bool is_operand_hi32_zero(Node* n) {
  int opc = n->Opcode();
  if (opc == Op_LoadUI2L) {
    return true;
  }
  if (opc == Op_AndL) {
    Node* o2 = n->in(2);
    if (o2->is_Con() && (o2->get_long() & 0xFFFFFFFF00000000LL) == 0LL) {
      return true;
    }
  }
  if (opc == Op_ConL && (n->get_long() & 0xFFFFFFFF00000000LL) == 0LL) {
    return true;
  }
  return false;
}


#line 1325 "../generated/adfiles/ad_x86_32.cpp"


//SourceForm

#line 27 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

  // Float masks come from different places depending on platform.
#ifdef _LP64
  static address float_signmask()  { return StubRoutines::x86::float_sign_mask(); }
  static address float_signflip()  { return StubRoutines::x86::float_sign_flip(); }
  static address double_signmask() { return StubRoutines::x86::double_sign_mask(); }
  static address double_signflip() { return StubRoutines::x86::double_sign_flip(); }
#else
  static address float_signmask()  { return (address)float_signmask_pool; }
  static address float_signflip()  { return (address)float_signflip_pool; }
  static address double_signmask() { return (address)double_signmask_pool; }
  static address double_signflip() { return (address)double_signflip_pool; }
#endif

#ifndef PRODUCT
  void MachNopNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("nop \t# %d bytes pad for loops and calls", _count);
  }
#endif

  void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc*) const {
    MacroAssembler _masm(&cbuf);
    __ nop(_count);
  }

  uint MachNopNode::size(PhaseRegAlloc*) const {
    return _count;
  }

#ifndef PRODUCT
  void MachBreakpointNode::format(PhaseRegAlloc*, outputStream* st) const {
    st->print("# breakpoint");
  }
#endif

  void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc* ra_) const {
    MacroAssembler _masm(&cbuf);
    __ int3();
  }

  uint MachBreakpointNode::size(PhaseRegAlloc* ra_) const {
    return MachNode::size(ra_);
  }


#line 1376 "../generated/adfiles/ad_x86_32.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C',
  'C',
  'N',
  'C',
  'C',
  'C',
  'C',
  'N',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C' // no trailing comma
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'C',
  'E',
  'E',
  'E',
  'C',
  'C',
  'E',
  'N',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C',
  'C' // no trailing comma
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  0 // no trailing comma
};


const        int   reduceOp[] = {
  0, // 0
  0, // 1
  0, // 2
  0, // 3
  0, // 4
  0, // 5
  0, // 6
  0, // 7
  immI_rule, // 8
  immI0_rule, // 9
  immI1_rule, // 10
  immI_M1_rule, // 11
  immI2_rule, // 12
  immI8_rule, // 13
  immI16_rule, // 14
  immI_32_rule, // 15
  immI_1_31_rule, // 16
  immI_32_63_rule, // 17
  immI_1_rule, // 18
  immI_2_rule, // 19
  immI_3_rule, // 20
  immP_rule, // 21
  immP0_rule, // 22
  immL_rule, // 23
  immL0_rule, // 24
  immL_M1_rule, // 25
  immL_127_rule, // 26
  immL_32bits_rule, // 27
  immL32_rule, // 28
  immDPR0_rule, // 29
  immDPR1_rule, // 30
  immDPR_rule, // 31
  immD_rule, // 32
  immD0_rule, // 33
  immFPR0_rule, // 34
  immFPR1_rule, // 35
  immFPR_rule, // 36
  immF_rule, // 37
  immF0_rule, // 38
  immI_16_rule, // 39
  immI_24_rule, // 40
  immI_255_rule, // 41
  immI_65535_rule, // 42
  eRegI_rule, // 43
  xRegI_rule, // 44
  eAXRegI_rule, // 45
  eBXRegI_rule, // 46
  eCXRegI_rule, // 47
  eDXRegI_rule, // 48
  eDIRegI_rule, // 49
  naxRegI_rule, // 50
  nadxRegI_rule, // 51
  ncxRegI_rule, // 52
  eSIRegI_rule, // 53
  anyRegP_rule, // 54
  eRegP_rule, // 55
  eRegP_no_EBP_rule, // 56
  naxRegP_rule, // 57
  nabxRegP_rule, // 58
  pRegP_rule, // 59
  eAXRegP_rule, // 60
  eBXRegP_rule, // 61
  eCXRegP_rule, // 62
  eSIRegP_rule, // 63
  eDIRegP_rule, // 64
  eBPRegP_rule, // 65
  eRegL_rule, // 66
  eADXRegL_rule, // 67
  eBCXRegL_rule, // 68
  eADXRegL_low_only_rule, // 69
  eFlagsReg_rule, // 70
  eFlagsRegU_rule, // 71
  eFlagsRegUCF_rule, // 72
  flagsReg_long_LTGE_rule, // 73
  flagsReg_long_EQNE_rule, // 74
  flagsReg_long_LEGT_rule, // 75
  regDPR_rule, // 76
  regDPR1_rule, // 77
  regDPR2_rule, // 78
  regnotDPR1_rule, // 79
  regD_rule, // 80
  regD6_rule, // 81
  regD7_rule, // 82
  regFPR_rule, // 83
  regFPR1_rule, // 84
  regF_rule, // 85
  direct_rule, // 86
  indirect_rule, // 87
  indOffset8_rule, // 88
  indOffset32_rule, // 89
  indOffset32X_rule, // 90
  indIndexOffset_rule, // 91
  indIndex_rule, // 92
  indIndexScale_rule, // 93
  indIndexScaleOffset_rule, // 94
  load_long_RegP_rule, // 95
  load_long_indirect_rule, // 96
  load_long_indOffset32_rule, // 97
  stackSlotP_rule, // 98
  stackSlotI_rule, // 99
  stackSlotF_rule, // 100
  stackSlotD_rule, // 101
  stackSlotL_rule, // 102
  indirect_win95_safe_rule, // 103
  indOffset8_win95_safe_rule, // 104
  indOffset32_win95_safe_rule, // 105
  indIndexOffset_win95_safe_rule, // 106
  indIndexScale_win95_safe_rule, // 107
  indIndexScaleOffset_win95_safe_rule, // 108
  cmpOp_rule, // 109
  cmpOpU_rule, // 110
  cmpOpUCF_rule, // 111
  cmpOpUCF2_rule, // 112
  cmpOp_fcmov_rule, // 113
  cmpOp_commute_rule, // 114
  // last operand
  load_long_memory_rule, // 115
  memory_rule, // 116
  long_memory_rule, // 117
  // last operand class
  _AddP_eRegP_eRegI_rule, // 118
  _LShiftI_eRegI_immI2_rule, // 119
  _AddP_eRegP__LShiftI_eRegI_immI2_rule, // 120
  _AddP_eRegP_no_EBP_eRegI_rule, // 121
  _AddP_eRegP_no_EBP__LShiftI_eRegI_immI2_rule, // 122
  _LoadI_memory__rule, // 123
  _LoadL_memory__rule, // 124
  _LoadB_memory__rule, // 125
  _LoadUB_memory__rule, // 126
  _AndI__LoadUB_memory__immI8_rule, // 127
  _LoadS_memory__rule, // 128
  _LShiftI__LoadS_memory__immI_24_rule, // 129
  _LoadUS_memory__rule, // 130
  _LShiftI__LoadUS_memory__immI_24_rule, // 131
  _AndI__LoadUS_memory__immI_255_rule, // 132
  _AndI__LoadUS_memory__immI16_rule, // 133
  _LShiftI__LoadI_memory__immI_24_rule, // 134
  _LShiftI__LoadI_memory__immI_16_rule, // 135
  _AndI__LoadI_memory__immI_255_rule, // 136
  _AndI__LoadI_memory__immI_65535_rule, // 137
  _AndI__LoadI_memory__immI_rule, // 138
  _ConvL2I_eRegL__rule, // 139
  _RoundDouble_regDPR1__rule, // 140
  _RoundFloat_regFPR1__rule, // 141
  _ConvD2F_regDPR1__rule, // 142
  _Binary_cmpOp_eFlagsReg_rule, // 143
  _Binary_eRegI_eRegI_rule, // 144
  _Binary_cmpOpU_eFlagsRegU_rule, // 145
  _Binary_cmpOpUCF_eFlagsRegUCF_rule, // 146
  _Binary_eRegI__LoadI_memory__rule, // 147
  _Binary_eRegP_eRegP_rule, // 148
  _Binary_cmpOp_fcmov_eFlagsRegU_rule, // 149
  _Binary_regDPR1_regDPR_rule, // 150
  _Binary_regFPR1_regFPR_rule, // 151
  _Binary_regDPR_regDPR_rule, // 152
  _Binary_regFPR_regFPR_rule, // 153
  _Binary_regF_regF_rule, // 154
  _Binary_regD_regD_rule, // 155
  _Binary_eRegL_eRegL_rule, // 156
  _AddI__LoadI_memory__eRegI_rule, // 157
  _AddI_eRegI__LoadI_memory__rule, // 158
  _AddI__LoadI_memory__immI_rule, // 159
  _AddI__LoadI_memory__immI1_rule, // 160
  _AddI__LoadI_memory__immI_M1_rule, // 161
  _Binary_eAXRegP_eRegP_rule, // 162
  _Binary_eAXRegI_eRegI_rule, // 163
  _Binary_eADXRegL_eBCXRegL_rule, // 164
  _Binary_eAXRegP_eCXRegP_rule, // 165
  _Binary_eAXRegI_eCXRegI_rule, // 166
  _SubI__LoadI_memory__eRegI_rule, // 167
  _SubI_immI0_eRegI_rule, // 168
  _ConvI2L_nadxRegI__rule, // 169
  _MulL__ConvI2L_nadxRegI__eADXRegL_low_only_rule, // 170
  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_rule, // 171
  _MulL_eADXRegL_low_only__ConvI2L_nadxRegI__rule, // 172
  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_rule, // 173
  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_63_rule, // 174
  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_63_rule, // 175
  _ConvI2L_eAXRegI__rule, // 176
  _AndL__ConvI2L_eAXRegI__immL_32bits_rule, // 177
  _AndL__ConvI2L_nadxRegI__immL_32bits_rule, // 178
  _RShiftI__LoadI_memory__immI1_rule, // 179
  _RShiftI__LoadI_memory__immI8_rule, // 180
  _LShiftI_xRegI_immI_24_rule, // 181
  _LShiftI_xRegI_immI_16_rule, // 182
  _AndI__LoadI_memory__eRegI_rule, // 183
  _AndI_eRegI__LoadI_memory__rule, // 184
  _CastP2X_eRegP__rule, // 185
  _OrI__LoadI_memory__eRegI_rule, // 186
  _OrI_eRegI__LoadI_memory__rule, // 187
  _OrI__LoadI_memory__immI_rule, // 188
  _LShiftI_eRegI_immI1_rule, // 189
  _URShiftI_eRegI_immI_M1_rule, // 190
  _LShiftI_eRegI_immI8_rule, // 191
  _URShiftI_eRegI_immI8_rule, // 192
  _LShiftI_ncxRegI_eCXRegI_rule, // 193
  _SubI_immI0_eCXRegI_rule, // 194
  _URShiftI_ncxRegI__SubI_immI0_eCXRegI_rule, // 195
  _SubI_immI_32_eCXRegI_rule, // 196
  _URShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule, // 197
  _URShiftI_eRegI_immI1_rule, // 198
  _LShiftI_eRegI_immI_M1_rule, // 199
  _URShiftI_ncxRegI_eCXRegI_rule, // 200
  _LShiftI_ncxRegI__SubI_immI0_eCXRegI_rule, // 201
  _LShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule, // 202
  _XorI__LoadI_memory__eRegI_rule, // 203
  _XorI_eRegI__LoadI_memory__rule, // 204
  _XorI__LoadI_memory__immI_rule, // 205
  _CmpLTMask_ncxRegI_ncxRegI_rule, // 206
  _AndI__CmpLTMask_ncxRegI_ncxRegI_ncxRegI_rule, // 207
  _SubI_ncxRegI_ncxRegI_rule, // 208
  _AndI_ncxRegI__CmpLTMask_ncxRegI_ncxRegI_rule, // 209
  _LoadL_load_long_memory__rule, // 210
  _LoadD_memory__rule, // 211
  _SubD_regDPR_regDPR_rule, // 212
  _AddD_regDPR_regDPR_rule, // 213
  _AddD__LoadD_memory__regDPR_rule, // 214
  _RoundDouble__AddD__LoadD_memory__regDPR__rule, // 215
  _AddD_regDPR__LoadD_memory__rule, // 216
  _RoundDouble__AddD_regDPR__LoadD_memory___rule, // 217
  _AddD_regDPR_immDPR_rule, // 218
  _MulD_regDPR_regDPR_rule, // 219
  _DivD_regDPR_regDPR_rule, // 220
  _LoadF_memory__rule, // 221
  _MulF__LoadF_memory__regFPR_rule, // 222
  _MulF_regFPR__LoadF_memory__rule, // 223
  _MulF_regFPR_regFPR_rule, // 224
  _SubF_regFPR_regFPR_rule, // 225
  _ConvI2L_eRegI__rule, // 226
  _Binary_eDIRegP_eCXRegI_rule, // 227
  _Binary_eSIRegP_eDXRegI_rule, // 228
  _Binary_eDIRegP_eSIRegP_rule, // 229
  _Binary_eDIRegP_eDXRegI_rule, // 230
  _Binary_eSIRegP_immI_rule, // 231
  _Binary_eSIRegP_eAXRegI_rule, // 232
  _AndI_eRegI_immI_rule, // 233
  _AndI_eRegI_memory_rule, // 234
  _LoadP_memory__rule, // 235
  _Binary_nadxRegI_eAXRegI_rule, // 236
  _PartialSubtypeCheck_eSIRegP_eAXRegP_rule, // 237
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 238
  _Binary_eRegL__LoadL_load_long_memory__rule, // 239
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 240
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 241
  _ConvF2D_regF__rule, // 242
  _SqrtD__ConvF2D_regF___rule, // 243
  _ConvF2D__LoadF_memory___rule, // 244
  _SqrtD__ConvF2D__LoadF_memory____rule, // 245
  _ConvF2D_immF__rule, // 246
  _SqrtD__ConvF2D_immF___rule, // 247
  // last internally defined operand
  stackSlotI_rule, // 248
  stackSlotP_rule, // 249
  stackSlotL_rule, // 250
  eRegP_rule, // 251
  eRegP_rule, // 252
  eRegP_rule, // 253
  eRegP_rule, // 254
  eRegP_rule, // 255
  eRegI_rule, // 256
  eRegI_rule, // 257
  eRegP_rule, // 258
  eRegL_rule, // 259
  eRegL_rule, // 260
  regFPR_rule, // 261
  regFPR_rule, // 262
  regFPR_rule, // 263
  regF_rule, // 264
  regF_rule, // 265
  regDPR_rule, // 266
  regDPR_rule, // 267
  regDPR_rule, // 268
  regD_rule, // 269
  regD_rule, // 270
  eRegI_rule, // 271
  eRegL_rule, // 272
  eRegP_rule, // 273
  regFPR_rule, // 274
  regDPR_rule, // 275
  eADXRegL_low_only_rule, // 276
  Universe_rule, // 277
  eAXRegP_rule, // 278
  eRegI_rule, // 279
  eRegP_rule, // 280
  eRegP_rule, // 281
  eRegI_rule, // 282
  eFlagsReg_rule, // 283
  eFlagsReg_rule, // 284
  eFlagsReg_rule, // 285
  0, // 286
  0, // 287
  eFlagsRegU_rule, // 288
  eFlagsRegUCF_rule, // 289
  eFlagsRegU_rule, // 290
  eFlagsRegU_rule, // 291
  eFlagsRegUCF_rule, // 292
  eFlagsRegU_rule, // 293
  eFlagsRegUCF_rule, // 294
  regDPR1_rule, // 295
  regDPR1_rule, // 296
  eFlagsRegU_rule, // 297
  eFlagsRegUCF_rule, // 298
  eFlagsRegU_rule, // 299
  eFlagsRegU_rule, // 300
  eFlagsRegUCF_rule, // 301
  eFlagsRegU_rule, // 302
  eFlagsRegUCF_rule, // 303
  regFPR1_rule, // 304
  regFPR1_rule, // 305
  eRegI_rule, // 306
  eRegI_rule, // 307
  regFPR_rule, // 308
  regF_rule, // 309
  regF_rule, // 310
  eRegL_rule, // 311
  regDPR_rule, // 312
  regD_rule, // 313
  regD_rule, // 314
  eFlagsReg_rule, // 315
  eFlagsReg_rule, // 316
  eFlagsReg_rule, // 317
  eFlagsReg_rule, // 318
  eFlagsReg_rule, // 319
  eFlagsReg_rule, // 320
  eFlagsRegU_rule, // 321
  eFlagsRegU_rule, // 322
  eFlagsRegU_rule, // 323
  eFlagsRegU_rule, // 324
  eFlagsRegU_rule, // 325
  eFlagsRegU_rule, // 326
  eFlagsRegU_rule, // 327
  eFlagsRegU_rule, // 328
  eFlagsReg_rule, // 329
  eFlagsReg_rule, // 330
  eFlagsReg_rule, // 331
  flagsReg_long_LTGE_rule, // 332
  flagsReg_long_LTGE_rule, // 333
  flagsReg_long_EQNE_rule, // 334
  flagsReg_long_EQNE_rule, // 335
  flagsReg_long_LEGT_rule, // 336
  flagsReg_long_LEGT_rule, // 337
  eFlagsReg_rule, // 338
  eFlagsReg_rule, // 339
  Universe_rule, // 340
  regF_rule, // 341
  regF_rule, // 342
  regD_rule, // 343
  regD_rule, // 344
  regF_rule, // 345
  regF_rule, // 346
  regD_rule, // 347
  regD_rule, // 348
  eRegI_rule, // 349
  eRegL_rule, // 350
  eRegI_rule, // 351
  eRegI_rule, // 352
  eRegI_rule, // 353
  eRegI_rule, // 354
  eRegI_rule, // 355
  eRegI_rule, // 356
  eRegI_rule, // 357
  eRegI_rule, // 358
  eRegI_rule, // 359
  eRegI_rule, // 360
  eRegI_rule, // 361
  eRegI_rule, // 362
  xRegI_rule, // 363
  eRegL_rule, // 364
  xRegI_rule, // 365
  eRegL_rule, // 366
  eRegL_rule, // 367
  eRegI_rule, // 368
  eRegI_rule, // 369
  eRegL_rule, // 370
  eRegI_rule, // 371
  eRegI_rule, // 372
  eRegL_rule, // 373
  eRegL_rule, // 374
  eRegL_rule, // 375
  eRegI_rule, // 376
  eRegI_rule, // 377
  eRegI_rule, // 378
  eRegI_rule, // 379
  eRegI_rule, // 380
  eRegL_rule, // 381
  eRegL_rule, // 382
  eRegL_rule, // 383
  eRegL_rule, // 384
  eRegL_rule, // 385
  eRegL_rule, // 386
  stackSlotL_rule, // 387
  stackSlotL_rule, // 388
  eRegL_rule, // 389
  eRegI_rule, // 390
  eRegP_rule, // 391
  eRegP_rule, // 392
  regDPR_rule, // 393
  regD_rule, // 394
  regD_rule, // 395
  regF_rule, // 396
  regFPR_rule, // 397
  regD_rule, // 398
  regD_rule, // 399
  regD_rule, // 400
  regD_rule, // 401
  regD_rule, // 402
  Universe_rule, // 403
  Universe_rule, // 404
  Universe_rule, // 405
  Universe_rule, // 406
  Universe_rule, // 407
  Universe_rule, // 408
  Universe_rule, // 409
  Universe_rule, // 410
  Universe_rule, // 411
  Universe_rule, // 412
  Universe_rule, // 413
  Universe_rule, // 414
  Universe_rule, // 415
  Universe_rule, // 416
  Universe_rule, // 417
  Universe_rule, // 418
  Universe_rule, // 419
  Universe_rule, // 420
  Universe_rule, // 421
  Universe_rule, // 422
  Universe_rule, // 423
  Universe_rule, // 424
  Universe_rule, // 425
  Universe_rule, // 426
  Universe_rule, // 427
  Universe_rule, // 428
  Universe_rule, // 429
  Universe_rule, // 430
  Universe_rule, // 431
  Universe_rule, // 432
  Universe_rule, // 433
  Universe_rule, // 434
  Universe_rule, // 435
  Universe_rule, // 436
  Universe_rule, // 437
  Universe_rule, // 438
  Universe_rule, // 439
  Universe_rule, // 440
  Universe_rule, // 441
  Universe_rule, // 442
  Universe_rule, // 443
  Universe_rule, // 444
  Universe_rule, // 445
  Universe_rule, // 446
  Universe_rule, // 447
  Universe_rule, // 448
  eRegI_rule, // 449
  eRegI_rule, // 450
  eRegI_rule, // 451
  eRegI_rule, // 452
  eRegI_rule, // 453
  eRegI_rule, // 454
  eRegI_rule, // 455
  eRegI_rule, // 456
  eRegP_rule, // 457
  eRegP_rule, // 458
  eRegP_rule, // 459
  eRegP_rule, // 460
  regDPR1_rule, // 461
  regFPR1_rule, // 462
  regDPR_rule, // 463
  regFPR_rule, // 464
  regF_rule, // 465
  regD_rule, // 466
  regF_rule, // 467
  regF_rule, // 468
  regD_rule, // 469
  regD_rule, // 470
  eRegL_rule, // 471
  eRegL_rule, // 472
  eRegL_rule, // 473
  eRegI_rule, // 474
  eRegI_rule, // 475
  eRegI_rule, // 476
  eRegI_rule, // 477
  eRegP_rule, // 478
  eRegI_rule, // 479
  eRegP_rule, // 480
  eRegP_rule, // 481
  eRegI_rule, // 482
  eRegI_rule, // 483
  Universe_rule, // 484
  Universe_rule, // 485
  Universe_rule, // 486
  Universe_rule, // 487
  Universe_rule, // 488
  eRegP_rule, // 489
  stackSlotL_rule, // 490
  stackSlotL_rule, // 491
  eRegL_rule, // 492
  eRegI_rule, // 493
  eRegI_rule, // 494
  eRegI_rule, // 495
  eRegI_rule, // 496
  eRegI_rule, // 497
  eRegI_rule, // 498
  Universe_rule, // 499
  eRegP_rule, // 500
  eRegI_rule, // 501
  eRegI_rule, // 502
  eRegI_rule, // 503
  eDXRegI_rule, // 504
  eDXRegI_rule, // 505
  eDXRegI_rule, // 506
  eDXRegI_rule, // 507
  eRegI_rule, // 508
  eRegI_rule, // 509
  eRegI_rule, // 510
  eADXRegL_rule, // 511
  eADXRegL_rule, // 512
  eADXRegL_rule, // 513
  eADXRegL_rule, // 514
  eADXRegL_rule, // 515
  eADXRegL_rule, // 516
  eADXRegL_rule, // 517
  eADXRegL_rule, // 518
  eADXRegL_rule, // 519
  eAXRegI_rule, // 520
  eADXRegL_rule, // 521
  Universe_rule, // 522
  eDXRegI_rule, // 523
  eADXRegL_rule, // 524
  eADXRegL_rule, // 525
  eADXRegL_rule, // 526
  eRegI_rule, // 527
  eRegI_rule, // 528
  eRegI_rule, // 529
  eRegI_rule, // 530
  Universe_rule, // 531
  eRegI_rule, // 532
  Universe_rule, // 533
  eRegI_rule, // 534
  eRegI_rule, // 535
  eRegI_rule, // 536
  eRegI_rule, // 537
  eRegI_rule, // 538
  eRegI_rule, // 539
  eRegI_rule, // 540
  eRegI_rule, // 541
  eRegI_rule, // 542
  eRegI_rule, // 543
  Universe_rule, // 544
  Universe_rule, // 545
  Universe_rule, // 546
  eRegI_rule, // 547
  eRegI_rule, // 548
  eRegI_rule, // 549
  eRegI_rule, // 550
  eRegI_rule, // 551
  eRegI_rule, // 552
  Universe_rule, // 553
  Universe_rule, // 554
  Universe_rule, // 555
  0, // 556
  0, // 557
  0, // 558
  eRegI_rule, // 559
  eRegI_rule, // 560
  eRegI_rule, // 561
  eRegI_rule, // 562
  ncxRegI_rule, // 563
  ncxRegI_rule, // 564
  ncxRegI_rule, // 565
  ncxRegI_rule, // 566
  0, // 567
  0, // 568
  0, // 569
  eRegI_rule, // 570
  eRegI_rule, // 571
  eRegI_rule, // 572
  eRegI_rule, // 573
  ncxRegI_rule, // 574
  ncxRegI_rule, // 575
  ncxRegI_rule, // 576
  ncxRegI_rule, // 577
  eRegI_rule, // 578
  eRegI_rule, // 579
  eRegI_rule, // 580
  eRegI_rule, // 581
  eRegI_rule, // 582
  Universe_rule, // 583
  Universe_rule, // 584
  Universe_rule, // 585
  0, // 586
  eRegI_rule, // 587
  0, // 588
  eRegI_rule, // 589
  eCXRegI_rule, // 590
  eRegI_rule, // 591
  ncxRegI_rule, // 592
  ncxRegI_rule, // 593
  ncxRegI_rule, // 594
  ncxRegI_rule, // 595
  eRegL_rule, // 596
  eRegL_rule, // 597
  eRegL_rule, // 598
  eRegL_rule, // 599
  eRegL_rule, // 600
  eRegL_rule, // 601
  eRegL_rule, // 602
  eRegL_rule, // 603
  eRegL_rule, // 604
  eRegL_rule, // 605
  eRegL_rule, // 606
  eRegL_rule, // 607
  eRegL_rule, // 608
  eRegL_rule, // 609
  eRegL_rule, // 610
  eRegL_rule, // 611
  eRegL_rule, // 612
  eRegL_rule, // 613
  eRegL_rule, // 614
  eRegL_rule, // 615
  eRegL_rule, // 616
  eRegL_rule, // 617
  eRegL_rule, // 618
  eRegL_rule, // 619
  eRegL_rule, // 620
  eRegL_rule, // 621
  eRegL_rule, // 622
  eRegL_rule, // 623
  eRegL_rule, // 624
  eRegL_rule, // 625
  eRegL_rule, // 626
  eRegL_rule, // 627
  eRegL_rule, // 628
  eRegI_rule, // 629
  eRegI_rule, // 630
  xRegI_rule, // 631
  xRegI_rule, // 632
  regDPR_rule, // 633
  stackSlotD_rule, // 634
  regDPR_rule, // 635
  regDPR_rule, // 636
  stackSlotD_rule, // 637
  regDPR_rule, // 638
  regDPR_rule, // 639
  Universe_rule, // 640
  Universe_rule, // 641
  regDPR_rule, // 642
  regDPR_rule, // 643
  stackSlotD_rule, // 644
  regDPR_rule, // 645
  regDPR1_rule, // 646
  regDPR_rule, // 647
  regDPR_rule, // 648
  regDPR_rule, // 649
  regDPR_rule, // 650
  regDPR_rule, // 651
  regDPR_rule, // 652
  regDPR_rule, // 653
  regDPR_rule, // 654
  regDPR_rule, // 655
  regDPR1_rule, // 656
  stackSlotD_rule, // 657
  regDPR_rule, // 658
  regD_rule, // 659
  regDPR1_rule, // 660
  regD_rule, // 661
  regDPR1_rule, // 662
  regD_rule, // 663
  regDPR1_rule, // 664
  regD_rule, // 665
  regDPR_rule, // 666
  regD_rule, // 667
  regDPR_rule, // 668
  regDPR1_rule, // 669
  regD_rule, // 670
  regDPR1_rule, // 671
  regD_rule, // 672
  regDPR1_rule, // 673
  regD_rule, // 674
  regDPR1_rule, // 675
  regD_rule, // 676
  eRegI_rule, // 677
  eRegI_rule, // 678
  xRegI_rule, // 679
  xRegI_rule, // 680
  stackSlotF_rule, // 681
  regFPR_rule, // 682
  stackSlotF_rule, // 683
  regFPR_rule, // 684
  stackSlotF_rule, // 685
  stackSlotF_rule, // 686
  regFPR_rule, // 687
  regFPR_rule, // 688
  stackSlotF_rule, // 689
  stackSlotF_rule, // 690
  stackSlotF_rule, // 691
  stackSlotF_rule, // 692
  stackSlotF_rule, // 693
  regFPR_rule, // 694
  stackSlotF_rule, // 695
  regFPR_rule, // 696
  stackSlotF_rule, // 697
  stackSlotF_rule, // 698
  regFPR_rule, // 699
  regFPR_rule, // 700
  stackSlotF_rule, // 701
  stackSlotF_rule, // 702
  regFPR_rule, // 703
  regFPR_rule, // 704
  regFPR_rule, // 705
  regFPR_rule, // 706
  regFPR_rule, // 707
  regFPR_rule, // 708
  regFPR_rule, // 709
  regFPR_rule, // 710
  regFPR_rule, // 711
  regFPR_rule, // 712
  stackSlotF_rule, // 713
  regFPR_rule, // 714
  stackSlotF_rule, // 715
  regFPR_rule, // 716
  regF_rule, // 717
  stackSlotF_rule, // 718
  stackSlotD_rule, // 719
  stackSlotF_rule, // 720
  regF_rule, // 721
  regF_rule, // 722
  regDPR_rule, // 723
  stackSlotD_rule, // 724
  regDPR_rule, // 725
  regD_rule, // 726
  eAXRegI_rule, // 727
  eAXRegI_rule, // 728
  eADXRegL_rule, // 729
  eADXRegL_rule, // 730
  eAXRegI_rule, // 731
  eAXRegI_rule, // 732
  eADXRegL_rule, // 733
  eADXRegL_rule, // 734
  regDPR_rule, // 735
  regD_rule, // 736
  regD_rule, // 737
  regD_rule, // 738
  regDPR_rule, // 739
  regFPR_rule, // 740
  stackSlotF_rule, // 741
  stackSlotF_rule, // 742
  regFPR_rule, // 743
  regFPR_rule, // 744
  regF_rule, // 745
  regF_rule, // 746
  eRegL_rule, // 747
  eRegL_rule, // 748
  eRegL_rule, // 749
  stackSlotD_rule, // 750
  regD_rule, // 751
  regF_rule, // 752
  stackSlotF_rule, // 753
  eRegI_rule, // 754
  stackSlotI_rule, // 755
  stackSlotI_rule, // 756
  stackSlotF_rule, // 757
  stackSlotL_rule, // 758
  stackSlotL_rule, // 759
  eRegL_rule, // 760
  stackSlotD_rule, // 761
  regD_rule, // 762
  regD_rule, // 763
  regD_rule, // 764
  regD_rule, // 765
  regD_rule, // 766
  regD_rule, // 767
  regD_rule, // 768
  regD_rule, // 769
  regD_rule, // 770
  regD_rule, // 771
  regD_rule, // 772
  regD_rule, // 773
  regD_rule, // 774
  regD_rule, // 775
  regD_rule, // 776
  regD_rule, // 777
  Universe_rule, // 778
  eAXRegI_rule, // 779
  eAXRegI_rule, // 780
  eBXRegI_rule, // 781
  eBXRegI_rule, // 782
  eAXRegI_rule, // 783
  eRegI_rule, // 784
  eRegI_rule, // 785
  eAXRegI_rule, // 786
  Universe_rule, // 787
  Universe_rule, // 788
  Universe_rule, // 789
  Universe_rule, // 790
  Universe_rule, // 791
  Universe_rule, // 792
  Universe_rule, // 793
  Universe_rule, // 794
  Universe_rule, // 795
  eDIRegP_rule, // 796
  Universe_rule, // 797
  Universe_rule, // 798
  Universe_rule, // 799
  Universe_rule, // 800
  Universe_rule, // 801
  Universe_rule, // 802
  Universe_rule, // 803
  Universe_rule, // 804
  eSIRegI_rule, // 805
  Universe_rule, // 806
  eRegL_rule, // 807
  eRegL_rule, // 808
  eRegI_rule, // 809
  eRegI_rule, // 810
  eRegP_rule, // 811
  regDPR_rule, // 812
  regD_rule, // 813
  regFPR_rule, // 814
  regF_rule, // 815
  Universe_rule, // 816
  eRegL_rule, // 817
  eRegL_rule, // 818
  eRegI_rule, // 819
  eRegI_rule, // 820
  eRegP_rule, // 821
  regDPR_rule, // 822
  regD_rule, // 823
  regFPR_rule, // 824
  regF_rule, // 825
  Universe_rule, // 826
  eRegL_rule, // 827
  eRegL_rule, // 828
  eRegI_rule, // 829
  eRegI_rule, // 830
  eRegP_rule, // 831
  regDPR_rule, // 832
  regD_rule, // 833
  regFPR_rule, // 834
  regF_rule, // 835
  Universe_rule, // 836
  Universe_rule, // 837
  Universe_rule, // 838
  Universe_rule, // 839
  Universe_rule, // 840
  Universe_rule, // 841
  Universe_rule, // 842
  Universe_rule, // 843
  Universe_rule, // 844
  eAXRegP_rule, // 845
  Universe_rule, // 846
  eRegP_rule, // 847
  Universe_rule, // 848
  regF_rule, // 849
  regF_rule, // 850
  regF_rule, // 851
  regF_rule, // 852
  regF_rule, // 853
  regF_rule, // 854
  regF_rule, // 855
  regF_rule, // 856
  regD_rule, // 857
  regD_rule, // 858
  regD_rule, // 859
  regD_rule, // 860
  regD_rule, // 861
  regD_rule, // 862
  regD_rule, // 863
  regD_rule, // 864
  regF_rule, // 865
  regF_rule, // 866
  regF_rule, // 867
  regF_rule, // 868
  regF_rule, // 869
  regF_rule, // 870
  regD_rule, // 871
  regD_rule, // 872
  regD_rule, // 873
  regD_rule, // 874
  regD_rule, // 875
  regD_rule, // 876
  regF_rule, // 877
  regF_rule, // 878
  regF_rule, // 879
  regF_rule, // 880
  regF_rule, // 881
  regF_rule, // 882
  regF_rule, // 883
  regF_rule, // 884
  regD_rule, // 885
  regD_rule, // 886
  regD_rule, // 887
  regD_rule, // 888
  regD_rule, // 889
  regD_rule, // 890
  regD_rule, // 891
  regD_rule, // 892
  regF_rule, // 893
  regF_rule, // 894
  regF_rule, // 895
  regF_rule, // 896
  regF_rule, // 897
  regF_rule, // 898
  regD_rule, // 899
  regD_rule, // 900
  regD_rule, // 901
  regD_rule, // 902
  regD_rule, // 903
  regD_rule, // 904
  regF_rule, // 905
  regF_rule, // 906
  regF_rule, // 907
  regD_rule, // 908
  regD_rule, // 909
  regD_rule, // 910
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  0, // 0
  0, // 1
  0, // 2
  0, // 3
  0, // 4
  0, // 5
  0, // 6
  0, // 7
  0, // 8
  0, // 9
  0, // 10
  0, // 11
  0, // 12
  0, // 13
  0, // 14
  0, // 15
  0, // 16
  0, // 17
  0, // 18
  0, // 19
  0, // 20
  0, // 21
  0, // 22
  0, // 23
  0, // 24
  0, // 25
  0, // 26
  0, // 27
  0, // 28
  0, // 29
  0, // 30
  0, // 31
  0, // 32
  0, // 33
  0, // 34
  0, // 35
  0, // 36
  0, // 37
  0, // 38
  0, // 39
  0, // 40
  0, // 41
  0, // 42
  0, // 43
  0, // 44
  0, // 45
  0, // 46
  0, // 47
  0, // 48
  0, // 49
  0, // 50
  0, // 51
  0, // 52
  0, // 53
  0, // 54
  0, // 55
  0, // 56
  0, // 57
  0, // 58
  0, // 59
  0, // 60
  0, // 61
  0, // 62
  0, // 63
  0, // 64
  0, // 65
  0, // 66
  0, // 67
  0, // 68
  0, // 69
  0, // 70
  0, // 71
  0, // 72
  0, // 73
  0, // 74
  0, // 75
  0, // 76
  0, // 77
  0, // 78
  0, // 79
  0, // 80
  0, // 81
  0, // 82
  0, // 83
  0, // 84
  0, // 85
  0, // 86
  0, // 87
  eRegP_rule, // 88
  eRegP_rule, // 89
  immP_rule, // 90
  _AddP_eRegP_eRegI_rule, // 91
  eRegP_rule, // 92
  eRegP_rule, // 93
  _AddP_eRegP__LShiftI_eRegI_immI2_rule, // 94
  0, // 95
  0, // 96
  load_long_RegP_rule, // 97
  0, // 98
  0, // 99
  0, // 100
  0, // 101
  0, // 102
  0, // 103
  eRegP_no_EBP_rule, // 104
  eRegP_no_EBP_rule, // 105
  _AddP_eRegP_no_EBP_eRegI_rule, // 106
  eRegP_no_EBP_rule, // 107
  _AddP_eRegP_no_EBP__LShiftI_eRegI_immI2_rule, // 108
  0, // 109
  0, // 110
  0, // 111
  0, // 112
  0, // 113
  0, // 114
  // last operand
  0, // 115
  0, // 116
  0, // 117
  // last operand class
  eRegP_rule, // 118
  eRegI_rule, // 119
  eRegP_rule, // 120
  eRegP_no_EBP_rule, // 121
  eRegP_no_EBP_rule, // 122
  memory_rule, // 123
  memory_rule, // 124
  memory_rule, // 125
  memory_rule, // 126
  _LoadUB_memory__rule, // 127
  memory_rule, // 128
  _LoadS_memory__rule, // 129
  memory_rule, // 130
  _LoadUS_memory__rule, // 131
  _LoadUS_memory__rule, // 132
  _LoadUS_memory__rule, // 133
  _LoadI_memory__rule, // 134
  _LoadI_memory__rule, // 135
  _LoadI_memory__rule, // 136
  _LoadI_memory__rule, // 137
  _LoadI_memory__rule, // 138
  eRegL_rule, // 139
  regDPR1_rule, // 140
  regFPR1_rule, // 141
  regDPR1_rule, // 142
  cmpOp_rule, // 143
  eRegI_rule, // 144
  cmpOpU_rule, // 145
  cmpOpUCF_rule, // 146
  eRegI_rule, // 147
  eRegP_rule, // 148
  cmpOp_fcmov_rule, // 149
  regDPR1_rule, // 150
  regFPR1_rule, // 151
  regDPR_rule, // 152
  regFPR_rule, // 153
  regF_rule, // 154
  regD_rule, // 155
  eRegL_rule, // 156
  _LoadI_memory__rule, // 157
  eRegI_rule, // 158
  _LoadI_memory__rule, // 159
  _LoadI_memory__rule, // 160
  _LoadI_memory__rule, // 161
  eAXRegP_rule, // 162
  eAXRegI_rule, // 163
  eADXRegL_rule, // 164
  eAXRegP_rule, // 165
  eAXRegI_rule, // 166
  _LoadI_memory__rule, // 167
  immI0_rule, // 168
  nadxRegI_rule, // 169
  _ConvI2L_nadxRegI__rule, // 170
  _MulL__ConvI2L_nadxRegI__eADXRegL_low_only_rule, // 171
  eADXRegL_low_only_rule, // 172
  _MulL_eADXRegL_low_only__ConvI2L_nadxRegI__rule, // 173
  _MulL__ConvI2L_nadxRegI__eADXRegL_low_only_rule, // 174
  _MulL_eADXRegL_low_only__ConvI2L_nadxRegI__rule, // 175
  eAXRegI_rule, // 176
  _ConvI2L_eAXRegI__rule, // 177
  _ConvI2L_nadxRegI__rule, // 178
  _LoadI_memory__rule, // 179
  _LoadI_memory__rule, // 180
  xRegI_rule, // 181
  xRegI_rule, // 182
  _LoadI_memory__rule, // 183
  eRegI_rule, // 184
  eRegP_rule, // 185
  _LoadI_memory__rule, // 186
  eRegI_rule, // 187
  _LoadI_memory__rule, // 188
  eRegI_rule, // 189
  eRegI_rule, // 190
  eRegI_rule, // 191
  eRegI_rule, // 192
  ncxRegI_rule, // 193
  immI0_rule, // 194
  ncxRegI_rule, // 195
  immI_32_rule, // 196
  ncxRegI_rule, // 197
  eRegI_rule, // 198
  eRegI_rule, // 199
  ncxRegI_rule, // 200
  ncxRegI_rule, // 201
  ncxRegI_rule, // 202
  _LoadI_memory__rule, // 203
  eRegI_rule, // 204
  _LoadI_memory__rule, // 205
  ncxRegI_rule, // 206
  _CmpLTMask_ncxRegI_ncxRegI_rule, // 207
  ncxRegI_rule, // 208
  ncxRegI_rule, // 209
  load_long_memory_rule, // 210
  memory_rule, // 211
  regDPR_rule, // 212
  regDPR_rule, // 213
  _LoadD_memory__rule, // 214
  _AddD__LoadD_memory__regDPR_rule, // 215
  regDPR_rule, // 216
  _AddD_regDPR__LoadD_memory__rule, // 217
  regDPR_rule, // 218
  regDPR_rule, // 219
  regDPR_rule, // 220
  memory_rule, // 221
  _LoadF_memory__rule, // 222
  regFPR_rule, // 223
  regFPR_rule, // 224
  regFPR_rule, // 225
  eRegI_rule, // 226
  eDIRegP_rule, // 227
  eSIRegP_rule, // 228
  eDIRegP_rule, // 229
  eDIRegP_rule, // 230
  eSIRegP_rule, // 231
  eSIRegP_rule, // 232
  eRegI_rule, // 233
  eRegI_rule, // 234
  memory_rule, // 235
  nadxRegI_rule, // 236
  eSIRegP_rule, // 237
  cmpOp_rule, // 238
  eRegL_rule, // 239
  cmpOp_rule, // 240
  cmpOp_commute_rule, // 241
  regF_rule, // 242
  _ConvF2D_regF__rule, // 243
  _LoadF_memory__rule, // 244
  _ConvF2D__LoadF_memory___rule, // 245
  immF_rule, // 246
  _ConvF2D_immF__rule, // 247
  // last internally defined operand
  eRegI_rule, // 248
  eRegP_rule, // 249
  eRegL_rule, // 250
  indOffset8_rule, // 251
  indOffset32_rule, // 252
  indIndexOffset_rule, // 253
  indIndexScale_rule, // 254
  indIndexScaleOffset_rule, // 255
  immI_rule, // 256
  immI0_rule, // 257
  immP_rule, // 258
  immL_rule, // 259
  immL0_rule, // 260
  immFPR_rule, // 261
  immFPR0_rule, // 262
  immFPR1_rule, // 263
  immF_rule, // 264
  immF0_rule, // 265
  immDPR_rule, // 266
  immDPR0_rule, // 267
  immDPR1_rule, // 268
  immD_rule, // 269
  immD0_rule, // 270
  stackSlotI_rule, // 271
  stackSlotL_rule, // 272
  stackSlotP_rule, // 273
  stackSlotF_rule, // 274
  stackSlotD_rule, // 275
  immL32_rule, // 276
  0, // 277
  eAXRegI_rule, // 278
  eRegP_rule, // 279
  eRegP_rule, // 280
  eRegP_rule, // 281
  eRegI_rule, // 282
  memory_rule, // 283
  memory_rule, // 284
  memory_rule, // 285
  0, // 286
  0, // 287
  regDPR_rule, // 288
  regDPR_rule, // 289
  regDPR_rule, // 290
  regD_rule, // 291
  regD_rule, // 292
  regD_rule, // 293
  regD_rule, // 294
  regDPR1_rule, // 295
  regDPR1_rule, // 296
  regFPR_rule, // 297
  regFPR_rule, // 298
  regFPR_rule, // 299
  regF_rule, // 300
  regF_rule, // 301
  regF_rule, // 302
  regF_rule, // 303
  regFPR1_rule, // 304
  regFPR1_rule, // 305
  stackSlotF_rule, // 306
  regF_rule, // 307
  stackSlotI_rule, // 308
  stackSlotI_rule, // 309
  eRegI_rule, // 310
  stackSlotD_rule, // 311
  stackSlotL_rule, // 312
  stackSlotL_rule, // 313
  stackSlotL_rule, // 314
  eRegI_rule, // 315
  eRegI_rule, // 316
  eRegI_rule, // 317
  eRegI_rule, // 318
  _AndI_eRegI_immI_rule, // 319
  _AndI_eRegI_memory_rule, // 320
  eRegI_rule, // 321
  eRegI_rule, // 322
  eRegI_rule, // 323
  eRegI_rule, // 324
  eRegP_rule, // 325
  eRegP_rule, // 326
  eRegP_rule, // 327
  eRegP_rule, // 328
  eRegP_rule, // 329
  _LoadP_memory__rule, // 330
  _PartialSubtypeCheck_eSIRegP_eAXRegP_rule, // 331
  eRegL_rule, // 332
  eRegL_rule, // 333
  eRegL_rule, // 334
  eRegL_rule, // 335
  eRegL_rule, // 336
  eRegL_rule, // 337
  eRegP_rule, // 338
  eRegP_rule, // 339
  0, // 340
  regF_rule, // 341
  regF_rule, // 342
  regD_rule, // 343
  regD_rule, // 344
  regF_rule, // 345
  regF_rule, // 346
  regD_rule, // 347
  regD_rule, // 348
  eRegI_rule, // 349
  eRegL_rule, // 350
  eRegI_rule, // 351
  eRegI_rule, // 352
  eRegI_rule, // 353
  eRegI_rule, // 354
  eRegL_rule, // 355
  eRegL_rule, // 356
  eRegI_rule, // 357
  eRegL_rule, // 358
  eRegI_rule, // 359
  _LoadI_memory__rule, // 360
  eRegL_rule, // 361
  _LoadL_memory__rule, // 362
  memory_rule, // 363
  _LoadB_memory__rule, // 364
  memory_rule, // 365
  _LoadUB_memory__rule, // 366
  _AndI__LoadUB_memory__immI8_rule, // 367
  memory_rule, // 368
  _LShiftI__LoadS_memory__immI_24_rule, // 369
  _LoadS_memory__rule, // 370
  memory_rule, // 371
  _LShiftI__LoadUS_memory__immI_24_rule, // 372
  _LoadUS_memory__rule, // 373
  _AndI__LoadUS_memory__immI_255_rule, // 374
  _AndI__LoadUS_memory__immI16_rule, // 375
  memory_rule, // 376
  _LShiftI__LoadI_memory__immI_24_rule, // 377
  _LoadI_memory__rule, // 378
  _LShiftI__LoadI_memory__immI_16_rule, // 379
  _LoadI_memory__rule, // 380
  _LoadI_memory__rule, // 381
  _AndI__LoadI_memory__immI_255_rule, // 382
  _AndI__LoadI_memory__immI_65535_rule, // 383
  _AndI__LoadI_memory__immI_rule, // 384
  memory_rule, // 385
  load_long_memory_rule, // 386
  memory_rule, // 387
  memory_rule, // 388
  memory_rule, // 389
  memory_rule, // 390
  memory_rule, // 391
  memory_rule, // 392
  memory_rule, // 393
  memory_rule, // 394
  memory_rule, // 395
  memory_rule, // 396
  memory_rule, // 397
  memory_rule, // 398
  memory_rule, // 399
  memory_rule, // 400
  memory_rule, // 401
  memory_rule, // 402
  memory_rule, // 403
  memory_rule, // 404
  memory_rule, // 405
  memory_rule, // 406
  memory_rule, // 407
  memory_rule, // 408
  memory_rule, // 409
  memory_rule, // 410
  memory_rule, // 411
  memory_rule, // 412
  memory_rule, // 413
  memory_rule, // 414
  memory_rule, // 415
  memory_rule, // 416
  memory_rule, // 417
  memory_rule, // 418
  long_memory_rule, // 419
  memory_rule, // 420
  memory_rule, // 421
  memory_rule, // 422
  memory_rule, // 423
  memory_rule, // 424
  memory_rule, // 425
  memory_rule, // 426
  memory_rule, // 427
  memory_rule, // 428
  memory_rule, // 429
  memory_rule, // 430
  memory_rule, // 431
  memory_rule, // 432
  memory_rule, // 433
  memory_rule, // 434
  memory_rule, // 435
  memory_rule, // 436
  memory_rule, // 437
  memory_rule, // 438
  memory_rule, // 439
  memory_rule, // 440
  memory_rule, // 441
  memory_rule, // 442
  0, // 443
  0, // 444
  0, // 445
  0, // 446
  0, // 447
  0, // 448
  _Binary_cmpOp_eFlagsReg_rule, // 449
  _Binary_cmpOpU_eFlagsRegU_rule, // 450
  _Binary_cmpOp_eFlagsReg_rule, // 451
  _Binary_cmpOpU_eFlagsRegU_rule, // 452
  _Binary_cmpOpUCF_eFlagsRegUCF_rule, // 453
  _Binary_cmpOp_eFlagsReg_rule, // 454
  _Binary_cmpOpU_eFlagsRegU_rule, // 455
  _Binary_cmpOpUCF_eFlagsRegUCF_rule, // 456
  _Binary_cmpOp_eFlagsReg_rule, // 457
  _Binary_cmpOp_eFlagsReg_rule, // 458
  _Binary_cmpOpU_eFlagsRegU_rule, // 459
  _Binary_cmpOpUCF_eFlagsRegUCF_rule, // 460
  _Binary_cmpOp_fcmov_eFlagsRegU_rule, // 461
  _Binary_cmpOp_fcmov_eFlagsRegU_rule, // 462
  _Binary_cmpOp_eFlagsReg_rule, // 463
  _Binary_cmpOp_eFlagsReg_rule, // 464
  _Binary_cmpOp_eFlagsReg_rule, // 465
  _Binary_cmpOp_eFlagsReg_rule, // 466
  _Binary_cmpOpU_eFlagsRegU_rule, // 467
  _Binary_cmpOpUCF_eFlagsRegUCF_rule, // 468
  _Binary_cmpOpU_eFlagsRegU_rule, // 469
  _Binary_cmpOpUCF_eFlagsRegUCF_rule, // 470
  _Binary_cmpOp_eFlagsReg_rule, // 471
  _Binary_cmpOpU_eFlagsRegU_rule, // 472
  _Binary_cmpOpUCF_eFlagsRegUCF_rule, // 473
  eRegI_rule, // 474
  eRegI_rule, // 475
  eRegI_rule, // 476
  eRegI_rule, // 477
  eRegP_rule, // 478
  eRegI_rule, // 479
  eRegP_rule, // 480
  eRegP_rule, // 481
  eRegI_rule, // 482
  _LoadI_memory__rule, // 483
  memory_rule, // 484
  memory_rule, // 485
  memory_rule, // 486
  memory_rule, // 487
  memory_rule, // 488
  memory_rule, // 489
  memory_rule, // 490
  memory_rule, // 491
  memory_rule, // 492
  eSIRegP_rule, // 493
  pRegP_rule, // 494
  pRegP_rule, // 495
  eRegI_rule, // 496
  eRegI_rule, // 497
  eRegI_rule, // 498
  memory_rule, // 499
  eRegP_rule, // 500
  immI0_rule, // 501
  eRegI_rule, // 502
  eRegI_rule, // 503
  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_rule, // 504
  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_rule, // 505
  _RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_63_rule, // 506
  _RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_63_rule, // 507
  _LoadI_memory__rule, // 508
  eRegI_rule, // 509
  _LoadI_memory__rule, // 510
  _ConvI2L_eAXRegI__rule, // 511
  _ConvI2L_nadxRegI__rule, // 512
  _AndL__ConvI2L_eAXRegI__immL_32bits_rule, // 513
  _AndL__ConvI2L_nadxRegI__immL_32bits_rule, // 514
  eADXRegL_rule, // 515
  eADXRegL_rule, // 516
  eADXRegL_rule, // 517
  eADXRegL_rule, // 518
  eADXRegL_rule, // 519
  eAXRegI_rule, // 520
  eRegL_rule, // 521
  eAXRegI_rule, // 522
  eAXRegI_rule, // 523
  eRegL_rule, // 524
  eADXRegL_rule, // 525
  eADXRegL_rule, // 526
  eRegI_rule, // 527
  eRegI_rule, // 528
  eRegI_rule, // 529
  eRegI_rule, // 530
  memory_rule, // 531
  eRegI_rule, // 532
  memory_rule, // 533
  eRegI_rule, // 534
  eRegI_rule, // 535
  eRegI_rule, // 536
  _LShiftI_xRegI_immI_24_rule, // 537
  _LShiftI_xRegI_immI_16_rule, // 538
  eRegI_rule, // 539
  eRegI_rule, // 540
  eRegI_rule, // 541
  eRegI_rule, // 542
  _LoadI_memory__rule, // 543
  memory_rule, // 544
  memory_rule, // 545
  memory_rule, // 546
  eRegI_rule, // 547
  eRegI_rule, // 548
  _CastP2X_eRegP__rule, // 549
  eRegI_rule, // 550
  eRegI_rule, // 551
  _LoadI_memory__rule, // 552
  memory_rule, // 553
  memory_rule, // 554
  memory_rule, // 555
  0, // 556
  0, // 557
  0, // 558
  _LShiftI_eRegI_immI1_rule, // 559
  _URShiftI_eRegI_immI_M1_rule, // 560
  _LShiftI_eRegI_immI8_rule, // 561
  _URShiftI_eRegI_immI8_rule, // 562
  _LShiftI_ncxRegI_eCXRegI_rule, // 563
  _URShiftI_ncxRegI__SubI_immI0_eCXRegI_rule, // 564
  _LShiftI_ncxRegI_eCXRegI_rule, // 565
  _URShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule, // 566
  0, // 567
  0, // 568
  0, // 569
  _URShiftI_eRegI_immI1_rule, // 570
  _LShiftI_eRegI_immI_M1_rule, // 571
  _URShiftI_eRegI_immI8_rule, // 572
  _LShiftI_eRegI_immI8_rule, // 573
  _URShiftI_ncxRegI_eCXRegI_rule, // 574
  _LShiftI_ncxRegI__SubI_immI0_eCXRegI_rule, // 575
  _URShiftI_ncxRegI_eCXRegI_rule, // 576
  _LShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule, // 577
  eRegI_rule, // 578
  eRegI_rule, // 579
  eRegI_rule, // 580
  eRegI_rule, // 581
  _LoadI_memory__rule, // 582
  memory_rule, // 583
  memory_rule, // 584
  memory_rule, // 585
  0, // 586
  eRegI_rule, // 587
  0, // 588
  eRegP_rule, // 589
  ncxRegI_rule, // 590
  eRegI_rule, // 591
  _AndI__CmpLTMask_ncxRegI_ncxRegI_ncxRegI_rule, // 592
  _SubI_ncxRegI_ncxRegI_rule, // 593
  _AndI_ncxRegI__CmpLTMask_ncxRegI_ncxRegI_rule, // 594
  _SubI_ncxRegI_ncxRegI_rule, // 595
  eRegL_rule, // 596
  eRegL_rule, // 597
  eRegL_rule, // 598
  _LoadL_load_long_memory__rule, // 599
  eRegL_rule, // 600
  eRegL_rule, // 601
  eRegL_rule, // 602
  immL0_rule, // 603
  eRegL_rule, // 604
  eRegL_rule, // 605
  eRegL_rule, // 606
  _LoadL_load_long_memory__rule, // 607
  eRegL_rule, // 608
  eRegL_rule, // 609
  eRegL_rule, // 610
  _LoadL_load_long_memory__rule, // 611
  eRegL_rule, // 612
  eRegL_rule, // 613
  eRegL_rule, // 614
  eRegL_rule, // 615
  _LoadL_load_long_memory__rule, // 616
  eRegL_rule, // 617
  eRegL_rule, // 618
  eRegL_rule, // 619
  eRegL_rule, // 620
  eRegL_rule, // 621
  eRegL_rule, // 622
  eRegL_rule, // 623
  eRegL_rule, // 624
  eRegL_rule, // 625
  eRegL_rule, // 626
  eRegL_rule, // 627
  eRegL_rule, // 628
  regDPR_rule, // 629
  regDPR_rule, // 630
  regD_rule, // 631
  regD_rule, // 632
  regDPR_rule, // 633
  _SubD_regDPR_regDPR_rule, // 634
  regDPR_rule, // 635
  regDPR_rule, // 636
  _AddD_regDPR_regDPR_rule, // 637
  regDPR_rule, // 638
  _LoadD_memory__rule, // 639
  memory_rule, // 640
  memory_rule, // 641
  regDPR_rule, // 642
  regDPR_rule, // 643
  _AddD_regDPR_immDPR_rule, // 644
  regDPR_rule, // 645
  regDPR1_rule, // 646
  regDPR_rule, // 647
  regDPR_rule, // 648
  _LoadD_memory__rule, // 649
  regDPR_rule, // 650
  _LoadD_memory__rule, // 651
  _MulD_regDPR_regDPR_rule, // 652
  regDPR_rule, // 653
  _MulD_regDPR_regDPR_rule, // 654
  regDPR_rule, // 655
  regDPR1_rule, // 656
  _DivD_regDPR_regDPR_rule, // 657
  regDPR_rule, // 658
  regD_rule, // 659
  regDPR1_rule, // 660
  regD_rule, // 661
  regDPR1_rule, // 662
  regD_rule, // 663
  regDPR1_rule, // 664
  regD_rule, // 665
  regDPR_rule, // 666
  regD_rule, // 667
  regDPR_rule, // 668
  regDPR_rule, // 669
  regD_rule, // 670
  regDPR1_rule, // 671
  regD_rule, // 672
  regDPR1_rule, // 673
  regD_rule, // 674
  regDPR1_rule, // 675
  regD_rule, // 676
  regFPR_rule, // 677
  regFPR_rule, // 678
  regF_rule, // 679
  regF_rule, // 680
  regFPR_rule, // 681
  regFPR_rule, // 682
  regFPR_rule, // 683
  regFPR_rule, // 684
  regFPR_rule, // 685
  _LoadF_memory__rule, // 686
  regFPR_rule, // 687
  _LoadF_memory__rule, // 688
  memory_rule, // 689
  memory_rule, // 690
  _LoadF_memory__rule, // 691
  memory_rule, // 692
  regFPR_rule, // 693
  regFPR_rule, // 694
  regFPR_rule, // 695
  regFPR_rule, // 696
  regFPR_rule, // 697
  _LoadF_memory__rule, // 698
  regFPR_rule, // 699
  _LoadF_memory__rule, // 700
  memory_rule, // 701
  regFPR_rule, // 702
  regFPR_rule, // 703
  _LoadF_memory__rule, // 704
  regFPR_rule, // 705
  _MulF__LoadF_memory__regFPR_rule, // 706
  regFPR_rule, // 707
  _MulF_regFPR__LoadF_memory__rule, // 708
  regFPR_rule, // 709
  _MulF_regFPR_regFPR_rule, // 710
  regFPR_rule, // 711
  _SubF_regFPR_regFPR_rule, // 712
  regFPR_rule, // 713
  regFPR_rule, // 714
  regFPR_rule, // 715
  regFPR_rule, // 716
  regF_rule, // 717
  regFPR_rule, // 718
  regDPR_rule, // 719
  regDPR_rule, // 720
  regDPR_rule, // 721
  regD_rule, // 722
  regFPR_rule, // 723
  regFPR_rule, // 724
  regF_rule, // 725
  regF_rule, // 726
  regDPR_rule, // 727
  regD_rule, // 728
  regDPR_rule, // 729
  regD_rule, // 730
  regFPR_rule, // 731
  regF_rule, // 732
  regFPR_rule, // 733
  regF_rule, // 734
  stackSlotI_rule, // 735
  eRegI_rule, // 736
  _LoadI_memory__rule, // 737
  eRegI_rule, // 738
  _LoadI_memory__rule, // 739
  stackSlotI_rule, // 740
  stackSlotI_rule, // 741
  _LoadI_memory__rule, // 742
  stackSlotI_rule, // 743
  _LoadI_memory__rule, // 744
  eRegI_rule, // 745
  eRegI_rule, // 746
  eRegI_rule, // 747
  _ConvI2L_eRegI__rule, // 748
  eRegL_rule, // 749
  eRegL_rule, // 750
  eRegL_rule, // 751
  eRegL_rule, // 752
  eRegL_rule, // 753
  eRegL_rule, // 754
  regFPR_rule, // 755
  regF_rule, // 756
  eRegI_rule, // 757
  regDPR_rule, // 758
  regD_rule, // 759
  regD_rule, // 760
  eRegL_rule, // 761
  eRegL_rule, // 762
  regD_rule, // 763
  eRegI_rule, // 764
  immI0_rule, // 765
  regD_rule, // 766
  eRegI_rule, // 767
  immI0_rule, // 768
  regD_rule, // 769
  eRegI_rule, // 770
  immI0_rule, // 771
  regD_rule, // 772
  eRegI_rule, // 773
  immI0_rule, // 774
  regD_rule, // 775
  regF_rule, // 776
  immF0_rule, // 777
  eCXRegI_rule, // 778
  _Binary_eDIRegP_eCXRegI_rule, // 779
  _Binary_eDIRegP_eSIRegP_rule, // 780
  _Binary_eDIRegP_eDXRegI_rule, // 781
  _Binary_eDIRegP_eDXRegI_rule, // 782
  eDIRegP_rule, // 783
  eRegI_rule, // 784
  eRegI_rule, // 785
  _Binary_nadxRegI_eAXRegI_rule, // 786
  eRegI_rule, // 787
  0, // 788
  cmpOp_rule, // 789
  cmpOp_rule, // 790
  cmpOpU_rule, // 791
  cmpOpUCF_rule, // 792
  cmpOpU_rule, // 793
  cmpOpUCF_rule, // 794
  cmpOpUCF2_rule, // 795
  eSIRegP_rule, // 796
  0, // 797
  cmpOp_rule, // 798
  cmpOp_rule, // 799
  cmpOpU_rule, // 800
  cmpOpUCF_rule, // 801
  cmpOpU_rule, // 802
  cmpOpUCF_rule, // 803
  cmpOpUCF2_rule, // 804
  eRegL_rule, // 805
  cmpOp_rule, // 806
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 807
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 808
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 809
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 810
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 811
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 812
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 813
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 814
  _Binary_cmpOp_flagsReg_long_LTGE_rule, // 815
  cmpOp_rule, // 816
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 817
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 818
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 819
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 820
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 821
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 822
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 823
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 824
  _Binary_cmpOp_flagsReg_long_EQNE_rule, // 825
  cmpOp_commute_rule, // 826
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 827
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 828
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 829
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 830
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 831
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 832
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 833
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 834
  _Binary_cmpOp_commute_flagsReg_long_LEGT_rule, // 835
  0, // 836
  0, // 837
  0, // 838
  0, // 839
  0, // 840
  0, // 841
  0, // 842
  eRegP_no_EBP_rule, // 843
  eRegP_no_EBP_rule, // 844
  0, // 845
  0, // 846
  0, // 847
  0, // 848
  regF_rule, // 849
  regF_rule, // 850
  _LoadF_memory__rule, // 851
  regF_rule, // 852
  regF_rule, // 853
  regF_rule, // 854
  _LoadF_memory__rule, // 855
  regF_rule, // 856
  regD_rule, // 857
  regD_rule, // 858
  _LoadD_memory__rule, // 859
  regD_rule, // 860
  regD_rule, // 861
  regD_rule, // 862
  _LoadD_memory__rule, // 863
  regD_rule, // 864
  regF_rule, // 865
  regF_rule, // 866
  regF_rule, // 867
  regF_rule, // 868
  regF_rule, // 869
  regF_rule, // 870
  regD_rule, // 871
  regD_rule, // 872
  regD_rule, // 873
  regD_rule, // 874
  regD_rule, // 875
  regD_rule, // 876
  regF_rule, // 877
  regF_rule, // 878
  _LoadF_memory__rule, // 879
  regF_rule, // 880
  regF_rule, // 881
  regF_rule, // 882
  _LoadF_memory__rule, // 883
  regF_rule, // 884
  regD_rule, // 885
  regD_rule, // 886
  _LoadD_memory__rule, // 887
  regD_rule, // 888
  regD_rule, // 889
  regD_rule, // 890
  _LoadD_memory__rule, // 891
  regD_rule, // 892
  regF_rule, // 893
  regF_rule, // 894
  regF_rule, // 895
  regF_rule, // 896
  regF_rule, // 897
  regF_rule, // 898
  regD_rule, // 899
  regD_rule, // 900
  regD_rule, // 901
  regD_rule, // 902
  regD_rule, // 903
  regD_rule, // 904
  _SqrtD__ConvF2D_regF___rule, // 905
  _SqrtD__ConvF2D__LoadF_memory____rule, // 906
  _SqrtD__ConvF2D_immF___rule, // 907
  regD_rule, // 908
  _LoadD_memory__rule, // 909
  immD_rule, // 910
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  0, // 0
  0, // 1
  0, // 2
  0, // 3
  0, // 4
  0, // 5
  0, // 6
  0, // 7
  0, // 8
  0, // 9
  0, // 10
  0, // 11
  0, // 12
  0, // 13
  0, // 14
  0, // 15
  0, // 16
  0, // 17
  0, // 18
  0, // 19
  0, // 20
  0, // 21
  0, // 22
  0, // 23
  0, // 24
  0, // 25
  0, // 26
  0, // 27
  0, // 28
  0, // 29
  0, // 30
  0, // 31
  0, // 32
  0, // 33
  0, // 34
  0, // 35
  0, // 36
  0, // 37
  0, // 38
  0, // 39
  0, // 40
  0, // 41
  0, // 42
  0, // 43
  0, // 44
  0, // 45
  0, // 46
  0, // 47
  0, // 48
  0, // 49
  0, // 50
  0, // 51
  0, // 52
  0, // 53
  0, // 54
  0, // 55
  0, // 56
  0, // 57
  0, // 58
  0, // 59
  0, // 60
  0, // 61
  0, // 62
  0, // 63
  0, // 64
  0, // 65
  0, // 66
  0, // 67
  0, // 68
  0, // 69
  0, // 70
  0, // 71
  0, // 72
  0, // 73
  0, // 74
  0, // 75
  0, // 76
  0, // 77
  0, // 78
  0, // 79
  0, // 80
  0, // 81
  0, // 82
  0, // 83
  0, // 84
  0, // 85
  0, // 86
  0, // 87
  immI8_rule, // 88
  immI_rule, // 89
  eRegI_rule, // 90
  immI_rule, // 91
  eRegI_rule, // 92
  _LShiftI_eRegI_immI2_rule, // 93
  immI_rule, // 94
  0, // 95
  0, // 96
  immI_rule, // 97
  0, // 98
  0, // 99
  0, // 100
  0, // 101
  0, // 102
  0, // 103
  immI8_rule, // 104
  immI_rule, // 105
  immI_rule, // 106
  _LShiftI_eRegI_immI2_rule, // 107
  immI_rule, // 108
  0, // 109
  0, // 110
  0, // 111
  0, // 112
  0, // 113
  0, // 114
  // last operand
  0, // 115
  0, // 116
  0, // 117
  // last operand class
  eRegI_rule, // 118
  immI2_rule, // 119
  _LShiftI_eRegI_immI2_rule, // 120
  eRegI_rule, // 121
  _LShiftI_eRegI_immI2_rule, // 122
  0, // 123
  0, // 124
  0, // 125
  0, // 126
  immI8_rule, // 127
  0, // 128
  immI_24_rule, // 129
  0, // 130
  immI_24_rule, // 131
  immI_255_rule, // 132
  immI16_rule, // 133
  immI_24_rule, // 134
  immI_16_rule, // 135
  immI_255_rule, // 136
  immI_65535_rule, // 137
  immI_rule, // 138
  0, // 139
  0, // 140
  0, // 141
  0, // 142
  eFlagsReg_rule, // 143
  eRegI_rule, // 144
  eFlagsRegU_rule, // 145
  eFlagsRegUCF_rule, // 146
  _LoadI_memory__rule, // 147
  eRegP_rule, // 148
  eFlagsRegU_rule, // 149
  regDPR_rule, // 150
  regFPR_rule, // 151
  regDPR_rule, // 152
  regFPR_rule, // 153
  regF_rule, // 154
  regD_rule, // 155
  eRegL_rule, // 156
  eRegI_rule, // 157
  _LoadI_memory__rule, // 158
  immI_rule, // 159
  immI1_rule, // 160
  immI_M1_rule, // 161
  eRegP_rule, // 162
  eRegI_rule, // 163
  eBCXRegL_rule, // 164
  eCXRegP_rule, // 165
  eCXRegI_rule, // 166
  eRegI_rule, // 167
  eRegI_rule, // 168
  0, // 169
  eADXRegL_low_only_rule, // 170
  immI_32_rule, // 171
  _ConvI2L_nadxRegI__rule, // 172
  immI_32_rule, // 173
  immI_32_63_rule, // 174
  immI_32_63_rule, // 175
  0, // 176
  immL_32bits_rule, // 177
  immL_32bits_rule, // 178
  immI1_rule, // 179
  immI8_rule, // 180
  immI_24_rule, // 181
  immI_16_rule, // 182
  eRegI_rule, // 183
  _LoadI_memory__rule, // 184
  0, // 185
  eRegI_rule, // 186
  _LoadI_memory__rule, // 187
  immI_rule, // 188
  immI1_rule, // 189
  immI_M1_rule, // 190
  immI8_rule, // 191
  immI8_rule, // 192
  eCXRegI_rule, // 193
  eCXRegI_rule, // 194
  _SubI_immI0_eCXRegI_rule, // 195
  eCXRegI_rule, // 196
  _SubI_immI_32_eCXRegI_rule, // 197
  immI1_rule, // 198
  immI_M1_rule, // 199
  eCXRegI_rule, // 200
  _SubI_immI0_eCXRegI_rule, // 201
  _SubI_immI_32_eCXRegI_rule, // 202
  eRegI_rule, // 203
  _LoadI_memory__rule, // 204
  immI_rule, // 205
  ncxRegI_rule, // 206
  ncxRegI_rule, // 207
  ncxRegI_rule, // 208
  _CmpLTMask_ncxRegI_ncxRegI_rule, // 209
  0, // 210
  0, // 211
  regDPR_rule, // 212
  regDPR_rule, // 213
  regDPR_rule, // 214
  0, // 215
  _LoadD_memory__rule, // 216
  0, // 217
  immDPR_rule, // 218
  regDPR_rule, // 219
  regDPR_rule, // 220
  0, // 221
  regFPR_rule, // 222
  _LoadF_memory__rule, // 223
  regFPR_rule, // 224
  regFPR_rule, // 225
  0, // 226
  eCXRegI_rule, // 227
  eDXRegI_rule, // 228
  eSIRegP_rule, // 229
  eDXRegI_rule, // 230
  immI_rule, // 231
  eAXRegI_rule, // 232
  immI_rule, // 233
  memory_rule, // 234
  0, // 235
  eAXRegI_rule, // 236
  eAXRegP_rule, // 237
  flagsReg_long_LTGE_rule, // 238
  _LoadL_load_long_memory__rule, // 239
  flagsReg_long_EQNE_rule, // 240
  flagsReg_long_LEGT_rule, // 241
  0, // 242
  0, // 243
  0, // 244
  0, // 245
  0, // 246
  0, // 247
  // last internally defined operand
  0, // 248
  0, // 249
  0, // 250
  0, // 251
  0, // 252
  0, // 253
  0, // 254
  0, // 255
  0, // 256
  0, // 257
  0, // 258
  0, // 259
  0, // 260
  0, // 261
  0, // 262
  0, // 263
  0, // 264
  0, // 265
  0, // 266
  0, // 267
  0, // 268
  0, // 269
  0, // 270
  0, // 271
  0, // 272
  0, // 273
  0, // 274
  0, // 275
  0, // 276
  0, // 277
  0, // 278
  0, // 279
  0, // 280
  0, // 281
  0, // 282
  _Binary_eAXRegP_eRegP_rule, // 283
  _Binary_eAXRegI_eRegI_rule, // 284
  _Binary_eADXRegL_eBCXRegL_rule, // 285
  0, // 286
  0, // 287
  regDPR_rule, // 288
  regDPR_rule, // 289
  regDPR_rule, // 290
  regD_rule, // 291
  regD_rule, // 292
  _LoadD_memory__rule, // 293
  _LoadD_memory__rule, // 294
  0, // 295
  0, // 296
  regFPR_rule, // 297
  regFPR_rule, // 298
  regFPR_rule, // 299
  regF_rule, // 300
  regF_rule, // 301
  _LoadF_memory__rule, // 302
  _LoadF_memory__rule, // 303
  0, // 304
  0, // 305
  0, // 306
  0, // 307
  0, // 308
  0, // 309
  0, // 310
  0, // 311
  0, // 312
  0, // 313
  0, // 314
  eRegI_rule, // 315
  immI_rule, // 316
  _LoadI_memory__rule, // 317
  immI0_rule, // 318
  immI0_rule, // 319
  immI0_rule, // 320
  eRegI_rule, // 321
  immI_rule, // 322
  _LoadI_memory__rule, // 323
  immI0_rule, // 324
  eRegP_rule, // 325
  immP_rule, // 326
  _LoadP_memory__rule, // 327
  _LoadP_memory__rule, // 328
  immP0_rule, // 329
  immI0_rule, // 330
  immP0_rule, // 331
  immL0_rule, // 332
  eRegL_rule, // 333
  immL0_rule, // 334
  eRegL_rule, // 335
  immL0_rule, // 336
  eRegL_rule, // 337
  eBXRegP_rule, // 338
  eAXRegP_rule, // 339
  0, // 340
  0, // 341
  0, // 342
  0, // 343
  0, // 344
  0, // 345
  0, // 346
  0, // 347
  0, // 348
  0, // 349
  0, // 350
  0, // 351
  0, // 352
  0, // 353
  0, // 354
  0, // 355
  0, // 356
  0, // 357
  0, // 358
  0, // 359
  0, // 360
  0, // 361
  0, // 362
  0, // 363
  0, // 364
  0, // 365
  0, // 366
  0, // 367
  0, // 368
  immI_24_rule, // 369
  0, // 370
  0, // 371
  immI_24_rule, // 372
  0, // 373
  0, // 374
  0, // 375
  0, // 376
  immI_24_rule, // 377
  immI_255_rule, // 378
  immI_16_rule, // 379
  immI_65535_rule, // 380
  0, // 381
  0, // 382
  0, // 383
  0, // 384
  0, // 385
  0, // 386
  0, // 387
  0, // 388
  0, // 389
  0, // 390
  0, // 391
  0, // 392
  0, // 393
  0, // 394
  0, // 395
  0, // 396
  0, // 397
  0, // 398
  0, // 399
  0, // 400
  0, // 401
  0, // 402
  0, // 403
  0, // 404
  0, // 405
  0, // 406
  0, // 407
  0, // 408
  0, // 409
  0, // 410
  0, // 411
  0, // 412
  0, // 413
  0, // 414
  0, // 415
  xRegI_rule, // 416
  eRegI_rule, // 417
  eRegI_rule, // 418
  eRegL_rule, // 419
  _ConvL2I_eRegL__rule, // 420
  stackSlotL_rule, // 421
  stackSlotL_rule, // 422
  eRegL_rule, // 423
  anyRegP_rule, // 424
  immI_rule, // 425
  immI16_rule, // 426
  immP_rule, // 427
  immI8_rule, // 428
  regD_rule, // 429
  regD_rule, // 430
  regD_rule, // 431
  immI8_rule, // 432
  regDPR1_rule, // 433
  _RoundDouble_regDPR1__rule, // 434
  regD_rule, // 435
  regF_rule, // 436
  regD_rule, // 437
  regFPR1_rule, // 438
  _RoundFloat_regFPR1__rule, // 439
  _ConvD2F_regDPR1__rule, // 440
  immFPR_rule, // 441
  immF_rule, // 442
  0, // 443
  0, // 444
  0, // 445
  0, // 446
  0, // 447
  0, // 448
  _Binary_eRegI_eRegI_rule, // 449
  _Binary_eRegI_eRegI_rule, // 450
  _Binary_eRegI_eRegI_rule, // 451
  _Binary_eRegI_eRegI_rule, // 452
  _Binary_eRegI_eRegI_rule, // 453
  _Binary_eRegI__LoadI_memory__rule, // 454
  _Binary_eRegI__LoadI_memory__rule, // 455
  _Binary_eRegI__LoadI_memory__rule, // 456
  _Binary_eRegP_eRegP_rule, // 457
  _Binary_eRegP_eRegP_rule, // 458
  _Binary_eRegP_eRegP_rule, // 459
  _Binary_eRegP_eRegP_rule, // 460
  _Binary_regDPR1_regDPR_rule, // 461
  _Binary_regFPR1_regFPR_rule, // 462
  _Binary_regDPR_regDPR_rule, // 463
  _Binary_regFPR_regFPR_rule, // 464
  _Binary_regF_regF_rule, // 465
  _Binary_regD_regD_rule, // 466
  _Binary_regF_regF_rule, // 467
  _Binary_regF_regF_rule, // 468
  _Binary_regD_regD_rule, // 469
  _Binary_regD_regD_rule, // 470
  _Binary_eRegL_eRegL_rule, // 471
  _Binary_eRegL_eRegL_rule, // 472
  _Binary_eRegL_eRegL_rule, // 473
  eRegI_rule, // 474
  immI_rule, // 475
  immI1_rule, // 476
  immI_rule, // 477
  immI_rule, // 478
  immI_M1_rule, // 479
  eRegI_rule, // 480
  immI_rule, // 481
  _LoadI_memory__rule, // 482
  eRegI_rule, // 483
  _AddI__LoadI_memory__eRegI_rule, // 484
  _AddI_eRegI__LoadI_memory__rule, // 485
  _AddI__LoadI_memory__immI_rule, // 486
  _AddI__LoadI_memory__immI1_rule, // 487
  _AddI__LoadI_memory__immI_M1_rule, // 488
  0, // 489
  0, // 490
  0, // 491
  0, // 492
  _Binary_eADXRegL_eBCXRegL_rule, // 493
  _Binary_eAXRegP_eCXRegP_rule, // 494
  _Binary_eAXRegI_eCXRegI_rule, // 495
  eRegI_rule, // 496
  immI_rule, // 497
  _LoadI_memory__rule, // 498
  _SubI__LoadI_memory__eRegI_rule, // 499
  _SubI_immI0_eRegI_rule, // 500
  eRegI_rule, // 501
  eRegI_rule, // 502
  immI_rule, // 503
  0, // 504
  0, // 505
  0, // 506
  0, // 507
  immI_rule, // 508
  _LoadI_memory__rule, // 509
  eRegI_rule, // 510
  _ConvI2L_nadxRegI__rule, // 511
  _ConvI2L_eAXRegI__rule, // 512
  _AndL__ConvI2L_nadxRegI__immL_32bits_rule, // 513
  _AndL__ConvI2L_eAXRegI__immL_32bits_rule, // 514
  eRegL_rule, // 515
  eRegL_rule, // 516
  eRegL_rule, // 517
  eRegL_rule, // 518
  immL_127_rule, // 519
  eCXRegI_rule, // 520
  eRegL_rule, // 521
  eCXRegI_rule, // 522
  eCXRegI_rule, // 523
  eRegL_rule, // 524
  immL32_rule, // 525
  immL32_rule, // 526
  immI1_rule, // 527
  immI8_rule, // 528
  eCXRegI_rule, // 529
  immI1_rule, // 530
  _RShiftI__LoadI_memory__immI1_rule, // 531
  immI8_rule, // 532
  _RShiftI__LoadI_memory__immI8_rule, // 533
  eCXRegI_rule, // 534
  immI1_rule, // 535
  immI8_rule, // 536
  immI_24_rule, // 537
  immI_16_rule, // 538
  eCXRegI_rule, // 539
  eRegI_rule, // 540
  immI_rule, // 541
  _LoadI_memory__rule, // 542
  eRegI_rule, // 543
  _AndI__LoadI_memory__eRegI_rule, // 544
  _AndI_eRegI__LoadI_memory__rule, // 545
  _AndI__LoadI_memory__immI_rule, // 546
  eRegI_rule, // 547
  _CastP2X_eRegP__rule, // 548
  eRegI_rule, // 549
  immI_rule, // 550
  _LoadI_memory__rule, // 551
  eRegI_rule, // 552
  _OrI__LoadI_memory__eRegI_rule, // 553
  _OrI_eRegI__LoadI_memory__rule, // 554
  _OrI__LoadI_memory__immI_rule, // 555
  0, // 556
  0, // 557
  0, // 558
  _URShiftI_eRegI_immI_M1_rule, // 559
  _LShiftI_eRegI_immI1_rule, // 560
  _URShiftI_eRegI_immI8_rule, // 561
  _LShiftI_eRegI_immI8_rule, // 562
  _URShiftI_ncxRegI__SubI_immI0_eCXRegI_rule, // 563
  _LShiftI_ncxRegI_eCXRegI_rule, // 564
  _URShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule, // 565
  _LShiftI_ncxRegI_eCXRegI_rule, // 566
  0, // 567
  0, // 568
  0, // 569
  _LShiftI_eRegI_immI_M1_rule, // 570
  _URShiftI_eRegI_immI1_rule, // 571
  _LShiftI_eRegI_immI8_rule, // 572
  _URShiftI_eRegI_immI8_rule, // 573
  _LShiftI_ncxRegI__SubI_immI0_eCXRegI_rule, // 574
  _URShiftI_ncxRegI_eCXRegI_rule, // 575
  _LShiftI_ncxRegI__SubI_immI_32_eCXRegI_rule, // 576
  _URShiftI_ncxRegI_eCXRegI_rule, // 577
  eRegI_rule, // 578
  immI_M1_rule, // 579
  immI_rule, // 580
  _LoadI_memory__rule, // 581
  eRegI_rule, // 582
  _XorI__LoadI_memory__eRegI_rule, // 583
  _XorI_eRegI__LoadI_memory__rule, // 584
  _XorI__LoadI_memory__immI_rule, // 585
  0, // 586
  0, // 587
  0, // 588
  0, // 589
  ncxRegI_rule, // 590
  immI0_rule, // 591
  _SubI_ncxRegI_ncxRegI_rule, // 592
  _AndI__CmpLTMask_ncxRegI_ncxRegI_ncxRegI_rule, // 593
  _SubI_ncxRegI_ncxRegI_rule, // 594
  _AndI_ncxRegI__CmpLTMask_ncxRegI_ncxRegI_rule, // 595
  eRegL_rule, // 596
  immL_rule, // 597
  _LoadL_load_long_memory__rule, // 598
  eRegL_rule, // 599
  eRegL_rule, // 600
  immL_rule, // 601
  _LoadL_load_long_memory__rule, // 602
  eRegL_rule, // 603
  eRegL_rule, // 604
  immL_rule, // 605
  _LoadL_load_long_memory__rule, // 606
  eRegL_rule, // 607
  eRegL_rule, // 608
  immL_rule, // 609
  _LoadL_load_long_memory__rule, // 610
  eRegL_rule, // 611
  eRegL_rule, // 612
  immL_M1_rule, // 613
  immL_rule, // 614
  _LoadL_load_long_memory__rule, // 615
  eRegL_rule, // 616
  immI_1_rule, // 617
  immI_2_rule, // 618
  immI_3_rule, // 619
  immI_1_31_rule, // 620
  immI_32_63_rule, // 621
  eCXRegI_rule, // 622
  immI_1_31_rule, // 623
  immI_32_63_rule, // 624
  eCXRegI_rule, // 625
  immI_1_31_rule, // 626
  immI_32_63_rule, // 627
  eCXRegI_rule, // 628
  immDPR0_rule, // 629
  regDPR_rule, // 630
  regD_rule, // 631
  _LoadD_memory__rule, // 632
  regDPR_rule, // 633
  0, // 634
  _LoadD_memory__rule, // 635
  regDPR_rule, // 636
  0, // 637
  _LoadD_memory__rule, // 638
  regDPR_rule, // 639
  _RoundDouble__AddD__LoadD_memory__regDPR__rule, // 640
  _RoundDouble__AddD_regDPR__LoadD_memory___rule, // 641
  immDPR1_rule, // 642
  immDPR_rule, // 643
  0, // 644
  regDPR_rule, // 645
  regnotDPR1_rule, // 646
  immDPR_rule, // 647
  _LoadD_memory__rule, // 648
  regDPR_rule, // 649
  _LoadD_memory__rule, // 650
  regDPR_rule, // 651
  regDPR_rule, // 652
  _MulD_regDPR_regDPR_rule, // 653
  regDPR_rule, // 654
  regDPR_rule, // 655
  regnotDPR1_rule, // 656
  0, // 657
  regDPR_rule, // 658
  regD_rule, // 659
  0, // 660
  0, // 661
  0, // 662
  0, // 663
  0, // 664
  0, // 665
  regDPR_rule, // 666
  regD_rule, // 667
  0, // 668
  regDPR1_rule, // 669
  regD_rule, // 670
  0, // 671
  0, // 672
  0, // 673
  0, // 674
  0, // 675
  0, // 676
  immFPR0_rule, // 677
  regFPR_rule, // 678
  regF_rule, // 679
  _LoadF_memory__rule, // 680
  regFPR_rule, // 681
  regFPR_rule, // 682
  regFPR_rule, // 683
  regFPR_rule, // 684
  _LoadF_memory__rule, // 685
  regFPR_rule, // 686
  _LoadF_memory__rule, // 687
  regFPR_rule, // 688
  regFPR_rule, // 689
  _LoadF_memory__rule, // 690
  memory_rule, // 691
  memory_rule, // 692
  immFPR_rule, // 693
  immFPR_rule, // 694
  regFPR_rule, // 695
  regFPR_rule, // 696
  _LoadF_memory__rule, // 697
  regFPR_rule, // 698
  _LoadF_memory__rule, // 699
  regFPR_rule, // 700
  memory_rule, // 701
  immFPR_rule, // 702
  immFPR_rule, // 703
  regFPR_rule, // 704
  _LoadF_memory__rule, // 705
  regFPR_rule, // 706
  _MulF__LoadF_memory__regFPR_rule, // 707
  regFPR_rule, // 708
  _MulF_regFPR__LoadF_memory__rule, // 709
  regFPR_rule, // 710
  _MulF_regFPR_regFPR_rule, // 711
  regFPR_rule, // 712
  regFPR_rule, // 713
  regFPR_rule, // 714
  regFPR_rule, // 715
  regFPR_rule, // 716
  regF_rule, // 717
  0, // 718
  0, // 719
  0, // 720
  0, // 721
  0, // 722
  0, // 723
  0, // 724
  0, // 725
  0, // 726
  0, // 727
  0, // 728
  0, // 729
  0, // 730
  0, // 731
  0, // 732
  0, // 733
  0, // 734
  0, // 735
  0, // 736
  0, // 737
  0, // 738
  0, // 739
  0, // 740
  0, // 741
  0, // 742
  0, // 743
  0, // 744
  0, // 745
  0, // 746
  0, // 747
  immL_32bits_rule, // 748
  immL_32bits_rule, // 749
  0, // 750
  0, // 751
  0, // 752
  0, // 753
  0, // 754
  0, // 755
  0, // 756
  0, // 757
  0, // 758
  0, // 759
  0, // 760
  0, // 761
  0, // 762
  0, // 763
  0, // 764
  0, // 765
  0, // 766
  0, // 767
  0, // 768
  0, // 769
  0, // 770
  0, // 771
  0, // 772
  0, // 773
  0, // 774
  0, // 775
  0, // 776
  0, // 777
  eDIRegP_rule, // 778
  _Binary_eSIRegP_eDXRegI_rule, // 779
  eCXRegI_rule, // 780
  _Binary_eSIRegP_immI_rule, // 781
  _Binary_eSIRegP_eAXRegI_rule, // 782
  eSIRegP_rule, // 783
  eRegI_rule, // 784
  eRegI_rule, // 785
  immI_rule, // 786
  0, // 787
  0, // 788
  eFlagsReg_rule, // 789
  eFlagsReg_rule, // 790
  eFlagsRegU_rule, // 791
  eFlagsRegUCF_rule, // 792
  eFlagsRegU_rule, // 793
  eFlagsRegUCF_rule, // 794
  eFlagsRegUCF_rule, // 795
  eAXRegP_rule, // 796
  0, // 797
  eFlagsReg_rule, // 798
  eFlagsReg_rule, // 799
  eFlagsRegU_rule, // 800
  eFlagsRegUCF_rule, // 801
  eFlagsRegU_rule, // 802
  eFlagsRegUCF_rule, // 803
  eFlagsRegUCF_rule, // 804
  eRegL_rule, // 805
  flagsReg_long_LTGE_rule, // 806
  _Binary_eRegL_eRegL_rule, // 807
  _Binary_eRegL__LoadL_load_long_memory__rule, // 808
  _Binary_eRegI_eRegI_rule, // 809
  _Binary_eRegI__LoadI_memory__rule, // 810
  _Binary_eRegP_eRegP_rule, // 811
  _Binary_regDPR_regDPR_rule, // 812
  _Binary_regD_regD_rule, // 813
  _Binary_regFPR_regFPR_rule, // 814
  _Binary_regF_regF_rule, // 815
  flagsReg_long_EQNE_rule, // 816
  _Binary_eRegL_eRegL_rule, // 817
  _Binary_eRegL__LoadL_load_long_memory__rule, // 818
  _Binary_eRegI_eRegI_rule, // 819
  _Binary_eRegI__LoadI_memory__rule, // 820
  _Binary_eRegP_eRegP_rule, // 821
  _Binary_regDPR_regDPR_rule, // 822
  _Binary_regD_regD_rule, // 823
  _Binary_regFPR_regFPR_rule, // 824
  _Binary_regF_regF_rule, // 825
  flagsReg_long_LEGT_rule, // 826
  _Binary_eRegL_eRegL_rule, // 827
  _Binary_eRegL__LoadL_load_long_memory__rule, // 828
  _Binary_eRegI_eRegI_rule, // 829
  _Binary_eRegI__LoadI_memory__rule, // 830
  _Binary_eRegP_eRegP_rule, // 831
  _Binary_regDPR_regDPR_rule, // 832
  _Binary_regD_regD_rule, // 833
  _Binary_regFPR_regFPR_rule, // 834
  _Binary_regF_regF_rule, // 835
  0, // 836
  0, // 837
  0, // 838
  0, // 839
  0, // 840
  0, // 841
  0, // 842
  eBXRegP_rule, // 843
  eAXRegP_rule, // 844
  0, // 845
  0, // 846
  0, // 847
  0, // 848
  regF_rule, // 849
  _LoadF_memory__rule, // 850
  regF_rule, // 851
  immF_rule, // 852
  regF_rule, // 853
  _LoadF_memory__rule, // 854
  regF_rule, // 855
  immF_rule, // 856
  regD_rule, // 857
  _LoadD_memory__rule, // 858
  regD_rule, // 859
  immD_rule, // 860
  regD_rule, // 861
  _LoadD_memory__rule, // 862
  regD_rule, // 863
  immD_rule, // 864
  regF_rule, // 865
  _LoadF_memory__rule, // 866
  immF_rule, // 867
  regF_rule, // 868
  _LoadF_memory__rule, // 869
  immF_rule, // 870
  regD_rule, // 871
  _LoadD_memory__rule, // 872
  immD_rule, // 873
  regD_rule, // 874
  _LoadD_memory__rule, // 875
  immD_rule, // 876
  regF_rule, // 877
  _LoadF_memory__rule, // 878
  regF_rule, // 879
  immF_rule, // 880
  regF_rule, // 881
  _LoadF_memory__rule, // 882
  regF_rule, // 883
  immF_rule, // 884
  regD_rule, // 885
  _LoadD_memory__rule, // 886
  regD_rule, // 887
  immD_rule, // 888
  regD_rule, // 889
  _LoadD_memory__rule, // 890
  regD_rule, // 891
  immD_rule, // 892
  regF_rule, // 893
  _LoadF_memory__rule, // 894
  immF_rule, // 895
  regF_rule, // 896
  _LoadF_memory__rule, // 897
  immF_rule, // 898
  regD_rule, // 899
  _LoadD_memory__rule, // 900
  immD_rule, // 901
  regD_rule, // 902
  _LoadD_memory__rule, // 903
  immD_rule, // 904
  0, // 905
  0, // 906
  0, // 907
  0, // 908
  0, // 909
  0, // 910
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  "UNIVERSE", // 0
  "LABEL", // 1
  "SREGI", // 2
  "SREGP", // 3
  "SREGF", // 4
  "SREGD", // 5
  "SREGL", // 6
  "METHOD", // 7
  "IMMI", // 8
  "IMMI0", // 9
  "IMMI1", // 10
  "IMMI_M1", // 11
  "IMMI2", // 12
  "IMMI8", // 13
  "IMMI16", // 14
  "IMMI_32", // 15
  "IMMI_1_31", // 16
  "IMMI_32_63", // 17
  "IMMI_1", // 18
  "IMMI_2", // 19
  "IMMI_3", // 20
  "IMMP", // 21
  "IMMP0", // 22
  "IMML", // 23
  "IMML0", // 24
  "IMML_M1", // 25
  "IMML_127", // 26
  "IMML_32BITS", // 27
  "IMML32", // 28
  "IMMDPR0", // 29
  "IMMDPR1", // 30
  "IMMDPR", // 31
  "IMMD", // 32
  "IMMD0", // 33
  "IMMFPR0", // 34
  "IMMFPR1", // 35
  "IMMFPR", // 36
  "IMMF", // 37
  "IMMF0", // 38
  "IMMI_16", // 39
  "IMMI_24", // 40
  "IMMI_255", // 41
  "IMMI_65535", // 42
  "EREGI", // 43
  "XREGI", // 44
  "EAXREGI", // 45
  "EBXREGI", // 46
  "ECXREGI", // 47
  "EDXREGI", // 48
  "EDIREGI", // 49
  "NAXREGI", // 50
  "NADXREGI", // 51
  "NCXREGI", // 52
  "ESIREGI", // 53
  "ANYREGP", // 54
  "EREGP", // 55
  "EREGP_NO_EBP", // 56
  "NAXREGP", // 57
  "NABXREGP", // 58
  "PREGP", // 59
  "EAXREGP", // 60
  "EBXREGP", // 61
  "ECXREGP", // 62
  "ESIREGP", // 63
  "EDIREGP", // 64
  "EBPREGP", // 65
  "EREGL", // 66
  "EADXREGL", // 67
  "EBCXREGL", // 68
  "EADXREGL_LOW_ONLY", // 69
  "EFLAGSREG", // 70
  "EFLAGSREGU", // 71
  "EFLAGSREGUCF", // 72
  "FLAGSREG_LONG_LTGE", // 73
  "FLAGSREG_LONG_EQNE", // 74
  "FLAGSREG_LONG_LEGT", // 75
  "REGDPR", // 76
  "REGDPR1", // 77
  "REGDPR2", // 78
  "REGNOTDPR1", // 79
  "REGD", // 80
  "REGD6", // 81
  "REGD7", // 82
  "REGFPR", // 83
  "REGFPR1", // 84
  "REGF", // 85
  "DIRECT", // 86
  "INDIRECT", // 87
  "INDOFFSET8", // 88
  "INDOFFSET32", // 89
  "INDOFFSET32X", // 90
  "INDINDEXOFFSET", // 91
  "INDINDEX", // 92
  "INDINDEXSCALE", // 93
  "INDINDEXSCALEOFFSET", // 94
  "LOAD_LONG_REGP", // 95
  "LOAD_LONG_INDIRECT", // 96
  "LOAD_LONG_INDOFFSET32", // 97
  "STACKSLOTP", // 98
  "STACKSLOTI", // 99
  "STACKSLOTF", // 100
  "STACKSLOTD", // 101
  "STACKSLOTL", // 102
  "INDIRECT_WIN95_SAFE", // 103
  "INDOFFSET8_WIN95_SAFE", // 104
  "INDOFFSET32_WIN95_SAFE", // 105
  "INDINDEXOFFSET_WIN95_SAFE", // 106
  "INDINDEXSCALE_WIN95_SAFE", // 107
  "INDINDEXSCALEOFFSET_WIN95_SAFE", // 108
  "CMPOP", // 109
  "CMPOPU", // 110
  "CMPOPUCF", // 111
  "CMPOPUCF2", // 112
  "CMPOP_FCMOV", // 113
  "CMPOP_COMMUTE", // 114
  // last operand
  "LOAD_LONG_MEMORY", // 115
  "MEMORY", // 116
  "LONG_MEMORY", // 117
  // last operand class
  "_AddP_eRegP_eRegI", // 118
  "_LShiftI_eRegI_immI2", // 119
  "_AddP_eRegP__LShiftI_eRegI_immI2", // 120
  "_AddP_eRegP_no_EBP_eRegI", // 121
  "_AddP_eRegP_no_EBP__LShiftI_eRegI_immI2", // 122
  "_LoadI_memory_", // 123
  "_LoadL_memory_", // 124
  "_LoadB_memory_", // 125
  "_LoadUB_memory_", // 126
  "_AndI__LoadUB_memory__immI8", // 127
  "_LoadS_memory_", // 128
  "_LShiftI__LoadS_memory__immI_24", // 129
  "_LoadUS_memory_", // 130
  "_LShiftI__LoadUS_memory__immI_24", // 131
  "_AndI__LoadUS_memory__immI_255", // 132
  "_AndI__LoadUS_memory__immI16", // 133
  "_LShiftI__LoadI_memory__immI_24", // 134
  "_LShiftI__LoadI_memory__immI_16", // 135
  "_AndI__LoadI_memory__immI_255", // 136
  "_AndI__LoadI_memory__immI_65535", // 137
  "_AndI__LoadI_memory__immI", // 138
  "_ConvL2I_eRegL_", // 139
  "_RoundDouble_regDPR1_", // 140
  "_RoundFloat_regFPR1_", // 141
  "_ConvD2F_regDPR1_", // 142
  "_Binary_cmpOp_eFlagsReg", // 143
  "_Binary_eRegI_eRegI", // 144
  "_Binary_cmpOpU_eFlagsRegU", // 145
  "_Binary_cmpOpUCF_eFlagsRegUCF", // 146
  "_Binary_eRegI__LoadI_memory_", // 147
  "_Binary_eRegP_eRegP", // 148
  "_Binary_cmpOp_fcmov_eFlagsRegU", // 149
  "_Binary_regDPR1_regDPR", // 150
  "_Binary_regFPR1_regFPR", // 151
  "_Binary_regDPR_regDPR", // 152
  "_Binary_regFPR_regFPR", // 153
  "_Binary_regF_regF", // 154
  "_Binary_regD_regD", // 155
  "_Binary_eRegL_eRegL", // 156
  "_AddI__LoadI_memory__eRegI", // 157
  "_AddI_eRegI__LoadI_memory_", // 158
  "_AddI__LoadI_memory__immI", // 159
  "_AddI__LoadI_memory__immI1", // 160
  "_AddI__LoadI_memory__immI_M1", // 161
  "_Binary_eAXRegP_eRegP", // 162
  "_Binary_eAXRegI_eRegI", // 163
  "_Binary_eADXRegL_eBCXRegL", // 164
  "_Binary_eAXRegP_eCXRegP", // 165
  "_Binary_eAXRegI_eCXRegI", // 166
  "_SubI__LoadI_memory__eRegI", // 167
  "_SubI_immI0_eRegI", // 168
  "_ConvI2L_nadxRegI_", // 169
  "_MulL__ConvI2L_nadxRegI__eADXRegL_low_only", // 170
  "_RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32", // 171
  "_MulL_eADXRegL_low_only__ConvI2L_nadxRegI_", // 172
  "_RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32", // 173
  "_RShiftL__MulL__ConvI2L_nadxRegI__eADXRegL_low_only_immI_32_63", // 174
  "_RShiftL__MulL_eADXRegL_low_only__ConvI2L_nadxRegI__immI_32_63", // 175
  "_ConvI2L_eAXRegI_", // 176
  "_AndL__ConvI2L_eAXRegI__immL_32bits", // 177
  "_AndL__ConvI2L_nadxRegI__immL_32bits", // 178
  "_RShiftI__LoadI_memory__immI1", // 179
  "_RShiftI__LoadI_memory__immI8", // 180
  "_LShiftI_xRegI_immI_24", // 181
  "_LShiftI_xRegI_immI_16", // 182
  "_AndI__LoadI_memory__eRegI", // 183
  "_AndI_eRegI__LoadI_memory_", // 184
  "_CastP2X_eRegP_", // 185
  "_OrI__LoadI_memory__eRegI", // 186
  "_OrI_eRegI__LoadI_memory_", // 187
  "_OrI__LoadI_memory__immI", // 188
  "_LShiftI_eRegI_immI1", // 189
  "_URShiftI_eRegI_immI_M1", // 190
  "_LShiftI_eRegI_immI8", // 191
  "_URShiftI_eRegI_immI8", // 192
  "_LShiftI_ncxRegI_eCXRegI", // 193
  "_SubI_immI0_eCXRegI", // 194
  "_URShiftI_ncxRegI__SubI_immI0_eCXRegI", // 195
  "_SubI_immI_32_eCXRegI", // 196
  "_URShiftI_ncxRegI__SubI_immI_32_eCXRegI", // 197
  "_URShiftI_eRegI_immI1", // 198
  "_LShiftI_eRegI_immI_M1", // 199
  "_URShiftI_ncxRegI_eCXRegI", // 200
  "_LShiftI_ncxRegI__SubI_immI0_eCXRegI", // 201
  "_LShiftI_ncxRegI__SubI_immI_32_eCXRegI", // 202
  "_XorI__LoadI_memory__eRegI", // 203
  "_XorI_eRegI__LoadI_memory_", // 204
  "_XorI__LoadI_memory__immI", // 205
  "_CmpLTMask_ncxRegI_ncxRegI", // 206
  "_AndI__CmpLTMask_ncxRegI_ncxRegI_ncxRegI", // 207
  "_SubI_ncxRegI_ncxRegI", // 208
  "_AndI_ncxRegI__CmpLTMask_ncxRegI_ncxRegI", // 209
  "_LoadL_load_long_memory_", // 210
  "_LoadD_memory_", // 211
  "_SubD_regDPR_regDPR", // 212
  "_AddD_regDPR_regDPR", // 213
  "_AddD__LoadD_memory__regDPR", // 214
  "_RoundDouble__AddD__LoadD_memory__regDPR_", // 215
  "_AddD_regDPR__LoadD_memory_", // 216
  "_RoundDouble__AddD_regDPR__LoadD_memory__", // 217
  "_AddD_regDPR_immDPR", // 218
  "_MulD_regDPR_regDPR", // 219
  "_DivD_regDPR_regDPR", // 220
  "_LoadF_memory_", // 221
  "_MulF__LoadF_memory__regFPR", // 222
  "_MulF_regFPR__LoadF_memory_", // 223
  "_MulF_regFPR_regFPR", // 224
  "_SubF_regFPR_regFPR", // 225
  "_ConvI2L_eRegI_", // 226
  "_Binary_eDIRegP_eCXRegI", // 227
  "_Binary_eSIRegP_eDXRegI", // 228
  "_Binary_eDIRegP_eSIRegP", // 229
  "_Binary_eDIRegP_eDXRegI", // 230
  "_Binary_eSIRegP_immI", // 231
  "_Binary_eSIRegP_eAXRegI", // 232
  "_AndI_eRegI_immI", // 233
  "_AndI_eRegI_memory", // 234
  "_LoadP_memory_", // 235
  "_Binary_nadxRegI_eAXRegI", // 236
  "_PartialSubtypeCheck_eSIRegP_eAXRegP", // 237
  "_Binary_cmpOp_flagsReg_long_LTGE", // 238
  "_Binary_eRegL__LoadL_load_long_memory_", // 239
  "_Binary_cmpOp_flagsReg_long_EQNE", // 240
  "_Binary_cmpOp_commute_flagsReg_long_LEGT", // 241
  "_ConvF2D_regF_", // 242
  "_SqrtD__ConvF2D_regF__", // 243
  "_ConvF2D__LoadF_memory__", // 244
  "_SqrtD__ConvF2D__LoadF_memory___", // 245
  "_ConvF2D_immF_", // 246
  "_SqrtD__ConvF2D_immF__", // 247
  // last internally defined operand
  "storeSSI", // 248
  "storeSSP", // 249
  "storeSSL", // 250
  "leaP8", // 251
  "leaP32", // 252
  "leaPIdxOff", // 253
  "leaPIdxScale", // 254
  "leaPIdxScaleOff", // 255
  "loadConI", // 256
  "loadConI0", // 257
  "loadConP", // 258
  "loadConL", // 259
  "loadConL0", // 260
  "loadConFPR", // 261
  "loadConFPR0", // 262
  "loadConFPR1", // 263
  "loadConF", // 264
  "loadConF0", // 265
  "loadConDPR", // 266
  "loadConDPR0", // 267
  "loadConDPR1", // 268
  "loadConD", // 269
  "loadConD0", // 270
  "loadSSI", // 271
  "loadSSL", // 272
  "loadSSP", // 273
  "loadSSF", // 274
  "loadSSD", // 275
  "loadConL_low_only", // 276
  "membar_volatile", // 277
  "castX2P", // 278
  "castP2X", // 279
  "checkCastPP", // 280
  "castPP", // 281
  "castII", // 282
  "storePConditional", // 283
  "storeIConditional", // 284
  "storeLConditional", // 285
  "movI_nocopy", // 286
  "movP_nocopy", // 287
  "cmpDPR_cc_P6", // 288
  "cmpDPR_cc_P6CF", // 289
  "cmpDPR_cc", // 290
  "cmpD_cc", // 291
  "cmpD_ccCF", // 292
  "cmpD_ccmem", // 293
  "cmpD_ccmemCF", // 294
  "absDPR_reg", // 295
  "negDPR_reg", // 296
  "cmpFPR_cc_P6", // 297
  "cmpFPR_cc_P6CF", // 298
  "cmpFPR_cc", // 299
  "cmpF_cc", // 300
  "cmpF_ccCF", // 301
  "cmpF_ccmem", // 302
  "cmpF_ccmemCF", // 303
  "absFPR_reg", // 304
  "negFPR_reg", // 305
  "MoveF2I_stack_reg", // 306
  "MoveF2I_reg_reg_sse", // 307
  "MoveI2FPR_stack_reg", // 308
  "MoveI2F_stack_reg_sse", // 309
  "MoveI2F_reg_reg_sse", // 310
  "MoveD2L_stack_reg", // 311
  "MoveL2DPR_stack_reg", // 312
  "MoveL2D_stack_reg_sse", // 313
  "MoveL2D_stack_reg_sse_partial", // 314
  "compI_eReg", // 315
  "compI_eReg_imm", // 316
  "compI_eReg_mem", // 317
  "testI_reg", // 318
  "testI_reg_imm", // 319
  "testI_reg_mem", // 320
  "compU_eReg", // 321
  "compU_eReg_imm", // 322
  "compU_eReg_mem", // 323
  "testU_reg", // 324
  "compP_eReg", // 325
  "compP_eReg_imm", // 326
  "compP_eReg_mem", // 327
  "compP_mem_eReg", // 328
  "testP_reg", // 329
  "testP_Reg_mem", // 330
  "partialSubtypeCheck_vs_Zero", // 331
  "cmpL_zero_flags_LTGE", // 332
  "cmpL_reg_flags_LTGE", // 333
  "cmpL_zero_flags_EQNE", // 334
  "cmpL_reg_flags_EQNE", // 335
  "cmpL_zero_flags_LEGT", // 336
  "cmpL_reg_flags_LEGT", // 337
  "cmpFastLock", // 338
  "cmpFastUnlock", // 339
  "safePoint_poll", // 340
  "absF_reg", // 341
  "vabsF_reg", // 342
  "absD_reg", // 343
  "vabsD_reg", // 344
  "negF_reg", // 345
  "vnegF_reg", // 346
  "negD_reg", // 347
  "vnegD_reg", // 348
  "bytes_reverse_int", // 349
  "bytes_reverse_long", // 350
  "bytes_reverse_unsigned_short", // 351
  "bytes_reverse_short", // 352
  "countLeadingZerosI", // 353
  "countLeadingZerosI_bsr", // 354
  "countLeadingZerosL", // 355
  "countLeadingZerosL_bsr", // 356
  "countTrailingZerosI", // 357
  "countTrailingZerosL", // 358
  "popCountI", // 359
  "popCountI_mem", // 360
  "popCountL", // 361
  "popCountL_mem", // 362
  "loadB", // 363
  "loadB2L", // 364
  "loadUB", // 365
  "loadUB2L", // 366
  "loadUB2L_immI8", // 367
  "loadS", // 368
  "loadS2B", // 369
  "loadS2L", // 370
  "loadUS", // 371
  "loadUS2B", // 372
  "loadUS2L", // 373
  "loadUS2L_immI_255", // 374
  "loadUS2L_immI16", // 375
  "loadI", // 376
  "loadI2B", // 377
  "loadI2UB", // 378
  "loadI2S", // 379
  "loadI2US", // 380
  "loadI2L", // 381
  "loadI2L_immI_255", // 382
  "loadI2L_immI_65535", // 383
  "loadI2L_immI", // 384
  "loadUI2L", // 385
  "loadL", // 386
  "loadL_volatile", // 387
  "loadLX_volatile", // 388
  "loadLX_reg_volatile", // 389
  "loadRange", // 390
  "loadP", // 391
  "loadKlass", // 392
  "loadDPR", // 393
  "loadD", // 394
  "loadD_partial", // 395
  "loadF", // 396
  "loadFPR", // 397
  "loadA8B", // 398
  "loadA4S", // 399
  "loadA4C", // 400
  "load2IU", // 401
  "loadA2F", // 402
  "prefetchr0", // 403
  "prefetchr", // 404
  "prefetchrNTA", // 405
  "prefetchrT0", // 406
  "prefetchrT2", // 407
  "prefetchw0", // 408
  "prefetchw", // 409
  "prefetchwNTA", // 410
  "prefetchAlloc0", // 411
  "prefetchAlloc", // 412
  "prefetchAllocNTA", // 413
  "prefetchAllocT0", // 414
  "prefetchAllocT2", // 415
  "storeB", // 416
  "storeC", // 417
  "storeI", // 418
  "storeL", // 419
  "storeL2I", // 420
  "storeL_volatile", // 421
  "storeLX_volatile", // 422
  "storeLX_reg_volatile", // 423
  "storeP", // 424
  "storeImmI", // 425
  "storeImmI16", // 426
  "storeImmP", // 427
  "storeImmB", // 428
  "storeA8B", // 429
  "storeA4C", // 430
  "storeA2I", // 431
  "storeImmCM", // 432
  "storeDPR", // 433
  "storeDPR_rounded", // 434
  "storeD", // 435
  "storeF", // 436
  "storeA2F", // 437
  "storeFPR", // 438
  "storeFPR_rounded", // 439
  "storeFPR_Drounded", // 440
  "storeFPR_imm", // 441
  "storeF_imm", // 442
  "membar_acquire", // 443
  "membar_acquire_lock", // 444
  "membar_release", // 445
  "membar_release_lock", // 446
  "unnecessary_membar_volatile", // 447
  "membar_storestore", // 448
  "jmovI_reg", // 449
  "jmovI_regU", // 450
  "cmovI_reg", // 451
  "cmovI_regU", // 452
  "cmovI_regUCF", // 453
  "cmovI_mem", // 454
  "cmovI_memU", // 455
  "cmovI_memUCF", // 456
  "cmovP_reg", // 457
  "cmovP_reg_nonP6", // 458
  "cmovP_regU", // 459
  "cmovP_regUCF", // 460
  "fcmovDPR_regU", // 461
  "fcmovFPR_regU", // 462
  "fcmovDPR_regS", // 463
  "fcmovFPR_regS", // 464
  "fcmovF_regS", // 465
  "fcmovD_regS", // 466
  "fcmovF_regU", // 467
  "fcmovF_regUCF", // 468
  "fcmovD_regU", // 469
  "fcmovD_regUCF", // 470
  "cmovL_reg", // 471
  "cmovL_regU", // 472
  "cmovL_regUCF", // 473
  "addI_eReg", // 474
  "addI_eReg_imm", // 475
  "incI_eReg", // 476
  "leaI_eReg_immI", // 477
  "leaP_eReg_immI", // 478
  "decI_eReg", // 479
  "addP_eReg", // 480
  "addP_eReg_imm", // 481
  "addI_eReg_mem", // 482
  "addI_eReg_mem_0", // 483
  "addI_mem_eReg", // 484
  "addI_mem_eReg_0", // 485
  "addI_mem_imm", // 486
  "incI_mem", // 487
  "decI_mem", // 488
  "loadPLocked", // 489
  "loadLLocked", // 490
  "loadLX_Locked", // 491
  "loadLX_reg_Locked", // 492
  "compareAndSwapL", // 493
  "compareAndSwapP", // 494
  "compareAndSwapI", // 495
  "subI_eReg", // 496
  "subI_eReg_imm", // 497
  "subI_eReg_mem", // 498
  "subI_mem_eReg", // 499
  "subP_eReg", // 500
  "negI_eReg", // 501
  "mulI_eReg", // 502
  "mulI_eReg_imm", // 503
  "mulI_imm_high", // 504
  "mulI_imm_high_0", // 505
  "mulI_imm_RShift_high", // 506
  "mulI_imm_RShift_high_0", // 507
  "mulI_mem_imm", // 508
  "mulI", // 509
  "mulI_0", // 510
  "mulI2L", // 511
  "mulI2L_0", // 512
  "mulIS_eReg", // 513
  "mulIS_eReg_0", // 514
  "mulL_eReg", // 515
  "mulL_eReg_lhi0", // 516
  "mulL_eReg_rhi0", // 517
  "mulL_eReg_hi0", // 518
  "mulL_eReg_con", // 519
  "divI_eReg", // 520
  "divL_eReg", // 521
  "divModI_eReg_divmod", // 522
  "modI_eReg", // 523
  "modL_eReg", // 524
  "divL_eReg_imm32", // 525
  "modL_eReg_imm32", // 526
  "shlI_eReg_1", // 527
  "salI_eReg_imm", // 528
  "salI_eReg_CL", // 529
  "sarI_eReg_1", // 530
  "sarI_mem_1", // 531
  "sarI_eReg_imm", // 532
  "sarI_mem_imm", // 533
  "sarI_eReg_CL", // 534
  "shrI_eReg_1", // 535
  "shrI_eReg_imm", // 536
  "i2b", // 537
  "i2s", // 538
  "shrI_eReg_CL", // 539
  "andI_eReg", // 540
  "andI_eReg_imm", // 541
  "andI_eReg_mem", // 542
  "andI_eReg_mem_0", // 543
  "andI_mem_eReg", // 544
  "andI_mem_eReg_0", // 545
  "andI_mem_imm", // 546
  "orI_eReg", // 547
  "orI_eReg_castP2X", // 548
  "orI_eReg_castP2X_0", // 549
  "orI_eReg_imm", // 550
  "orI_eReg_mem", // 551
  "orI_eReg_mem_0", // 552
  "orI_mem_eReg", // 553
  "orI_mem_eReg_0", // 554
  "orI_mem_imm", // 555
  "rolI_eReg_imm1", // 556
  "rolI_eReg_imm8", // 557
  "rolI_eReg_CL", // 558
  "rolI_eReg_i1", // 559
  "rolI_eReg_i1_0", // 560
  "rolI_eReg_i8", // 561
  "rolI_eReg_i8_0", // 562
  "rolI_eReg_Var_C0", // 563
  "rolI_eReg_Var_C0_0", // 564
  "rolI_eReg_Var_C32", // 565
  "rolI_eReg_Var_C32_0", // 566
  "rorI_eReg_imm1", // 567
  "rorI_eReg_imm8", // 568
  "rorI_eReg_CL", // 569
  "rorI_eReg_i1", // 570
  "rorI_eReg_i1_0", // 571
  "rorI_eReg_i8", // 572
  "rorI_eReg_i8_0", // 573
  "rorI_eReg_Var_C0", // 574
  "rorI_eReg_Var_C0_0", // 575
  "rorI_eReg_Var_C32", // 576
  "rorI_eReg_Var_C32_0", // 577
  "xorI_eReg", // 578
  "xorI_eReg_im1", // 579
  "xorI_eReg_imm", // 580
  "xorI_eReg_mem", // 581
  "xorI_eReg_mem_0", // 582
  "xorI_mem_eReg", // 583
  "xorI_mem_eReg_0", // 584
  "xorI_mem_imm", // 585
  "ci2b", // 586
  "convI2B", // 587
  "cp2b", // 588
  "convP2B", // 589
  "cmpLTMask", // 590
  "cmpLTMask0", // 591
  "cadd_cmpLTMask", // 592
  "cadd_cmpLTMask_1", // 593
  "cadd_cmpLTMask_0", // 594
  "cadd_cmpLTMask_2", // 595
  "addL_eReg", // 596
  "addL_eReg_imm", // 597
  "addL_eReg_mem", // 598
  "addL_eReg_mem_0", // 599
  "subL_eReg", // 600
  "subL_eReg_imm", // 601
  "subL_eReg_mem", // 602
  "negL_eReg", // 603
  "andL_eReg", // 604
  "andL_eReg_imm", // 605
  "andL_eReg_mem", // 606
  "andL_eReg_mem_0", // 607
  "orl_eReg", // 608
  "orl_eReg_imm", // 609
  "orl_eReg_mem", // 610
  "orl_eReg_mem_0", // 611
  "xorl_eReg", // 612
  "xorl_eReg_im1", // 613
  "xorl_eReg_imm", // 614
  "xorl_eReg_mem", // 615
  "xorl_eReg_mem_0", // 616
  "shlL_eReg_1", // 617
  "shlL_eReg_2", // 618
  "shlL_eReg_3", // 619
  "shlL_eReg_1_31", // 620
  "shlL_eReg_32_63", // 621
  "salL_eReg_CL", // 622
  "shrL_eReg_1_31", // 623
  "shrL_eReg_32_63", // 624
  "shrL_eReg_CL", // 625
  "sarL_eReg_1_31", // 626
  "sarL_eReg_32_63", // 627
  "sarL_eReg_CL", // 628
  "cmpDPR_0", // 629
  "cmpDPR_reg", // 630
  "cmpD_reg", // 631
  "cmpD_regmem", // 632
  "subDPR_reg", // 633
  "subDPR_reg_round", // 634
  "subDPR_reg_mem", // 635
  "addDPR_reg", // 636
  "addDPR_reg_round", // 637
  "addDPR_reg_mem", // 638
  "addDPR_reg_mem_0", // 639
  "addDPR_mem_reg", // 640
  "addDPR_mem_reg_0", // 641
  "addDPR_reg_imm1", // 642
  "addDPR_reg_imm", // 643
  "addDPR_reg_imm_round", // 644
  "mulDPR_reg", // 645
  "strictfp_mulDPR_reg", // 646
  "mulDPR_reg_imm", // 647
  "mulDPR_reg_mem", // 648
  "mulDPR_reg_mem_0", // 649
  "mulDPR_reg_mem_cisc", // 650
  "mulDPR_reg_mem_cisc_0", // 651
  "addDPR_mulDPR_reg", // 652
  "addDPR_mulDPR_reg_0", // 653
  "subDPR_mulDPR_reg", // 654
  "divDPR_reg", // 655
  "strictfp_divDPR_reg", // 656
  "divDPR_reg_round", // 657
  "modDPR_reg", // 658
  "modD_reg", // 659
  "sinDPR_reg", // 660
  "sinD_reg", // 661
  "cosDPR_reg", // 662
  "cosD_reg", // 663
  "tanDPR_reg", // 664
  "tanD_reg", // 665
  "atanDPR_reg", // 666
  "atanD_reg", // 667
  "sqrtDPR_reg", // 668
  "powDPR_reg", // 669
  "powD_reg", // 670
  "expDPR_reg", // 671
  "expD_reg", // 672
  "log10DPR_reg", // 673
  "log10D_reg", // 674
  "logDPR_reg", // 675
  "logD_reg", // 676
  "cmpFPR_0", // 677
  "cmpFPR_reg", // 678
  "cmpF_reg", // 679
  "cmpF_regmem", // 680
  "subFPR24_reg", // 681
  "subFPR_reg", // 682
  "addFPR24_reg", // 683
  "addFPR_reg", // 684
  "addFPR24_reg_mem", // 685
  "addFPR24_reg_mem_0", // 686
  "addFPR_reg_mem", // 687
  "addFPR_reg_mem_0", // 688
  "addFPR24_mem_reg", // 689
  "addFPR24_mem_cisc", // 690
  "addFPR24_mem_cisc_0", // 691
  "addFPR24_mem_mem", // 692
  "addFPR24_reg_imm", // 693
  "addFPR_reg_imm", // 694
  "mulFPR24_reg", // 695
  "mulFPR_reg", // 696
  "mulFPR24_reg_mem", // 697
  "mulFPR24_reg_mem_0", // 698
  "mulFPR_reg_mem", // 699
  "mulFPR_reg_mem_0", // 700
  "mulFPR24_mem_mem", // 701
  "mulFPR24_reg_imm", // 702
  "mulFPR_reg_imm", // 703
  "mulFPR_reg_load1", // 704
  "mulFPR_reg_load1_0", // 705
  "addFPR_mulFPR_reg_load1", // 706
  "addFPR_mulFPR_reg_load1_1", // 707
  "addFPR_mulFPR_reg_load1_0", // 708
  "addFPR_mulFPR_reg_load1_2", // 709
  "addFPR_mulFPR_reg", // 710
  "addFPR_mulFPR_reg_0", // 711
  "subFPR_divFPR_reg", // 712
  "divFPR24_reg", // 713
  "divFPR_reg", // 714
  "modFPR24_reg", // 715
  "modFPR_reg", // 716
  "modF_reg", // 717
  "roundFloat_mem_reg", // 718
  "roundDouble_mem_reg", // 719
  "convDPR2FPR_reg", // 720
  "convDPR2F_reg", // 721
  "convD2F_reg", // 722
  "convFPR2DPR_reg_reg", // 723
  "convFPR2D_reg", // 724
  "convF2DPR_reg", // 725
  "convF2D_reg", // 726
  "convDPR2I_reg_reg", // 727
  "convD2I_reg_reg", // 728
  "convDPR2L_reg_reg", // 729
  "convD2L_reg_reg", // 730
  "convFPR2I_reg_reg", // 731
  "convF2I_reg", // 732
  "convFPR2L_reg_reg", // 733
  "convF2L_reg_reg", // 734
  "convI2DPR_reg", // 735
  "convI2D_reg", // 736
  "convI2D_mem", // 737
  "convXI2D_reg", // 738
  "convI2DPR_mem", // 739
  "conv24I2FPR_reg", // 740
  "convI2FPR_SSF", // 741
  "convI2FPR_SSF_mem", // 742
  "convI2FPR_reg", // 743
  "convI2FPR_mem", // 744
  "convI2F_reg", // 745
  "convXI2F_reg", // 746
  "convI2L_reg", // 747
  "convI2L_reg_zex", // 748
  "zerox_long", // 749
  "convL2DPR_reg", // 750
  "convL2D_reg", // 751
  "convL2F_reg", // 752
  "convL2FPR_reg", // 753
  "convL2I_reg", // 754
  "MoveFPR2I_reg_stack", // 755
  "MoveF2I_reg_stack_sse", // 756
  "MoveI2F_reg_stack", // 757
  "MoveDPR2L_reg_stack", // 758
  "MoveD2L_reg_stack_sse", // 759
  "MoveD2L_reg_reg_sse", // 760
  "MoveL2D_reg_stack", // 761
  "MoveL2D_reg_reg_sse", // 762
  "Repl8B_reg", // 763
  "Repl8B_eRegI", // 764
  "Repl8B_immI0", // 765
  "Repl4S_reg", // 766
  "Repl4S_eRegI", // 767
  "Repl4S_immI0", // 768
  "Repl4C_reg", // 769
  "Repl4C_eRegI", // 770
  "Repl4C_immI0", // 771
  "Repl2I_reg", // 772
  "Repl2I_eRegI", // 773
  "Repl2I_immI0", // 774
  "Repl2F_reg", // 775
  "Repl2F_regF", // 776
  "Repl2F_immF0", // 777
  "rep_stos", // 778
  "string_compare", // 779
  "string_equals", // 780
  "string_indexof_con", // 781
  "string_indexof", // 782
  "array_equals", // 783
  "minI_eReg", // 784
  "maxI_eReg", // 785
  "loopLimit_eReg", // 786
  "jumpXtnd", // 787
  "jmpDir", // 788
  "jmpCon", // 789
  "jmpLoopEnd", // 790
  "jmpLoopEndU", // 791
  "jmpLoopEndUCF", // 792
  "jmpConU", // 793
  "jmpConUCF", // 794
  "jmpConUCF2", // 795
  "partialSubtypeCheck", // 796
  "jmpDir_short", // 797
  "jmpCon_short", // 798
  "jmpLoopEnd_short", // 799
  "jmpLoopEndU_short", // 800
  "jmpLoopEndUCF_short", // 801
  "jmpConU_short", // 802
  "jmpConUCF_short", // 803
  "jmpConUCF2_short", // 804
  "cmpL3_reg_reg", // 805
  "cmpL_LTGE", // 806
  "cmovLL_reg_LTGE", // 807
  "cmovLL_mem_LTGE", // 808
  "cmovII_reg_LTGE", // 809
  "cmovII_mem_LTGE", // 810
  "cmovPP_reg_LTGE", // 811
  "cmovDDPR_reg_LTGE", // 812
  "cmovDD_reg_LTGE", // 813
  "cmovFFPR_reg_LTGE", // 814
  "cmovFF_reg_LTGE", // 815
  "cmpL_EQNE", // 816
  "cmovLL_reg_EQNE", // 817
  "cmovLL_mem_EQNE", // 818
  "cmovII_reg_EQNE", // 819
  "cmovII_mem_EQNE", // 820
  "cmovPP_reg_EQNE", // 821
  "cmovDDPR_reg_EQNE", // 822
  "cmovDD_reg_EQNE", // 823
  "cmovFFPR_reg_EQNE", // 824
  "cmovFF_reg_EQNE", // 825
  "cmpL_LEGT", // 826
  "cmovLL_reg_LEGT", // 827
  "cmovLL_mem_LEGT", // 828
  "cmovII_reg_LEGT", // 829
  "cmovII_mem_LEGT", // 830
  "cmovPP_reg_LEGT", // 831
  "cmovDDPR_reg_LEGT", // 832
  "cmovDD_reg_LEGT", // 833
  "cmovFFPR_reg_LEGT", // 834
  "cmovFF_reg_LEGT", // 835
  "CallStaticJavaDirect", // 836
  "CallStaticJavaHandle", // 837
  "CallDynamicJavaDirect", // 838
  "CallRuntimeDirect", // 839
  "CallLeafDirect", // 840
  "CallLeafNoFPDirect", // 841
  "Ret", // 842
  "TailCalljmpInd", // 843
  "tailjmpInd", // 844
  "CreateException", // 845
  "RethrowException", // 846
  "tlsLoadP", // 847
  "ShouldNotReachHere", // 848
  "addF_reg", // 849
  "addF_mem", // 850
  "addF_mem_0", // 851
  "addF_imm", // 852
  "vaddF_reg", // 853
  "vaddF_mem", // 854
  "vaddF_mem_0", // 855
  "vaddF_imm", // 856
  "addD_reg", // 857
  "addD_mem", // 858
  "addD_mem_0", // 859
  "addD_imm", // 860
  "vaddD_reg", // 861
  "vaddD_mem", // 862
  "vaddD_mem_0", // 863
  "vaddD_imm", // 864
  "subF_reg", // 865
  "subF_mem", // 866
  "subF_imm", // 867
  "vsubF_reg", // 868
  "vsubF_mem", // 869
  "vsubF_imm", // 870
  "subD_reg", // 871
  "subD_mem", // 872
  "subD_imm", // 873
  "vsubD_reg", // 874
  "vsubD_mem", // 875
  "vsubD_imm", // 876
  "mulF_reg", // 877
  "mulF_mem", // 878
  "mulF_mem_0", // 879
  "mulF_imm", // 880
  "vmulF_reg", // 881
  "vmulF_mem", // 882
  "vmulF_mem_0", // 883
  "vmulF_imm", // 884
  "mulD_reg", // 885
  "mulD_mem", // 886
  "mulD_mem_0", // 887
  "mulD_imm", // 888
  "vmulD_reg", // 889
  "vmulD_mem", // 890
  "vmulD_mem_0", // 891
  "vmulD_imm", // 892
  "divF_reg", // 893
  "divF_mem", // 894
  "divF_imm", // 895
  "vdivF_reg", // 896
  "vdivF_mem", // 897
  "vdivF_imm", // 898
  "divD_reg", // 899
  "divD_mem", // 900
  "divD_imm", // 901
  "vdivD_reg", // 902
  "vdivD_mem", // 903
  "vdivD_imm", // 904
  "sqrtF_reg", // 905
  "sqrtF_mem", // 906
  "sqrtF_imm", // 907
  "sqrtD_reg", // 908
  "sqrtD_mem", // 909
  "sqrtD_imm", // 910
  // last instruction
  "no trailing comma"
};

const        bool  swallowed[] = {
  false, // 0
  false, // 1
  false, // 2
  false, // 3
  false, // 4
  false, // 5
  false, // 6
  false, // 7
  true, // 8
  true, // 9
  true, // 10
  true, // 11
  true, // 12
  true, // 13
  true, // 14
  true, // 15
  true, // 16
  true, // 17
  true, // 18
  true, // 19
  true, // 20
  true, // 21
  true, // 22
  true, // 23
  true, // 24
  true, // 25
  true, // 26
  true, // 27
  true, // 28
  true, // 29
  true, // 30
  true, // 31
  true, // 32
  true, // 33
  true, // 34
  true, // 35
  true, // 36
  true, // 37
  true, // 38
  true, // 39
  true, // 40
  true, // 41
  true, // 42
  false, // 43
  false, // 44
  false, // 45
  false, // 46
  false, // 47
  false, // 48
  false, // 49
  false, // 50
  false, // 51
  false, // 52
  false, // 53
  false, // 54
  false, // 55
  false, // 56
  false, // 57
  false, // 58
  false, // 59
  false, // 60
  false, // 61
  false, // 62
  false, // 63
  false, // 64
  false, // 65
  false, // 66
  false, // 67
  false, // 68
  false, // 69
  false, // 70
  false, // 71
  false, // 72
  false, // 73
  false, // 74
  false, // 75
  false, // 76
  false, // 77
  false, // 78
  false, // 79
  false, // 80
  false, // 81
  false, // 82
  false, // 83
  false, // 84
  false, // 85
  true, // 86
  false, // 87
  false, // 88
  false, // 89
  false, // 90
  false, // 91
  false, // 92
  false, // 93
  false, // 94
  false, // 95
  false, // 96
  false, // 97
  false, // 98
  false, // 99
  false, // 100
  false, // 101
  false, // 102
  false, // 103
  false, // 104
  false, // 105
  false, // 106
  false, // 107
  false, // 108
  true, // 109
  true, // 110
  true, // 111
  true, // 112
  true, // 113
  true, // 114
  // last operand
  false, // 115
  false, // 116
  false, // 117
  // last operand class
  false, // 118
  false, // 119
  false, // 120
  false, // 121
  false, // 122
  false, // 123
  false, // 124
  false, // 125
  false, // 126
  false, // 127
  false, // 128
  false, // 129
  false, // 130
  false, // 131
  false, // 132
  false, // 133
  false, // 134
  false, // 135
  false, // 136
  false, // 137
  false, // 138
  false, // 139
  false, // 140
  false, // 141
  false, // 142
  false, // 143
  false, // 144
  false, // 145
  false, // 146
  false, // 147
  false, // 148
  false, // 149
  false, // 150
  false, // 151
  false, // 152
  false, // 153
  false, // 154
  false, // 155
  false, // 156
  false, // 157
  false, // 158
  false, // 159
  false, // 160
  false, // 161
  false, // 162
  false, // 163
  false, // 164
  false, // 165
  false, // 166
  false, // 167
  false, // 168
  false, // 169
  false, // 170
  false, // 171
  false, // 172
  false, // 173
  false, // 174
  false, // 175
  false, // 176
  false, // 177
  false, // 178
  false, // 179
  false, // 180
  false, // 181
  false, // 182
  false, // 183
  false, // 184
  false, // 185
  false, // 186
  false, // 187
  false, // 188
  false, // 189
  false, // 190
  false, // 191
  false, // 192
  false, // 193
  false, // 194
  false, // 195
  false, // 196
  false, // 197
  false, // 198
  false, // 199
  false, // 200
  false, // 201
  false, // 202
  false, // 203
  false, // 204
  false, // 205
  false, // 206
  false, // 207
  false, // 208
  false, // 209
  false, // 210
  false, // 211
  false, // 212
  false, // 213
  false, // 214
  false, // 215
  false, // 216
  false, // 217
  false, // 218
  false, // 219
  false, // 220
  false, // 221
  false, // 222
  false, // 223
  false, // 224
  false, // 225
  false, // 226
  false, // 227
  false, // 228
  false, // 229
  false, // 230
  false, // 231
  false, // 232
  false, // 233
  false, // 234
  false, // 235
  false, // 236
  false, // 237
  false, // 238
  false, // 239
  false, // 240
  false, // 241
  false, // 242
  false, // 243
  false, // 244
  false, // 245
  false, // 246
  false, // 247
  // last internally defined operand
  false, // 248
  false, // 249
  false, // 250
  false, // 251
  false, // 252
  false, // 253
  false, // 254
  false, // 255
  false, // 256
  false, // 257
  false, // 258
  false, // 259
  false, // 260
  false, // 261
  false, // 262
  false, // 263
  false, // 264
  false, // 265
  false, // 266
  false, // 267
  false, // 268
  false, // 269
  false, // 270
  false, // 271
  false, // 272
  false, // 273
  false, // 274
  false, // 275
  false, // 276
  false, // 277
  false, // 278
  false, // 279
  false, // 280
  false, // 281
  false, // 282
  false, // 283
  false, // 284
  false, // 285
  false, // 286
  false, // 287
  false, // 288
  false, // 289
  false, // 290
  false, // 291
  false, // 292
  false, // 293
  false, // 294
  false, // 295
  false, // 296
  false, // 297
  false, // 298
  false, // 299
  false, // 300
  false, // 301
  false, // 302
  false, // 303
  false, // 304
  false, // 305
  false, // 306
  false, // 307
  false, // 308
  false, // 309
  false, // 310
  false, // 311
  false, // 312
  false, // 313
  false, // 314
  false, // 315
  false, // 316
  false, // 317
  false, // 318
  false, // 319
  false, // 320
  false, // 321
  false, // 322
  false, // 323
  false, // 324
  false, // 325
  false, // 326
  false, // 327
  false, // 328
  false, // 329
  false, // 330
  false, // 331
  false, // 332
  false, // 333
  false, // 334
  false, // 335
  false, // 336
  false, // 337
  false, // 338
  false, // 339
  false, // 340
  false, // 341
  false, // 342
  false, // 343
  false, // 344
  false, // 345
  false, // 346
  false, // 347
  false, // 348
  false, // 349
  false, // 350
  false, // 351
  false, // 352
  false, // 353
  false, // 354
  false, // 355
  false, // 356
  false, // 357
  false, // 358
  false, // 359
  false, // 360
  false, // 361
  false, // 362
  false, // 363
  false, // 364
  false, // 365
  false, // 366
  false, // 367
  false, // 368
  false, // 369
  false, // 370
  false, // 371
  false, // 372
  false, // 373
  false, // 374
  false, // 375
  false, // 376
  false, // 377
  false, // 378
  false, // 379
  false, // 380
  false, // 381
  false, // 382
  false, // 383
  false, // 384
  false, // 385
  false, // 386
  false, // 387
  false, // 388
  false, // 389
  false, // 390
  false, // 391
  false, // 392
  false, // 393
  false, // 394
  false, // 395
  false, // 396
  false, // 397
  false, // 398
  false, // 399
  false, // 400
  false, // 401
  false, // 402
  false, // 403
  false, // 404
  false, // 405
  false, // 406
  false, // 407
  false, // 408
  false, // 409
  false, // 410
  false, // 411
  false, // 412
  false, // 413
  false, // 414
  false, // 415
  false, // 416
  false, // 417
  false, // 418
  false, // 419
  false, // 420
  false, // 421
  false, // 422
  false, // 423
  false, // 424
  false, // 425
  false, // 426
  false, // 427
  false, // 428
  false, // 429
  false, // 430
  false, // 431
  false, // 432
  false, // 433
  false, // 434
  false, // 435
  false, // 436
  false, // 437
  false, // 438
  false, // 439
  false, // 440
  false, // 441
  false, // 442
  false, // 443
  false, // 444
  false, // 445
  false, // 446
  false, // 447
  false, // 448
  false, // 449
  false, // 450
  false, // 451
  false, // 452
  false, // 453
  false, // 454
  false, // 455
  false, // 456
  false, // 457
  false, // 458
  false, // 459
  false, // 460
  false, // 461
  false, // 462
  false, // 463
  false, // 464
  false, // 465
  false, // 466
  false, // 467
  false, // 468
  false, // 469
  false, // 470
  false, // 471
  false, // 472
  false, // 473
  false, // 474
  false, // 475
  false, // 476
  false, // 477
  false, // 478
  false, // 479
  false, // 480
  false, // 481
  false, // 482
  false, // 483
  false, // 484
  false, // 485
  false, // 486
  false, // 487
  false, // 488
  false, // 489
  false, // 490
  false, // 491
  false, // 492
  false, // 493
  false, // 494
  false, // 495
  false, // 496
  false, // 497
  false, // 498
  false, // 499
  false, // 500
  false, // 501
  false, // 502
  false, // 503
  false, // 504
  false, // 505
  false, // 506
  false, // 507
  false, // 508
  false, // 509
  false, // 510
  false, // 511
  false, // 512
  false, // 513
  false, // 514
  false, // 515
  false, // 516
  false, // 517
  false, // 518
  false, // 519
  false, // 520
  false, // 521
  false, // 522
  false, // 523
  false, // 524
  false, // 525
  false, // 526
  false, // 527
  false, // 528
  false, // 529
  false, // 530
  false, // 531
  false, // 532
  false, // 533
  false, // 534
  false, // 535
  false, // 536
  false, // 537
  false, // 538
  false, // 539
  false, // 540
  false, // 541
  false, // 542
  false, // 543
  false, // 544
  false, // 545
  false, // 546
  false, // 547
  false, // 548
  false, // 549
  false, // 550
  false, // 551
  false, // 552
  false, // 553
  false, // 554
  false, // 555
  false, // 556
  false, // 557
  false, // 558
  false, // 559
  false, // 560
  false, // 561
  false, // 562
  false, // 563
  false, // 564
  false, // 565
  false, // 566
  false, // 567
  false, // 568
  false, // 569
  false, // 570
  false, // 571
  false, // 572
  false, // 573
  false, // 574
  false, // 575
  false, // 576
  false, // 577
  false, // 578
  false, // 579
  false, // 580
  false, // 581
  false, // 582
  false, // 583
  false, // 584
  false, // 585
  false, // 586
  false, // 587
  false, // 588
  false, // 589
  false, // 590
  false, // 591
  false, // 592
  false, // 593
  false, // 594
  false, // 595
  false, // 596
  false, // 597
  false, // 598
  false, // 599
  false, // 600
  false, // 601
  false, // 602
  false, // 603
  false, // 604
  false, // 605
  false, // 606
  false, // 607
  false, // 608
  false, // 609
  false, // 610
  false, // 611
  false, // 612
  false, // 613
  false, // 614
  false, // 615
  false, // 616
  false, // 617
  false, // 618
  false, // 619
  false, // 620
  false, // 621
  false, // 622
  false, // 623
  false, // 624
  false, // 625
  false, // 626
  false, // 627
  false, // 628
  false, // 629
  false, // 630
  false, // 631
  false, // 632
  false, // 633
  false, // 634
  false, // 635
  false, // 636
  false, // 637
  false, // 638
  false, // 639
  false, // 640
  false, // 641
  false, // 642
  false, // 643
  false, // 644
  false, // 645
  false, // 646
  false, // 647
  false, // 648
  false, // 649
  false, // 650
  false, // 651
  false, // 652
  false, // 653
  false, // 654
  false, // 655
  false, // 656
  false, // 657
  false, // 658
  false, // 659
  false, // 660
  false, // 661
  false, // 662
  false, // 663
  false, // 664
  false, // 665
  false, // 666
  false, // 667
  false, // 668
  false, // 669
  false, // 670
  false, // 671
  false, // 672
  false, // 673
  false, // 674
  false, // 675
  false, // 676
  false, // 677
  false, // 678
  false, // 679
  false, // 680
  false, // 681
  false, // 682
  false, // 683
  false, // 684
  false, // 685
  false, // 686
  false, // 687
  false, // 688
  false, // 689
  false, // 690
  false, // 691
  false, // 692
  false, // 693
  false, // 694
  false, // 695
  false, // 696
  false, // 697
  false, // 698
  false, // 699
  false, // 700
  false, // 701
  false, // 702
  false, // 703
  false, // 704
  false, // 705
  false, // 706
  false, // 707
  false, // 708
  false, // 709
  false, // 710
  false, // 711
  false, // 712
  false, // 713
  false, // 714
  false, // 715
  false, // 716
  false, // 717
  false, // 718
  false, // 719
  false, // 720
  false, // 721
  false, // 722
  false, // 723
  false, // 724
  false, // 725
  false, // 726
  false, // 727
  false, // 728
  false, // 729
  false, // 730
  false, // 731
  false, // 732
  false, // 733
  false, // 734
  false, // 735
  false, // 736
  false, // 737
  false, // 738
  false, // 739
  false, // 740
  false, // 741
  false, // 742
  false, // 743
  false, // 744
  false, // 745
  false, // 746
  false, // 747
  false, // 748
  false, // 749
  false, // 750
  false, // 751
  false, // 752
  false, // 753
  false, // 754
  false, // 755
  false, // 756
  false, // 757
  false, // 758
  false, // 759
  false, // 760
  false, // 761
  false, // 762
  false, // 763
  false, // 764
  false, // 765
  false, // 766
  false, // 767
  false, // 768
  false, // 769
  false, // 770
  false, // 771
  false, // 772
  false, // 773
  false, // 774
  false, // 775
  false, // 776
  false, // 777
  false, // 778
  false, // 779
  false, // 780
  false, // 781
  false, // 782
  false, // 783
  false, // 784
  false, // 785
  false, // 786
  false, // 787
  false, // 788
  false, // 789
  false, // 790
  false, // 791
  false, // 792
  false, // 793
  false, // 794
  false, // 795
  false, // 796
  false, // 797
  false, // 798
  false, // 799
  false, // 800
  false, // 801
  false, // 802
  false, // 803
  false, // 804
  false, // 805
  false, // 806
  false, // 807
  false, // 808
  false, // 809
  false, // 810
  false, // 811
  false, // 812
  false, // 813
  false, // 814
  false, // 815
  false, // 816
  false, // 817
  false, // 818
  false, // 819
  false, // 820
  false, // 821
  false, // 822
  false, // 823
  false, // 824
  false, // 825
  false, // 826
  false, // 827
  false, // 828
  false, // 829
  false, // 830
  false, // 831
  false, // 832
  false, // 833
  false, // 834
  false, // 835
  false, // 836
  false, // 837
  false, // 838
  false, // 839
  false, // 840
  false, // 841
  false, // 842
  false, // 843
  false, // 844
  false, // 845
  false, // 846
  false, // 847
  false, // 848
  false, // 849
  false, // 850
  false, // 851
  false, // 852
  false, // 853
  false, // 854
  false, // 855
  false, // 856
  false, // 857
  false, // 858
  false, // 859
  false, // 860
  false, // 861
  false, // 862
  false, // 863
  false, // 864
  false, // 865
  false, // 866
  false, // 867
  false, // 868
  false, // 869
  false, // 870
  false, // 871
  false, // 872
  false, // 873
  false, // 874
  false, // 875
  false, // 876
  false, // 877
  false, // 878
  false, // 879
  false, // 880
  false, // 881
  false, // 882
  false, // 883
  false, // 884
  false, // 885
  false, // 886
  false, // 887
  false, // 888
  false, // 889
  false, // 890
  false, // 891
  false, // 892
  false, // 893
  false, // 894
  false, // 895
  false, // 896
  false, // 897
  false, // 898
  false, // 899
  false, // 900
  false, // 901
  false, // 902
  false, // 903
  false, // 904
  false, // 905
  false, // 906
  false, // 907
  false, // 908
  false, // 909
  false, // 910
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // RegFlags: 8
  0, // _last_machine_leaf: 9
  0, // AbsD: 10
  0, // AbsF: 11
  0, // AbsI: 12
  0, // AddD: 13
  0, // AddF: 14
  0, // AddI: 15
  0, // AddL: 16
  0, // AddP: 17
  0, // Allocate: 18
  0, // AllocateArray: 19
  0, // AndI: 20
  0, // AndL: 21
  0, // AryEq: 22
  0, // AtanD: 23
  1, // Binary: 24
  1, // Bool: 25
  0, // BoxLock: 26
  0, // ReverseBytesI: 27
  0, // ReverseBytesL: 28
  0, // ReverseBytesUS: 29
  0, // ReverseBytesS: 30
  0, // CProj: 31
  0, // CallDynamicJava: 32
  0, // CallJava: 33
  0, // CallLeaf: 34
  0, // CallLeafNoFP: 35
  0, // CallRuntime: 36
  0, // CallStaticJava: 37
  0, // CastII: 38
  0, // CastX2P: 39
  0, // CastP2X: 40
  0, // CastPP: 41
  0, // Catch: 42
  0, // CatchProj: 43
  0, // CheckCastPP: 44
  0, // ClearArray: 45
  0, // ConstraintCast: 46
  0, // CMoveD: 47
  0, // CMoveF: 48
  0, // CMoveI: 49
  0, // CMoveL: 50
  0, // CMoveP: 51
  0, // CMoveN: 52
  1, // CmpN: 53
  1, // CmpD: 54
  0, // CmpD3: 55
  1, // CmpF: 56
  0, // CmpF3: 57
  1, // CmpI: 58
  1, // CmpL: 59
  0, // CmpL3: 60
  0, // CmpLTMask: 61
  1, // CmpP: 62
  1, // CmpU: 63
  0, // CompareAndSwapI: 64
  0, // CompareAndSwapL: 65
  0, // CompareAndSwapP: 66
  0, // CompareAndSwapN: 67
  0, // Con: 68
  0, // ConN: 69
  0, // ConD: 70
  0, // ConF: 71
  0, // ConI: 72
  0, // ConL: 73
  0, // ConP: 74
  0, // Conv2B: 75
  0, // ConvD2F: 76
  0, // ConvD2I: 77
  0, // ConvD2L: 78
  0, // ConvF2D: 79
  0, // ConvF2I: 80
  0, // ConvF2L: 81
  0, // ConvI2D: 82
  0, // ConvI2F: 83
  0, // ConvI2L: 84
  0, // ConvL2D: 85
  0, // ConvL2F: 86
  0, // ConvL2I: 87
  0, // CosD: 88
  0, // CountedLoop: 89
  0, // CountedLoopEnd: 90
  0, // CountLeadingZerosI: 91
  0, // CountLeadingZerosL: 92
  0, // CountTrailingZerosI: 93
  0, // CountTrailingZerosL: 94
  0, // CreateEx: 95
  0, // DecodeN: 96
  0, // DivD: 97
  0, // DivF: 98
  0, // DivI: 99
  0, // DivL: 100
  0, // DivMod: 101
  0, // DivModI: 102
  0, // DivModL: 103
  0, // EncodeP: 104
  0, // ExpD: 105
  1, // FastLock: 106
  1, // FastUnlock: 107
  0, // Goto: 108
  0, // Halt: 109
  0, // If: 110
  0, // IfFalse: 111
  0, // IfTrue: 112
  0, // Initialize: 113
  0, // JProj: 114
  0, // Jump: 115
  0, // JumpProj: 116
  0, // LShiftI: 117
  0, // LShiftL: 118
  0, // LoadB: 119
  0, // LoadUB: 120
  0, // LoadUS: 121
  0, // LoadD: 122
  0, // LoadD_unaligned: 123
  0, // LoadF: 124
  0, // LoadI: 125
  0, // LoadUI2L: 126
  0, // LoadKlass: 127
  0, // LoadNKlass: 128
  0, // LoadL: 129
  0, // LoadL_unaligned: 130
  0, // LoadPLocked: 131
  0, // LoadLLocked: 132
  0, // LoadP: 133
  0, // LoadN: 134
  0, // LoadRange: 135
  0, // LoadS: 136
  0, // Lock: 137
  0, // LogD: 138
  0, // Log10D: 139
  0, // Loop: 140
  0, // LoopLimit: 141
  0, // Mach: 142
  0, // MachProj: 143
  0, // MaxI: 144
  0, // MemBarAcquire: 145
  0, // MemBarAcquireLock: 146
  0, // MemBarCPUOrder: 147
  0, // MemBarRelease: 148
  0, // MemBarReleaseLock: 149
  0, // MemBarVolatile: 150
  0, // MemBarStoreStore: 151
  0, // MergeMem: 152
  0, // MinI: 153
  0, // ModD: 154
  0, // ModF: 155
  0, // ModI: 156
  0, // ModL: 157
  0, // MoveI2F: 158
  0, // MoveF2I: 159
  0, // MoveL2D: 160
  0, // MoveD2L: 161
  0, // MulD: 162
  0, // MulF: 163
  0, // MulHiL: 164
  0, // MulI: 165
  0, // MulL: 166
  0, // Multi: 167
  0, // NegD: 168
  0, // NegF: 169
  0, // NeverBranch: 170
  0, // Opaque1: 171
  0, // Opaque2: 172
  0, // OrI: 173
  0, // OrL: 174
  0, // PCTable: 175
  0, // Parm: 176
  0, // PartialSubtypeCheck: 177
  0, // Phi: 178
  0, // PopCountI: 179
  0, // PopCountL: 180
  0, // PowD: 181
  0, // PrefetchAllocation: 182
  0, // PrefetchRead: 183
  0, // PrefetchWrite: 184
  0, // Proj: 185
  0, // RShiftI: 186
  0, // RShiftL: 187
  0, // Region: 188
  0, // Rethrow: 189
  0, // Return: 190
  0, // Root: 191
  0, // RoundDouble: 192
  0, // RoundFloat: 193
  0, // SafePoint: 194
  0, // SafePointScalarObject: 195
  0, // SCMemProj: 196
  0, // SinD: 197
  0, // SqrtD: 198
  0, // Start: 199
  0, // StartOSR: 200
  0, // StoreB: 201
  0, // StoreC: 202
  0, // StoreCM: 203
  0, // StorePConditional: 204
  0, // StoreIConditional: 205
  0, // StoreLConditional: 206
  0, // StoreD: 207
  0, // StoreF: 208
  0, // StoreI: 209
  0, // StoreL: 210
  0, // StoreP: 211
  0, // StoreN: 212
  0, // StrComp: 213
  0, // StrEquals: 214
  0, // StrIndexOf: 215
  0, // SubD: 216
  0, // SubF: 217
  0, // SubI: 218
  0, // SubL: 219
  0, // TailCall: 220
  0, // TailJump: 221
  0, // TanD: 222
  0, // ThreadLocal: 223
  0, // Unlock: 224
  0, // URShiftI: 225
  0, // URShiftL: 226
  0, // XorI: 227
  0, // XorL: 228
  0, // Vector: 229
  0, // AddVB: 230
  0, // AddVC: 231
  0, // AddVS: 232
  0, // AddVI: 233
  0, // AddVL: 234
  0, // AddVF: 235
  0, // AddVD: 236
  0, // SubVB: 237
  0, // SubVC: 238
  0, // SubVS: 239
  0, // SubVI: 240
  0, // SubVL: 241
  0, // SubVF: 242
  0, // SubVD: 243
  0, // MulVF: 244
  0, // MulVD: 245
  0, // DivVF: 246
  0, // DivVD: 247
  0, // LShiftVB: 248
  0, // LShiftVC: 249
  0, // LShiftVS: 250
  0, // LShiftVI: 251
  0, // URShiftVB: 252
  0, // URShiftVC: 253
  0, // URShiftVS: 254
  0, // URShiftVI: 255
  0, // AndV: 256
  0, // OrV: 257
  0, // XorV: 258
  0, // VectorLoad: 259
  0, // Load16B: 260
  0, // Load8B: 261
  0, // Load4B: 262
  0, // Load8C: 263
  0, // Load4C: 264
  0, // Load2C: 265
  0, // Load8S: 266
  0, // Load4S: 267
  0, // Load2S: 268
  0, // Load4I: 269
  0, // Load2I: 270
  0, // Load2L: 271
  0, // Load4F: 272
  0, // Load2F: 273
  0, // Load2D: 274
  0, // VectorStore: 275
  0, // Store16B: 276
  0, // Store8B: 277
  0, // Store4B: 278
  0, // Store8C: 279
  0, // Store4C: 280
  0, // Store2C: 281
  0, // Store4I: 282
  0, // Store2I: 283
  0, // Store2L: 284
  0, // Store4F: 285
  0, // Store2F: 286
  0, // Store2D: 287
  0, // Pack: 288
  0, // PackB: 289
  0, // PackS: 290
  0, // PackC: 291
  0, // PackI: 292
  0, // PackL: 293
  0, // PackF: 294
  0, // PackD: 295
  0, // Pack2x1B: 296
  0, // Pack2x2B: 297
  0, // Replicate16B: 298
  0, // Replicate8B: 299
  0, // Replicate4B: 300
  0, // Replicate8S: 301
  0, // Replicate4S: 302
  0, // Replicate2S: 303
  0, // Replicate8C: 304
  0, // Replicate4C: 305
  0, // Replicate2C: 306
  0, // Replicate4I: 307
  0, // Replicate2I: 308
  0, // Replicate2L: 309
  0, // Replicate4F: 310
  0, // Replicate2F: 311
  0, // Replicate2D: 312
  0, // Extract: 313
  0, // ExtractB: 314
  0, // ExtractS: 315
  0, // ExtractC: 316
  0, // ExtractI: 317
  0, // ExtractL: 318
  0, // ExtractF: 319
  0 // no trailing comma // ExtractD: 320
};
//  The following instructions can cisc-spill
//  popCountI can cisc-spill operand 1 to popCountI_mem
//  popCountL can cisc-spill operand 1 to popCountL_mem
//  cmovI_reg can cisc-spill operand 4 to cmovI_mem
//  cmovI_regU can cisc-spill operand 4 to cmovI_memU
//  cmovI_regUCF can cisc-spill operand 4 to cmovI_memUCF
//  addI_eReg can cisc-spill operand 2 to addI_eReg_mem
//  subI_eReg can cisc-spill operand 2 to subI_eReg_mem
//  mulI_eReg can cisc-spill operand 2 to mulI
//  mulI_eReg_imm can cisc-spill operand 1 to mulI_mem_imm
//  i2b can cisc-spill operand 1 to loadI2B
//  i2s can cisc-spill operand 1 to loadI2S
//  andI_eReg can cisc-spill operand 2 to andI_eReg_mem
//  orI_eReg can cisc-spill operand 2 to orI_eReg_mem
//  xorI_eReg can cisc-spill operand 2 to xorI_eReg_mem
//  addL_eReg can cisc-spill operand 2 to addL_eReg_mem
//  subL_eReg can cisc-spill operand 2 to subL_eReg_mem
//  andL_eReg can cisc-spill operand 2 to andL_eReg_mem
//  orl_eReg can cisc-spill operand 2 to orl_eReg_mem
//  xorl_eReg can cisc-spill operand 2 to xorl_eReg_mem
//  cmpD_cc can cisc-spill operand 2 to cmpD_ccmem
//  cmpD_ccCF can cisc-spill operand 2 to cmpD_ccmemCF
//  cmpD_reg can cisc-spill operand 2 to cmpD_regmem
//  subDPR_reg can cisc-spill operand 2 to subDPR_reg_mem
//  addDPR_reg can cisc-spill operand 2 to addDPR_reg_mem
//  mulDPR_reg can cisc-spill operand 2 to mulDPR_reg_mem
//  cmpF_cc can cisc-spill operand 2 to cmpF_ccmem
//  cmpF_ccCF can cisc-spill operand 2 to cmpF_ccmemCF
//  cmpF_reg can cisc-spill operand 2 to cmpF_regmem
//  addFPR24_reg can cisc-spill operand 2 to addFPR24_reg_mem
//  addFPR_reg can cisc-spill operand 2 to addFPR_reg_mem
//  addFPR24_reg_mem can cisc-spill operand 1 to addFPR24_mem_cisc
//  addFPR24_reg_mem_0 can cisc-spill operand 2 to addFPR24_mem_cisc_0
//  addFPR24_mem_reg can cisc-spill operand 2 to addFPR24_mem_cisc
//  mulFPR24_reg can cisc-spill operand 2 to mulFPR24_reg_mem
//  mulFPR_reg can cisc-spill operand 2 to mulFPR_reg_mem
//  addFPR_mulFPR_reg can cisc-spill operand 1 to addFPR_mulFPR_reg_load1
//  addFPR_mulFPR_reg_0 can cisc-spill operand 2 to addFPR_mulFPR_reg_load1_1
//  convI2L_reg can cisc-spill operand 1 to loadI2L
//  compI_eReg can cisc-spill operand 2 to compI_eReg_mem
//  compU_eReg can cisc-spill operand 2 to compU_eReg_mem
//  compP_eReg can cisc-spill operand 2 to compP_eReg_mem
//  cmovLL_reg_LTGE can cisc-spill operand 4 to cmovLL_mem_LTGE
//  cmovII_reg_LTGE can cisc-spill operand 4 to cmovII_mem_LTGE
//  cmovLL_reg_EQNE can cisc-spill operand 4 to cmovLL_mem_EQNE
//  cmovII_reg_EQNE can cisc-spill operand 4 to cmovII_mem_EQNE
//  cmovLL_reg_LEGT can cisc-spill operand 4 to cmovLL_mem_LEGT
//  cmovII_reg_LEGT can cisc-spill operand 4 to cmovII_mem_LEGT
//  addF_reg can cisc-spill operand 2 to addF_mem
//  vaddF_reg can cisc-spill operand 2 to vaddF_mem
//  addD_reg can cisc-spill operand 2 to addD_mem
//  vaddD_reg can cisc-spill operand 2 to vaddD_mem
//  subF_reg can cisc-spill operand 2 to subF_mem
//  vsubF_reg can cisc-spill operand 2 to vsubF_mem
//  subD_reg can cisc-spill operand 2 to subD_mem
//  vsubD_reg can cisc-spill operand 2 to vsubD_mem
//  mulF_reg can cisc-spill operand 2 to mulF_mem
//  vmulF_reg can cisc-spill operand 2 to vmulF_mem
//  mulD_reg can cisc-spill operand 2 to mulD_mem
//  vmulD_reg can cisc-spill operand 2 to vmulD_mem
//  divF_reg can cisc-spill operand 2 to divF_mem
//  vdivF_reg can cisc-spill operand 2 to vdivF_mem
//  divD_reg can cisc-spill operand 2 to divD_mem
//  vdivD_reg can cisc-spill operand 2 to vdivD_mem
//  sqrtF_reg can cisc-spill operand 1 to sqrtF_mem
//  sqrtD_reg can cisc-spill operand 1 to sqrtD_mem



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "ECX",
  "EBX",
  "EBP",
  "EDI",
  "EAX",
  "EDX",
  "ESI",
  "ESP",
  "FPR0L",
  "FPR0H",
  "FPR1L",
  "FPR1H",
  "FPR2L",
  "FPR2H",
  "FPR3L",
  "FPR3H",
  "FPR4L",
  "FPR4H",
  "FPR5L",
  "FPR5H",
  "FPR6L",
  "FPR6H",
  "FPR7L",
  "FPR7H",
  "XMM0a",
  "XMM0b",
  "XMM1a",
  "XMM1b",
  "XMM2a",
  "XMM2b",
  "XMM3a",
  "XMM3b",
  "XMM4a",
  "XMM4b",
  "XMM5a",
  "XMM5b",
  "XMM6a",
  "XMM6b",
  "XMM7a",
  "XMM7b",
  "EFLAGS" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	rcx->as_VMReg(),
	rbx->as_VMReg(),
	rbp->as_VMReg(),
	rdi->as_VMReg(),
	rax->as_VMReg(),
	rdx->as_VMReg(),
	rsi->as_VMReg(),
	rsp->as_VMReg(),
	VMRegImpl::Bad(),
	VMRegImpl::Bad(),
	as_FloatRegister(0)->as_VMReg(),
	as_FloatRegister(0)->as_VMReg()->next(),
	as_FloatRegister(1)->as_VMReg(),
	as_FloatRegister(1)->as_VMReg()->next(),
	as_FloatRegister(2)->as_VMReg(),
	as_FloatRegister(2)->as_VMReg()->next(),
	as_FloatRegister(3)->as_VMReg(),
	as_FloatRegister(3)->as_VMReg()->next(),
	as_FloatRegister(4)->as_VMReg(),
	as_FloatRegister(4)->as_VMReg()->next(),
	as_FloatRegister(5)->as_VMReg(),
	as_FloatRegister(5)->as_VMReg()->next(),
	as_FloatRegister(6)->as_VMReg(),
	as_FloatRegister(6)->as_VMReg()->next(),
	xmm0->as_VMReg(),
	xmm0->as_VMReg()->next(),
	xmm1->as_VMReg(),
	xmm1->as_VMReg()->next(),
	xmm2->as_VMReg(),
	xmm2->as_VMReg()->next(),
	xmm3->as_VMReg(),
	xmm3->as_VMReg()->next(),
	xmm4->as_VMReg(),
	xmm4->as_VMReg()->next(),
	xmm5->as_VMReg(),
	xmm5->as_VMReg()->next(),
	xmm6->as_VMReg(),
	xmm6->as_VMReg()->next(),
	xmm7->as_VMReg(),
	xmm7->as_VMReg()->next(),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\x1',  // ECX
  (unsigned char)'\x3',  // EBX
  (unsigned char)'\x5',  // EBP
  (unsigned char)'\x7',  // EDI
  (unsigned char)'\x0',  // EAX
  (unsigned char)'\x2',  // EDX
  (unsigned char)'\x6',  // ESI
  (unsigned char)'\x4',  // ESP
  (unsigned char)'\x0',  // FPR0L
  (unsigned char)'\x0',  // FPR0H
  (unsigned char)'\x1',  // FPR1L
  (unsigned char)'\x1',  // FPR1H
  (unsigned char)'\x2',  // FPR2L
  (unsigned char)'\x2',  // FPR2H
  (unsigned char)'\x3',  // FPR3L
  (unsigned char)'\x3',  // FPR3H
  (unsigned char)'\x4',  // FPR4L
  (unsigned char)'\x4',  // FPR4H
  (unsigned char)'\x5',  // FPR5L
  (unsigned char)'\x5',  // FPR5H
  (unsigned char)'\x6',  // FPR6L
  (unsigned char)'\x6',  // FPR6H
  (unsigned char)'\x7',  // FPR7L
  (unsigned char)'\x7',  // FPR7H
  (unsigned char)'\x0',  // XMM0a
  (unsigned char)'\x0',  // XMM0b
  (unsigned char)'\x1',  // XMM1a
  (unsigned char)'\x1',  // XMM1b
  (unsigned char)'\x2',  // XMM2a
  (unsigned char)'\x2',  // XMM2b
  (unsigned char)'\x3',  // XMM3a
  (unsigned char)'\x3',  // XMM3b
  (unsigned char)'\x4',  // XMM4a
  (unsigned char)'\x4',  // XMM4b
  (unsigned char)'\x5',  // XMM5a
  (unsigned char)'\x5',  // XMM5b
  (unsigned char)'\x6',  // XMM6a
  (unsigned char)'\x6',  // XMM6b
  (unsigned char)'\x7',  // XMM7a
  (unsigned char)'\x7',  // XMM7b
  (unsigned char)'\x8' // no trailing comma  // EFLAGS
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone(Compile* C) const {
  return  new (C) labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone(Compile* C) const {
  return  new (C) methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *eRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_mask();
}

const RegMask *xRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &X_REG_mask();
}

const RegMask *eAXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EAX_REG_mask();
}

const RegMask *eBXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBX_REG_mask();
}

const RegMask *eCXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ECX_REG_mask();
}

const RegMask *eDXRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EDX_REG_mask();
}

const RegMask *eDIRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EDI_REG_mask();
}

const RegMask *naxRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NAX_REG_mask();
}

const RegMask *nadxRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NADX_REG_mask();
}

const RegMask *ncxRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NCX_REG_mask();
}

const RegMask *eSIRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *anyRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ANY_REG_mask();
}

const RegMask *eRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_mask();
}

const RegMask *eRegP_no_EBPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_NO_RBP_mask();
}

const RegMask *naxRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NAX_REG_mask();
}

const RegMask *nabxRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &NABX_REG_mask();
}

const RegMask *pRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &P_REG_mask();
}

const RegMask *eAXRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EAX_REG_mask();
}

const RegMask *eBXRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBX_REG_mask();
}

const RegMask *eCXRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ECX_REG_mask();
}

const RegMask *eSIRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *eDIRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EDI_REG_mask();
}

const RegMask *eBPRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBP_REG_mask();
}

const RegMask *eRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_REG_mask();
}

const RegMask *eADXRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EADX_REG_mask();
}

const RegMask *eBCXRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EBCX_REG_mask();
}

const RegMask *eADXRegL_low_onlyOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &EADX_REG_mask();
}

const RegMask *eFlagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *eFlagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *eFlagsRegUCFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsReg_long_LTGEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsReg_long_EQNEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsReg_long_LEGTOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *regDPROper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DBL_REG_mask();
}

const RegMask *regDPR1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DBL_REG0_mask();
}

const RegMask *regDPR2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DBL_REG1_mask();
}

const RegMask *regnotDPR1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DBL_NOTREG0_mask();
}

const RegMask *regDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &XDB_REG_mask();
}

const RegMask *regD6Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &XDB_REG6_mask();
}

const RegMask *regD7Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &XDB_REG7_mask();
}

const RegMask *regFPROper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLT_REG_mask();
}

const RegMask *regFPR1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLT_REG0_mask();
}

const RegMask *regFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &XMM_REG_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_mask();
}

const RegMask *indOffset8Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_mask();
}

const RegMask *indOffset32Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_mask();
}

const RegMask *indOffset32XOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_mask();
}

const RegMask *indIndexOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &E_REG_mask();
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &E_REG_mask();
}

const RegMask *indIndexScaleOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &E_REG_mask();
}

const RegMask *indIndexScaleOffsetOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  return &E_REG_mask();
}

const RegMask *load_long_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *load_long_indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *load_long_indOffset32Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ESI_REG_mask();
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *indirect_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_mask();
}

const RegMask *indOffset8_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_NO_RBP_mask();
}

const RegMask *indOffset32_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &E_REG_NO_RBP_mask();
}

const RegMask *indIndexOffset_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &E_REG_NO_RBP_mask();
  case 1: return &E_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScale_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &E_REG_NO_RBP_mask();
  case 1: return &E_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

const RegMask *indIndexScaleOffset_win95_safeOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &E_REG_NO_RBP_mask();
  case 1: return &E_REG_mask();
  }
  ShouldNotReachHere();
  return NULL;
}

//------------------Define members for classes derived from MachNode----------

void popCountINode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *popCountINode::cisc_version( int offset, Compile* C ) {
  popCountI_memNode *node = new (C) popCountI_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void popCountLNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *popCountLNode::cisc_version( int offset, Compile* C ) {
  popCountL_memNode *node = new (C) popCountL_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regNode::cisc_version( int offset, Compile* C ) {
  cmovI_memNode *node = new (C) cmovI_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regUNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regUNode::cisc_version( int offset, Compile* C ) {
  cmovI_memUNode *node = new (C) cmovI_memUNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovI_regUCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovI_regUCFNode::cisc_version( int offset, Compile* C ) {
  cmovI_memUCFNode *node = new (C) cmovI_memUCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *addI_eRegNode::cisc_version( int offset, Compile* C ) {
  addI_eReg_memNode *node = new (C) addI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *subI_eRegNode::cisc_version( int offset, Compile* C ) {
  subI_eReg_memNode *node = new (C) subI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulI_eRegNode::cisc_version( int offset, Compile* C ) {
  mulINode *node = new (C) mulINode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulI_eReg_immNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulI_eReg_immNode::cisc_version( int offset, Compile* C ) {
  mulI_mem_immNode *node = new (C) mulI_mem_immNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void i2bNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_X_REG_mask();
}

// Build CISC version of this instruction
MachNode *i2bNode::cisc_version( int offset, Compile* C ) {
  loadI2BNode *node = new (C) loadI2BNode();
  node->_num_opnds = 3;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void i2sNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_X_REG_mask();
}

// Build CISC version of this instruction
MachNode *i2sNode::cisc_version( int offset, Compile* C ) {
  loadI2SNode *node = new (C) loadI2SNode();
  node->_num_opnds = 3;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *andI_eRegNode::cisc_version( int offset, Compile* C ) {
  andI_eReg_memNode *node = new (C) andI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void orI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *orI_eRegNode::cisc_version( int offset, Compile* C ) {
  orI_eReg_memNode *node = new (C) orI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void xorI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *xorI_eRegNode::cisc_version( int offset, Compile* C ) {
  xorI_eReg_memNode *node = new (C) xorI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addL_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *addL_eRegNode::cisc_version( int offset, Compile* C ) {
  addL_eReg_memNode *node = new (C) addL_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subL_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *subL_eRegNode::cisc_version( int offset, Compile* C ) {
  subL_eReg_memNode *node = new (C) subL_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void andL_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *andL_eRegNode::cisc_version( int offset, Compile* C ) {
  andL_eReg_memNode *node = new (C) andL_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void orl_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *orl_eRegNode::cisc_version( int offset, Compile* C ) {
  orl_eReg_memNode *node = new (C) orl_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void xorl_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *xorl_eRegNode::cisc_version( int offset, Compile* C ) {
  xorl_eReg_memNode *node = new (C) xorl_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_ccNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_ccNode::cisc_version( int offset, Compile* C ) {
  cmpD_ccmemNode *node = new (C) cmpD_ccmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_ccCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_ccCFNode::cisc_version( int offset, Compile* C ) {
  cmpD_ccmemCFNode *node = new (C) cmpD_ccmemCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpD_regNode::cisc_version( int offset, Compile* C ) {
  cmpD_regmemNode *node = new (C) cmpD_regmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subDPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DBL_REG_mask();
}

// Build CISC version of this instruction
MachNode *subDPR_regNode::cisc_version( int offset, Compile* C ) {
  subDPR_reg_memNode *node = new (C) subDPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addDPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DBL_REG_mask();
}

// Build CISC version of this instruction
MachNode *addDPR_regNode::cisc_version( int offset, Compile* C ) {
  addDPR_reg_memNode *node = new (C) addDPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulDPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_DBL_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulDPR_regNode::cisc_version( int offset, Compile* C ) {
  mulDPR_reg_memNode *node = new (C) mulDPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_ccNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_ccNode::cisc_version( int offset, Compile* C ) {
  cmpF_ccmemNode *node = new (C) cmpF_ccmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_ccCFNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_ccCFNode::cisc_version( int offset, Compile* C ) {
  cmpF_ccmemCFNode *node = new (C) cmpF_ccmemCFNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmpF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmpF_regNode::cisc_version( int offset, Compile* C ) {
  cmpF_regmemNode *node = new (C) cmpF_regmemNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_regNode::cisc_version( int offset, Compile* C ) {
  addFPR24_reg_memNode *node = new (C) addFPR24_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR_regNode::cisc_version( int offset, Compile* C ) {
  addFPR_reg_memNode *node = new (C) addFPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_reg_memNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_reg_memNode::cisc_version( int offset, Compile* C ) {
  addFPR24_mem_ciscNode *node = new (C) addFPR24_mem_ciscNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_reg_mem_0Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_reg_mem_0Node::cisc_version( int offset, Compile* C ) {
  addFPR24_mem_cisc_0Node *node = new (C) addFPR24_mem_cisc_0Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR24_mem_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR24_mem_regNode::cisc_version( int offset, Compile* C ) {
  addFPR24_mem_ciscNode *node = new (C) addFPR24_mem_ciscNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulFPR24_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulFPR24_regNode::cisc_version( int offset, Compile* C ) {
  mulFPR24_reg_memNode *node = new (C) mulFPR24_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulFPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulFPR_regNode::cisc_version( int offset, Compile* C ) {
  mulFPR_reg_memNode *node = new (C) mulFPR_reg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR_mulFPR_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR_mulFPR_regNode::cisc_version( int offset, Compile* C ) {
  addFPR_mulFPR_reg_load1Node *node = new (C) addFPR_mulFPR_reg_load1Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addFPR_mulFPR_reg_0Node::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_FLT_REG_mask();
}

// Build CISC version of this instruction
MachNode *addFPR_mulFPR_reg_0Node::cisc_version( int offset, Compile* C ) {
  addFPR_mulFPR_reg_load1_1Node *node = new (C) addFPR_mulFPR_reg_load1_1Node();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void convI2L_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *convI2L_regNode::cisc_version( int offset, Compile* C ) {
  loadI2LNode *node = new (C) loadI2LNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compI_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *compI_eRegNode::cisc_version( int offset, Compile* C ) {
  compI_eReg_memNode *node = new (C) compI_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compU_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *compU_eRegNode::cisc_version( int offset, Compile* C ) {
  compU_eReg_memNode *node = new (C) compU_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void compP_eRegNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *compP_eRegNode::cisc_version( int offset, Compile* C ) {
  compP_eReg_memNode *node = new (C) compP_eReg_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}

// Build short branch version of this instruction
MachNode *jmpDirNode::short_branch_version(Compile* C) {
  jmpDir_shortNode *node = new (C) jmpDir_shortNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConNode::short_branch_version(Compile* C) {
  jmpCon_shortNode *node = new (C) jmpCon_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndNode::short_branch_version(Compile* C) {
  jmpLoopEnd_shortNode *node = new (C) jmpLoopEnd_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndUNode::short_branch_version(Compile* C) {
  jmpLoopEndU_shortNode *node = new (C) jmpLoopEndU_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpLoopEndUCFNode::short_branch_version(Compile* C) {
  jmpLoopEndUCF_shortNode *node = new (C) jmpLoopEndUCF_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUNode::short_branch_version(Compile* C) {
  jmpConU_shortNode *node = new (C) jmpConU_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUCFNode::short_branch_version(Compile* C) {
  jmpConUCF_shortNode *node = new (C) jmpConUCF_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}

// Build short branch version of this instruction
MachNode *jmpConUCF2Node::short_branch_version(Compile* C) {
  jmpConUCF2_shortNode *node = new (C) jmpConUCF2_shortNode();
  node->_prob = _prob;
  node->_fcnt = _fcnt;

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  return node;
}


void cmovLL_reg_LTGENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovLL_reg_LTGENode::cisc_version( int offset, Compile* C ) {
  cmovLL_mem_LTGENode *node = new (C) cmovLL_mem_LTGENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovII_reg_LTGENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovII_reg_LTGENode::cisc_version( int offset, Compile* C ) {
  cmovII_mem_LTGENode *node = new (C) cmovII_mem_LTGENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovLL_reg_EQNENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovLL_reg_EQNENode::cisc_version( int offset, Compile* C ) {
  cmovLL_mem_EQNENode *node = new (C) cmovLL_mem_EQNENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovII_reg_EQNENode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovII_reg_EQNENode::cisc_version( int offset, Compile* C ) {
  cmovII_mem_EQNENode *node = new (C) cmovII_mem_EQNENode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovLL_reg_LEGTNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_LONG_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovLL_reg_LEGTNode::cisc_version( int offset, Compile* C ) {
  cmovLL_mem_LEGTNode *node = new (C) cmovLL_mem_LEGTNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void cmovII_reg_LEGTNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_E_REG_mask();
}

// Build CISC version of this instruction
MachNode *cmovII_reg_LEGTNode::cisc_version( int offset, Compile* C ) {
  cmovII_mem_LEGTNode *node = new (C) cmovII_mem_LEGTNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *addF_regNode::cisc_version( int offset, Compile* C ) {
  addF_memNode *node = new (C) addF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vaddF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *vaddF_regNode::cisc_version( int offset, Compile* C ) {
  vaddF_memNode *node = new (C) vaddF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void addD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *addD_regNode::cisc_version( int offset, Compile* C ) {
  addD_memNode *node = new (C) addD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vaddD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *vaddD_regNode::cisc_version( int offset, Compile* C ) {
  vaddD_memNode *node = new (C) vaddD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *subF_regNode::cisc_version( int offset, Compile* C ) {
  subF_memNode *node = new (C) subF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vsubF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *vsubF_regNode::cisc_version( int offset, Compile* C ) {
  vsubF_memNode *node = new (C) vsubF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void subD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *subD_regNode::cisc_version( int offset, Compile* C ) {
  subD_memNode *node = new (C) subD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vsubD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *vsubD_regNode::cisc_version( int offset, Compile* C ) {
  vsubD_memNode *node = new (C) vsubD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulF_regNode::cisc_version( int offset, Compile* C ) {
  mulF_memNode *node = new (C) mulF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vmulF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *vmulF_regNode::cisc_version( int offset, Compile* C ) {
  vmulF_memNode *node = new (C) vmulF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void mulD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *mulD_regNode::cisc_version( int offset, Compile* C ) {
  mulD_memNode *node = new (C) mulD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vmulD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *vmulD_regNode::cisc_version( int offset, Compile* C ) {
  vmulD_memNode *node = new (C) vmulD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *divF_regNode::cisc_version( int offset, Compile* C ) {
  divF_memNode *node = new (C) divF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vdivF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *vdivF_regNode::cisc_version( int offset, Compile* C ) {
  vdivF_memNode *node = new (C) vdivF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void divD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *divD_regNode::cisc_version( int offset, Compile* C ) {
  divD_memNode *node = new (C) divD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void vdivD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *vdivD_regNode::cisc_version( int offset, Compile* C ) {
  vdivD_memNode *node = new (C) vdivD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void sqrtF_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XMM_REG_mask();
}

// Build CISC version of this instruction
MachNode *sqrtF_regNode::cisc_version( int offset, Compile* C ) {
  sqrtF_memNode *node = new (C) sqrtF_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


void sqrtD_regNode::use_cisc_RegMask() {
  _cisc_RegMask = &STACK_OR_XDB_REG_mask();
}

// Build CISC version of this instruction
MachNode *sqrtD_regNode::cisc_version( int offset, Compile* C ) {
  sqrtD_memNode *node = new (C) sqrtD_memNode();

  // Copy _idx, inputs and operands to new node
  fill_new_machnode(node, C);
  // Construct operand to access [stack_pointer + offset]
  node->set_opnd_array(cisc_operand(), new (C) indOffset32Oper(offset));

  return node;
}


// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode( MachNode* node, Compile* C) const {
  // New node must use same node index
  node->set_idx( _idx );
  // Copy machine-independent inputs
  for( uint j = 0; j < req(); j++ ) {
    node->add_req(in(j));
  }
  // Copy my operands, except for cisc position
  int nopnds = num_opnds();
  assert( node->num_opnds() == (uint)nopnds, "Must have same number of operands");
  MachOper **to = node->_opnds;
  for( int i = 0; i < nopnds; i++ ) {
    if( i != cisc_operand() ) 
      to[i] = _opnds[i]->clone(C);
  }
}

void jmpDirNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpDirNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUCFNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUCFNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCFNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCFNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF2Node::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF2Node::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpDir_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpDir_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpCon_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpCon_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEnd_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEnd_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndU_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndU_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpLoopEndUCF_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpLoopEndUCF_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConU_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConU_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void jmpConUCF2_shortNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void jmpConUCF2_shortNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_LTGENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_LTGENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_EQNENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_EQNENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void cmpL_LEGTNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void cmpL_LEGTNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallStaticJavaHandleNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int  popCountI_memNode::reloc()   const {
  return  1;
}

int  popCountL_memNode::reloc()   const {
  return  1;
}

int  loadBNode::reloc()   const {
  return  1;
}

int  loadB2LNode::reloc()   const {
  return  1;
}

int  loadUBNode::reloc()   const {
  return  1;
}

int  loadUB2LNode::reloc()   const {
  return  1;
}

int  loadUB2L_immI8Node::reloc()   const {
  return  1;
}

int  loadSNode::reloc()   const {
  return  1;
}

int  loadS2BNode::reloc()   const {
  return  1;
}

int  loadS2LNode::reloc()   const {
  return  1;
}

int  loadUSNode::reloc()   const {
  return  1;
}

int  loadUS2BNode::reloc()   const {
  return  1;
}

int  loadUS2LNode::reloc()   const {
  return  1;
}

int  loadUS2L_immI_255Node::reloc()   const {
  return  1;
}

int  loadUS2L_immI16Node::reloc()   const {
  return  1;
}

int  loadINode::reloc()   const {
  return  1;
}

int  loadI2BNode::reloc()   const {
  return  1;
}

int  loadI2UBNode::reloc()   const {
  return  1;
}

int  loadI2SNode::reloc()   const {
  return  1;
}

int  loadI2USNode::reloc()   const {
  return  1;
}

int  loadI2LNode::reloc()   const {
  return  1;
}

int  loadI2L_immI_255Node::reloc()   const {
  return  1;
}

int  loadI2L_immI_65535Node::reloc()   const {
  return  1;
}

int  loadI2L_immINode::reloc()   const {
  return  1;
}

int  loadUI2LNode::reloc()   const {
  return  1;
}

int  loadLNode::reloc()   const {
  return  1;
}

int  loadL_volatileNode::reloc()   const {
  return  1;
}

int  loadLX_volatileNode::reloc()   const {
  return  1;
}

int  loadLX_reg_volatileNode::reloc()   const {
  return  1;
}

int  loadRangeNode::reloc()   const {
  return  1;
}

int  loadPNode::reloc()   const {
  return  1;
}

int  loadKlassNode::reloc()   const {
  return  1;
}

int  loadDPRNode::reloc()   const {
  return  1;
}

int  loadDNode::reloc()   const {
  return  1;
}

int  loadD_partialNode::reloc()   const {
  return  1;
}

int  loadFNode::reloc()   const {
  return  1;
}

int  loadFPRNode::reloc()   const {
  return  1;
}

int  loadA8BNode::reloc()   const {
  return  1;
}

int  loadA4SNode::reloc()   const {
  return  1;
}

int  loadA4CNode::reloc()   const {
  return  1;
}

int  load2IUNode::reloc()   const {
  return  1;
}

int  loadA2FNode::reloc()   const {
  return  1;
}

int  loadConPNode::reloc()   const {
  return  1;
}

int  loadConFPRNode::reloc()   const {
  return  2;
}

int  loadConFPR0Node::reloc()   const {
  return  2;
}

int  loadConFPR1Node::reloc()   const {
  return  2;
}

int  loadConFNode::reloc()   const {
  return  2;
}

int  loadConF0Node::reloc()   const {
  return  2;
}

int  loadConDPRNode::reloc()   const {
  return  2;
}

int  loadConDPR0Node::reloc()   const {
  return  2;
}

int  loadConDPR1Node::reloc()   const {
  return  2;
}

int  loadConDNode::reloc()   const {
  return  2;
}

int  loadConD0Node::reloc()   const {
  return  2;
}

int  prefetchr0Node::reloc()   const {
  return  1;
}

int  prefetchrNode::reloc()   const {
  return  1;
}

int  prefetchrNTANode::reloc()   const {
  return  1;
}

int  prefetchrT0Node::reloc()   const {
  return  1;
}

int  prefetchrT2Node::reloc()   const {
  return  1;
}

int  prefetchw0Node::reloc()   const {
  return  1;
}

int  prefetchwNode::reloc()   const {
  return  1;
}

int  prefetchwNTANode::reloc()   const {
  return  1;
}

int  prefetchAlloc0Node::reloc()   const {
  return  1;
}

int  prefetchAllocNode::reloc()   const {
  return  1;
}

int  prefetchAllocNTANode::reloc()   const {
  return  1;
}

int  prefetchAllocT0Node::reloc()   const {
  return  1;
}

int  prefetchAllocT2Node::reloc()   const {
  return  1;
}

int  storeBNode::reloc()   const {
  return  2;
}

int  storeCNode::reloc()   const {
  return  2;
}

int  storeINode::reloc()   const {
  return  2;
}

int  storeLNode::reloc()   const {
  return  2;
}

int  storeL2INode::reloc()   const {
  return  2;
}

int  storeL_volatileNode::reloc()   const {
  return  2;
}

int  storeLX_volatileNode::reloc()   const {
  return  2;
}

int  storeLX_reg_volatileNode::reloc()   const {
  return  2;
}

int  storePNode::reloc()   const {
  return  2;
}

int  storeImmINode::reloc()   const {
  return  2;
}

int  storeImmI16Node::reloc()   const {
  return  2;
}

int  storeImmPNode::reloc()   const {
  return  3;
}

int  storeImmBNode::reloc()   const {
  return  2;
}

int  storeA8BNode::reloc()   const {
  return  2;
}

int  storeA4CNode::reloc()   const {
  return  2;
}

int  storeA2INode::reloc()   const {
  return  2;
}

int  storeImmCMNode::reloc()   const {
  return  2;
}

int  storeDPRNode::reloc()   const {
  return  2;
}

int  storeDPR_roundedNode::reloc()   const {
  return  2;
}

int  storeDNode::reloc()   const {
  return  2;
}

int  storeFNode::reloc()   const {
  return  2;
}

int  storeA2FNode::reloc()   const {
  return  2;
}

int  storeFPRNode::reloc()   const {
  return  2;
}

int  storeFPR_roundedNode::reloc()   const {
  return  2;
}

int  storeFPR_DroundedNode::reloc()   const {
  return  2;
}

int  storeFPR_immNode::reloc()   const {
  return  3;
}

int  storeF_immNode::reloc()   const {
  return  3;
}

int  cmovI_memNode::reloc()   const {
  return  1;
}

int  cmovI_memUNode::reloc()   const {
  return  1;
}

int  cmovI_memUCFNode::reloc()   const {
  return  1;
}

int  addI_eReg_memNode::reloc()   const {
  return  1;
}

int  addI_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  addI_mem_eRegNode::reloc()   const {
  return  3;
}

int  addI_mem_eReg_0Node::reloc()   const {
  return  3;
}

int  addI_mem_immNode::reloc()   const {
  return  3;
}

int  incI_memNode::reloc()   const {
  return  3;
}

int  decI_memNode::reloc()   const {
  return  3;
}

int  loadPLockedNode::reloc()   const {
  return  1;
}

int  loadLLockedNode::reloc()   const {
  return  1;
}

int  loadLX_LockedNode::reloc()   const {
  return  1;
}

int  loadLX_reg_LockedNode::reloc()   const {
  return  1;
}

int  storePConditionalNode::reloc()   const {
  return  1;
}

int  storeIConditionalNode::reloc()   const {
  return  1;
}

int  storeLConditionalNode::reloc()   const {
  return  1;
}

int  subI_eReg_memNode::reloc()   const {
  return  1;
}

int  subI_mem_eRegNode::reloc()   const {
  return  3;
}

int  mulI_mem_immNode::reloc()   const {
  return  1;
}

int  mulINode::reloc()   const {
  return  1;
}

int  mulI_0Node::reloc()   const {
  return  1;
}

int  sarI_mem_1Node::reloc()   const {
  return  3;
}

int  sarI_mem_immNode::reloc()   const {
  return  3;
}

int  andI_eReg_memNode::reloc()   const {
  return  1;
}

int  andI_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  andI_mem_eRegNode::reloc()   const {
  return  3;
}

int  andI_mem_eReg_0Node::reloc()   const {
  return  3;
}

int  andI_mem_immNode::reloc()   const {
  return  3;
}

int  orI_eReg_memNode::reloc()   const {
  return  1;
}

int  orI_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  orI_mem_eRegNode::reloc()   const {
  return  3;
}

int  orI_mem_eReg_0Node::reloc()   const {
  return  3;
}

int  orI_mem_immNode::reloc()   const {
  return  3;
}

int  xorI_eReg_memNode::reloc()   const {
  return  1;
}

int  xorI_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  xorI_mem_eRegNode::reloc()   const {
  return  3;
}

int  xorI_mem_eReg_0Node::reloc()   const {
  return  3;
}

int  xorI_mem_immNode::reloc()   const {
  return  3;
}

int  addL_eReg_memNode::reloc()   const {
  return  1;
}

int  addL_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  subL_eReg_memNode::reloc()   const {
  return  1;
}

int  andL_eReg_memNode::reloc()   const {
  return  1;
}

int  andL_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  orl_eReg_memNode::reloc()   const {
  return  1;
}

int  orl_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  xorl_eReg_memNode::reloc()   const {
  return  1;
}

int  xorl_eReg_mem_0Node::reloc()   const {
  return  1;
}

int  cmpDPR_0Node::reloc()   const {
  return  1;
}

int  cmpD_ccmemNode::reloc()   const {
  return  1;
}

int  cmpD_ccmemCFNode::reloc()   const {
  return  1;
}

int  cmpD_regmemNode::reloc()   const {
  return  1;
}

int  subDPR_reg_memNode::reloc()   const {
  return  1;
}

int  addDPR_reg_memNode::reloc()   const {
  return  1;
}

int  addDPR_reg_mem_0Node::reloc()   const {
  return  1;
}

int  addDPR_mem_regNode::reloc()   const {
  return  3;
}

int  addDPR_mem_reg_0Node::reloc()   const {
  return  3;
}

int  addDPR_reg_imm1Node::reloc()   const {
  return  1;
}

int  addDPR_reg_immNode::reloc()   const {
  return  1;
}

int  addDPR_reg_imm_roundNode::reloc()   const {
  return  1;
}

int  mulDPR_reg_immNode::reloc()   const {
  return  1;
}

int  mulDPR_reg_memNode::reloc()   const {
  return  1;
}

int  mulDPR_reg_mem_0Node::reloc()   const {
  return  1;
}

int  mulDPR_reg_mem_ciscNode::reloc()   const {
  return  1;
}

int  mulDPR_reg_mem_cisc_0Node::reloc()   const {
  return  1;
}

int  cmpFPR_0Node::reloc()   const {
  return  1;
}

int  cmpF_ccmemNode::reloc()   const {
  return  1;
}

int  cmpF_ccmemCFNode::reloc()   const {
  return  1;
}

int  cmpF_regmemNode::reloc()   const {
  return  1;
}

int  addFPR24_reg_memNode::reloc()   const {
  return  1;
}

int  addFPR24_reg_mem_0Node::reloc()   const {
  return  1;
}

int  addFPR_reg_memNode::reloc()   const {
  return  1;
}

int  addFPR_reg_mem_0Node::reloc()   const {
  return  1;
}

int  addFPR24_mem_regNode::reloc()   const {
  return  1;
}

int  addFPR24_mem_ciscNode::reloc()   const {
  return  2;
}

int  addFPR24_mem_cisc_0Node::reloc()   const {
  return  2;
}

int  addFPR24_mem_memNode::reloc()   const {
  return  2;
}

int  addFPR24_reg_immNode::reloc()   const {
  return  1;
}

int  addFPR_reg_immNode::reloc()   const {
  return  1;
}

int  mulFPR24_reg_memNode::reloc()   const {
  return  1;
}

int  mulFPR24_reg_mem_0Node::reloc()   const {
  return  1;
}

int  mulFPR_reg_memNode::reloc()   const {
  return  1;
}

int  mulFPR_reg_mem_0Node::reloc()   const {
  return  1;
}

int  mulFPR24_mem_memNode::reloc()   const {
  return  2;
}

int  mulFPR24_reg_immNode::reloc()   const {
  return  1;
}

int  mulFPR_reg_immNode::reloc()   const {
  return  1;
}

int  mulFPR_reg_load1Node::reloc()   const {
  return  1;
}

int  mulFPR_reg_load1_0Node::reloc()   const {
  return  1;
}

int  addFPR_mulFPR_reg_load1Node::reloc()   const {
  return  1;
}

int  addFPR_mulFPR_reg_load1_1Node::reloc()   const {
  return  1;
}

int  addFPR_mulFPR_reg_load1_0Node::reloc()   const {
  return  1;
}

int  addFPR_mulFPR_reg_load1_2Node::reloc()   const {
  return  1;
}

int  convI2D_memNode::reloc()   const {
  return  1;
}

int  convI2DPR_memNode::reloc()   const {
  return  1;
}

int  convI2FPR_SSF_memNode::reloc()   const {
  return  1;
}

int  convI2FPR_memNode::reloc()   const {
  return  1;
}

int  Repl2F_immF0Node::reloc()   const {
  return  1;
}

int  compI_eReg_memNode::reloc()   const {
  return  1;
}

int  testI_reg_memNode::reloc()   const {
  return  1;
}

int  compU_eReg_memNode::reloc()   const {
  return  1;
}

int  compP_eReg_immNode::reloc()   const {
  return  1;
}

int  compP_eReg_memNode::reloc()   const {
  return  1;
}

int  compP_mem_eRegNode::reloc()   const {
  return  1;
}

int  testP_regNode::reloc()   const {
  return  1;
}

int  testP_Reg_memNode::reloc()   const {
  return  1;
}

int  partialSubtypeCheck_vs_ZeroNode::reloc()   const {
  return  1;
}

int  cmovLL_mem_LTGENode::reloc()   const {
  return  1;
}

int  cmovII_mem_LTGENode::reloc()   const {
  return  1;
}

int  cmovLL_mem_EQNENode::reloc()   const {
  return  1;
}

int  cmovII_mem_EQNENode::reloc()   const {
  return  1;
}

int  cmovLL_mem_LEGTNode::reloc()   const {
  return  1;
}

int  cmovII_mem_LEGTNode::reloc()   const {
  return  1;
}

int  CallStaticJavaDirectNode::reloc()   const {
  return  1;
}

int  CallStaticJavaHandleNode::reloc()   const {
  return  1;
}

int  CallDynamicJavaDirectNode::reloc()   const {
  return  1;
}

int  CallRuntimeDirectNode::reloc()   const {
  return  1;
}

int  CallLeafDirectNode::reloc()   const {
  return  1;
}

int  CallLeafNoFPDirectNode::reloc()   const {
  return  1;
}

int  RetNode::reloc()   const {
  return  1;
}

int  TailCalljmpIndNode::reloc()   const {
  return  1;
}

int  tailjmpIndNode::reloc()   const {
  return  1;
}

int  RethrowExceptionNode::reloc()   const {
  return  1;
}

int  safePoint_pollNode::reloc()   const {
  return  1;
}

int  addF_memNode::reloc()   const {
  return  1;
}

int  addF_mem_0Node::reloc()   const {
  return  1;
}

int  addF_immNode::reloc()   const {
  return  1;
}

int  vaddF_memNode::reloc()   const {
  return  1;
}

int  vaddF_mem_0Node::reloc()   const {
  return  1;
}

int  vaddF_immNode::reloc()   const {
  return  1;
}

int  addD_memNode::reloc()   const {
  return  1;
}

int  addD_mem_0Node::reloc()   const {
  return  1;
}

int  addD_immNode::reloc()   const {
  return  1;
}

int  vaddD_memNode::reloc()   const {
  return  1;
}

int  vaddD_mem_0Node::reloc()   const {
  return  1;
}

int  vaddD_immNode::reloc()   const {
  return  1;
}

int  subF_memNode::reloc()   const {
  return  1;
}

int  subF_immNode::reloc()   const {
  return  1;
}

int  vsubF_memNode::reloc()   const {
  return  1;
}

int  vsubF_immNode::reloc()   const {
  return  1;
}

int  subD_memNode::reloc()   const {
  return  1;
}

int  subD_immNode::reloc()   const {
  return  1;
}

int  vsubD_memNode::reloc()   const {
  return  1;
}

int  vsubD_immNode::reloc()   const {
  return  1;
}

int  mulF_memNode::reloc()   const {
  return  1;
}

int  mulF_mem_0Node::reloc()   const {
  return  1;
}

int  mulF_immNode::reloc()   const {
  return  1;
}

int  vmulF_memNode::reloc()   const {
  return  1;
}

int  vmulF_mem_0Node::reloc()   const {
  return  1;
}

int  vmulF_immNode::reloc()   const {
  return  1;
}

int  mulD_memNode::reloc()   const {
  return  1;
}

int  mulD_mem_0Node::reloc()   const {
  return  1;
}

int  mulD_immNode::reloc()   const {
  return  1;
}

int  vmulD_memNode::reloc()   const {
  return  1;
}

int  vmulD_mem_0Node::reloc()   const {
  return  1;
}

int  vmulD_immNode::reloc()   const {
  return  1;
}

int  divF_memNode::reloc()   const {
  return  1;
}

int  divF_immNode::reloc()   const {
  return  1;
}

int  vdivF_memNode::reloc()   const {
  return  1;
}

int  vdivF_immNode::reloc()   const {
  return  1;
}

int  divD_memNode::reloc()   const {
  return  1;
}

int  divD_immNode::reloc()   const {
  return  1;
}

int  vdivD_memNode::reloc()   const {
  return  1;
}

int  vdivD_immNode::reloc()   const {
  return  1;
}

int  sqrtF_memNode::reloc()   const {
  return  1;
}

int  sqrtF_immNode::reloc()   const {
  return  1;
}

int  sqrtD_memNode::reloc()   const {
  return  1;
}

int  sqrtD_immNode::reloc()   const {
  return  1;
}


void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*primary()*/));
  
#line 9503 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1677 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_cc(cbuf, (0xC8 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 9511 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1681 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int destlo = opnd_array(1)->reg(ra_,this,idx1);
    int desthi = HIGH_FROM_LOW(destlo);
    // bswap lo
    emit_opcode(cbuf, 0x0F);
    emit_cc(cbuf, 0xC8, destlo);
    // bswap hi
    emit_opcode(cbuf, 0x0F);
    emit_cc(cbuf, 0xC8, desthi);
    // xchg lo and hi
    emit_opcode(cbuf, 0x87);
    emit_rm(cbuf, 0x3, destlo, desthi);
  
#line 9535 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 5595 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ bswapl(opnd_array(1)->as_Register(ra_,this,idx1));
    __ shrl(opnd_array(1)->as_Register(ra_,this,idx1), 16); 
  
#line 9551 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 5608 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ bswapl(opnd_array(1)->as_Register(ra_,this,idx1));
    __ sarl(opnd_array(1)->as_Register(ra_,this,idx1), 16); 
  
#line 9567 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 5624 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ lzcntl(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 9582 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void countLeadingZerosI_bsrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 5641 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1);
    Label skip;
    __ bsrl(Rdst, Rsrc);
    __ jccb(Assembler::notZero, skip);
    __ movl(Rdst, -1);
    __ bind(skip);
    __ negl(Rdst);
    __ addl(Rdst, BitsPerInt - 1);
  
#line 9605 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5665 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(2)->as_Register(ra_,this,idx2);
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1);
    Label done;
    __ lzcntl(Rdst, HIGH_FROM_LOW(Rsrc));
    __ jccb(Assembler::carryClear, done);
    __ lzcntl(Rdst, Rsrc);
    __ addl(Rdst, BitsPerInt);
    __ bind(done);
  
#line 9628 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void countLeadingZerosL_bsrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5694 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(2)->as_Register(ra_,this,idx2);
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1);
    Label msw_is_zero;
    Label not_zero;
    __ bsrl(Rdst, HIGH_FROM_LOW(Rsrc));
    __ jccb(Assembler::zero, msw_is_zero);
    __ addl(Rdst, BitsPerInt);
    __ jmpb(not_zero);
    __ bind(msw_is_zero);
    __ bsrl(Rdst, Rsrc);
    __ jccb(Assembler::notZero, not_zero);
    __ movl(Rdst, -1);
    __ bind(not_zero);
    __ negl(Rdst);
    __ addl(Rdst, BitsPerLong - 1);
  
#line 9658 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 5722 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    Label done;
    __ bsfl(Rdst, opnd_array(1)->as_Register(ra_,this,idx1));
    __ jccb(Assembler::notZero, done);
    __ movl(Rdst, BitsPerInt);
    __ bind(done);
  
#line 9678 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5745 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(2)->as_Register(ra_,this,idx2);
    Register Rsrc = opnd_array(1)->as_Register(ra_,this,idx1);
    Label msw_not_zero;
    Label done;
    __ bsfl(Rdst, Rsrc);
    __ jccb(Assembler::notZero, done);
    __ bsfl(Rdst, HIGH_FROM_LOW(Rsrc));
    __ jccb(Assembler::notZero, msw_not_zero);
    __ movl(Rdst, BitsPerInt);
    __ bind(msw_not_zero);
    __ addl(Rdst, BitsPerInt);
    __ bind(done);
  
#line 9705 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 5771 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ popcntl(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 9720 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void popCountI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5783 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ popcntl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 9735 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5798 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ popcntl(opnd_array(2)->as_Register(ra_,this,idx2), opnd_array(1)->as_Register(ra_,this,idx1));
    __ popcntl(opnd_array(3)->as_Register(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ addl(opnd_array(2)->as_Register(ra_,this,idx2), opnd_array(3)->as_Register(ra_,this,idx3));
  
#line 9754 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void popCountL_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5815 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    //__ popcntl($dst$$Register, $mem$$Address$$first);
    //__ popcntl($tmp$$Register, $mem$$Address$$second);
    __ popcntl(opnd_array(2)->as_Register(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), false));
    __ popcntl(opnd_array(3)->as_Register(ra_,this,idx3), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, false));
    __ addl(opnd_array(2)->as_Register(ra_,this,idx2), opnd_array(3)->as_Register(ra_,this,idx3));
  
#line 9775 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5835 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 9790 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5852 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), opnd_array(0)->as_Register(ra_,this)); // This is always a different register.
    __ sarl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), 7); // 24+1 MSB are already signed extended.
  
#line 9807 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5868 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzbl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 9822 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5884 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 9839 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUB2L_immI8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5901 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 9858 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5917 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 9873 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5930 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 9889 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), opnd_array(0)->as_Register(ra_,this)); // This is always a different register.
    __ sarl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), 15); // 16+1 MSB are already signed extended.
  
#line 9906 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5962 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 9921 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 5975 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 9937 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 5990 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)));
  
#line 9953 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUS2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6005 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 9971 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUS2L_immI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6021 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    __ movzwl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 9990 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6037 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10005 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6050 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10021 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2UBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6062 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzbl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10037 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6074 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10053 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2USNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6086 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movzwl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10069 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6102 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), opnd_array(0)->as_Register(ra_,this)); // This is always a different register.
    __ sarl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), 31);
  
#line 10086 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6118 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    __ movzbl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 10104 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2L_immI_65535Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6133 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    __ movzwl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
  
#line 10122 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadI2L_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6149 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Rdst = opnd_array(0)->as_Register(ra_,this);
    __ movl(Rdst, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(Rdst), HIGH_FROM_LOW(Rdst));
    __ andl(Rdst, opnd_array(2)->constant());
  
#line 10141 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6167 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xorl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)));
  
#line 10157 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6185 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Address Amemlo = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), false);
    Address Amemhi = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, false);
    __ movl(opnd_array(0)->as_Register(ra_,this), Amemlo);
    __ movl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), Amemhi);
  
#line 10175 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 3619 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xDF);
    int rm_byte_opcode = 0x05;
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
    store_to_stackslot( cbuf, 0x0DF, 0x07, opnd_array(0)->disp(ra_,this,0) );
  
#line 10197 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadLX_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6216 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdbl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 10214 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadLX_reg_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6232 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdl(opnd_array(0)->as_Register(ra_,this), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    __ psrlq(opnd_array(2)->as_XMMRegister(ra_,this,idx2), 32);
    __ movdl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 10233 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 10247 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10261 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 10275 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10289 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 10303 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10317 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadDPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*primary()*/));
  
#line 10331 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 10345 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 10354 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6295 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl (opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10369 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadD_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6306 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl (opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10384 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6319 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt (opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10399 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadFPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 10413 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 10427 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 10436 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadA8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6345 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10451 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadA4SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6357 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10466 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadA4CNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6369 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10481 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void load2IUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6381 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10496 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadA2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6393 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 10511 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void leaP8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 10525 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10539 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void leaP32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 10553 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10567 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void leaPIdxOffNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 10581 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10595 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void leaPIdxScaleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 10609 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10623 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void leaPIdxScaleOffNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 10637 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10651 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1892 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    emit_opcode(cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32(cbuf, opnd_array(1)->constant());
  
#line 10668 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 10682 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this), opnd_array(0)->reg(ra_,this));
  
#line 10690 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1899 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    emit_opcode(cbuf, (0xB8 /*primary()*/) + opnd_array(0)->reg(ra_,this));
    
if ( opnd_array(1)->constant_is_oop() ) {
  emit_d32_reloc(cbuf, opnd_array(1)->constant(), relocInfo::oop_type, 0);
} else {
  emit_d32(cbuf, opnd_array(1)->constant());
};
  
#line 10712 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1906 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    int dst_enc = opnd_array(0)->reg(ra_,this);
    int src_con = opnd_array(1)->constantL() & 0x0FFFFFFFFL;
    if (src_con == 0) {
      // xor dst, dst
      emit_opcode(cbuf, 0x33);
      emit_rm(cbuf, 0x3, dst_enc, dst_enc);
    } else {
      emit_opcode(cbuf, (0xB8 /*primary()*/) + dst_enc);
      emit_d32(cbuf, src_con);
    }
  
#line 10737 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1921 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    int dst_enc = opnd_array(0)->reg(ra_,this) + 2;
    int src_con = ((julong)(opnd_array(1)->constantL())) >> 32;
    if (src_con == 0) {
      // xor dst, dst
      emit_opcode(cbuf, 0x33);
      emit_rm(cbuf, 0x3, dst_enc, dst_enc);
    } else {
      emit_opcode(cbuf, (0xB8 /*primary()*/) + dst_enc);
      emit_d32(cbuf, src_con);
    }
  
#line 10756 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConL0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1950 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this), opnd_array(0)->reg(ra_,this));
  
#line 10771 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1955 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)), HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)));
  
#line 10780 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConFPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 10796 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConFPRNode::eval_constant(Compile* C) {
  {

#line 6509 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 10804 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConFPR0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6521 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fldz();
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 10820 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConFPR1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6534 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld1();
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 10836 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6546 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 10851 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConFNode::eval_constant(Compile* C) {
  {

#line 6547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 10859 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6557 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ xorps(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 10874 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConDPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6570 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 10890 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConDPRNode::eval_constant(Compile* C) {
  {

#line 6571 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 10898 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConDPR0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6584 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fldz();
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 10914 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConDPR1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6598 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld1();
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 10930 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6610 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 10945 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConDNode::eval_constant(Compile* C) {
  {

#line 6611 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 10953 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConD0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 6621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ xorpd (opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 10968 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadSSINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 10982 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 10996 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadSSLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 11010 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11024 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*secondary()*/));
  
#line 11032 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this));  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 11046 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadSSPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 11060 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11074 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadSSFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 11088 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 11102 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 11111 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadSSDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*primary()*/));
  
#line 11125 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 11139 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 11148 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchr0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  // User did not define which encode class to use.
}
uint  prefetchr0Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void prefetchrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6705 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchr(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11174 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchrNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6717 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11189 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchrT0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6729 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht0(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11204 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchrT2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6741 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht2(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11219 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchw0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  // User did not define which encode class to use.
}
uint  prefetchw0Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void prefetchwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6763 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchw(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11245 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchwNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6775 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11260 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchAlloc0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  // User did not define which encode class to use.
}
uint  prefetchAlloc0Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void prefetchAllocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6799 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchw(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11286 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchAllocNTANode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6811 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetchnta(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11301 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchAllocT0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6823 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht0(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11316 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void prefetchAllocT2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 6835 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ prefetcht2(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 11331 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x88 /*primary()*/));
  
#line 11346 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11360 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x66 /*secondary()*/));
  
#line 11375 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 11383 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11397 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 11412 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11426 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 11441 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11455 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*secondary()*/));
  
#line 11463 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2));  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 11477 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6894 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_Register(ra_,this,idx2));
  
#line 11493 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 11508 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = (EAX_enc);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11522 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3635 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0x0DF, 0x05, opnd_array(2)->disp(ra_,this,idx2) );
    cbuf.set_insts_mark();            // Mark start of FIST in case $mem has an oop
    emit_opcode(cbuf,0xDF);
    int rm_byte_opcode = 0x07;
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 11539 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeLX_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6925 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cmpl(rax, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3), Address(rsp, opnd_array(2)->disp(ra_,this,idx2)));
    __ movdbl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(3)->as_XMMRegister(ra_,this,idx3));
  
#line 11558 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeLX_reg_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 6943 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cmpl(rax, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdl(opnd_array(4)->as_XMMRegister(ra_,this,idx4), opnd_array(2)->as_Register(ra_,this,idx2));
    __ movdl(opnd_array(3)->as_XMMRegister(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(2)->as_Register(ra_,this,idx2)));
    __ punpckldq(opnd_array(4)->as_XMMRegister(ra_,this,idx4), opnd_array(3)->as_XMMRegister(ra_,this,idx3));
    __ movdbl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(4)->as_XMMRegister(ra_,this,idx4));
  
#line 11580 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 11595 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11609 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeImmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 11624 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 11638 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1972 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constant());
  
#line 11647 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeImmI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1556 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0x66);
  
#line 11662 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 11670 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 11684 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1991 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    emit_d16(cbuf, opnd_array(2)->constant());
  
#line 11693 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeImmPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 11708 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 11722 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1972 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    
if ( opnd_array(2)->constant_is_oop() ) {
  emit_d32_reloc(cbuf, opnd_array(2)->constant(), relocInfo::oop_type, 0);
} else {
  emit_d32(cbuf, opnd_array(2)->constant());
};
  
#line 11736 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeImmBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC6 /*primary()*/));
  
#line 11751 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 11765 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 11780 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeA8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7016 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 11796 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeA4CNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7028 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 11812 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeA2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7040 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 11828 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeImmCMNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC6 /*primary()*/));
  
#line 11843 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 11857 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 11872 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeDPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2197 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xDD /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11902 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeDPR_roundedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2197 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xDD /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 11932 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7088 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 11948 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7101 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 11964 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeA2FNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7113 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movq(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 11980 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeFPRNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2197 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xD9 /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12010 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeFPR_roundedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2197 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xD9 /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12040 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeFPR_DroundedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2197 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If src is FPR1, we can just FST to store it.
    // Else we need to FLD it to FPR1, then FSTP to store/pop it.
    int reg_encoding = 0x2; // Just store
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    if( opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc ) {
      reg_encoding = 0x3;  // Store & pop
      emit_opcode( cbuf, 0xD9 ); // FLD (i.e., push it)
      emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
    }
    cbuf.set_insts_mark();       // Mark start of opcode for reloc info in mem operand
    emit_opcode(cbuf,(0xD9 /*primary()*/));
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12070 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeFPR_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 12085 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 12099 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1977 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output Float immediate bits
    jfloat jf = opnd_array(2)->constantF();
    int    jf_as_bits = jint_cast( jf );
    emit_d32(cbuf, jf_as_bits);
  
#line 12110 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC7 /*primary()*/));
  
#line 12125 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 12139 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1984 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output Float immediate bits
    jfloat jf = opnd_array(2)->constantF();
    int    jf_as_bits = jint_cast( jf );
    emit_d32(cbuf, jf_as_bits);
  
#line 12150 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeSSINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2385 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0x89 /*primary()*/), opnd_array(1)->reg(ra_,this,idx1), opnd_array(0)->disp(ra_,this,0) );
  
#line 12164 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeSSPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2385 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0x89 /*primary()*/), opnd_array(1)->reg(ra_,this,idx1), opnd_array(0)->disp(ra_,this,0) );
  
#line 12178 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeSSLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 12192 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0);
    bool disp_is_oop = opnd_array(0)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12206 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*secondary()*/));
  
#line 12214 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1));  // Hi register of pair, computed from lo
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(0)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 12228 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  membar_acquireNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  membar_acquire_lockNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  membar_releaseNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  membar_release_lockNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 7269 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ membar(Assembler::StoreLoad);
  
#line 12287 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  unnecessary_membar_volatileNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  membar_storestoreNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1938 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 12330 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void jmovI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7322 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movl(opnd_array(3)->as_Register(ra_,this,idx3), opnd_array(4)->as_Register(ra_,this,idx4));
    __ bind(Lskip);
  
#line 12352 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void jmovI_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7339 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label Lskip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), Lskip);
    __ movl(opnd_array(3)->as_Register(ra_,this,idx3), opnd_array(4)->as_Register(ra_,this,idx4));
    __ bind(Lskip);
  
#line 12374 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12392 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 12400 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovI_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12418 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 12426 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12444 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12458 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovI_memUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12476 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12490 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12508 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 12516 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovP_reg_nonP6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1711 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Invert sense of branch from sense of CMOV
    emit_cc( cbuf, 0x70, (opnd_array(1)->ccode()^1) );
    emit_d8( cbuf, (0x2) );
  
#line 12535 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8b /*primary()*/));
  
#line 12543 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 12551 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovP_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12569 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 12577 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovDPR_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1704 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int op = 0xDA00 + opnd_array(1)->ccode() + (opnd_array(4)->reg(ra_,this,idx4)-1);
    emit_d8(cbuf, op >> 8 );
    emit_d8(cbuf, op & 255);
  
#line 12596 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovFPR_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1704 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int op = 0xDA00 + opnd_array(1)->ccode() + (opnd_array(4)->reg(ra_,this,idx4)-1);
    emit_d8(cbuf, op >> 8 );
    emit_d8(cbuf, op & 255);
  
#line 12615 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovDPR_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1711 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Invert sense of branch from sense of CMOV
    emit_cc( cbuf, 0x70, (opnd_array(1)->ccode()^1) );
    emit_d8( cbuf, (0x4) );
  
#line 12634 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(4)->reg(ra_,this,idx4) );   // FLD ST(i-1)
  
#line 12643 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xdd /*primary()*/));
  
#line 12651 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(3)->reg(ra_,this,idx3) );
  
#line 12659 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovFPR_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1711 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Invert sense of branch from sense of CMOV
    emit_cc( cbuf, 0x70, (opnd_array(1)->ccode()^1) );
    emit_d8( cbuf, (0x4) );
  
#line 12678 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(4)->reg(ra_,this,idx4) );
  
#line 12687 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xdd /*primary()*/));
  
#line 12695 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(3)->reg(ra_,this,idx3) );
  
#line 12703 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovF_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7538 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movflt(opnd_array(3)->as_XMMRegister(ra_,this,idx3), opnd_array(4)->as_XMMRegister(ra_,this,idx4));
    __ bind(skip);
  
#line 12725 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovD_regSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7556 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3), opnd_array(4)->as_XMMRegister(ra_,this,idx4));
    __ bind(skip);
  
#line 12747 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovF_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7574 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movflt(opnd_array(3)->as_XMMRegister(ra_,this,idx3), opnd_array(4)->as_XMMRegister(ra_,this,idx4));
    __ bind(skip);
  
#line 12769 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void fcmovD_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7601 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label skip;
    // Invert sense of branch from sense of CMOV
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()^1), skip);
    __ movdbl(opnd_array(3)->as_XMMRegister(ra_,this,idx3), opnd_array(4)->as_XMMRegister(ra_,this,idx4));
    __ bind(skip);
  
#line 12791 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12809 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1960 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 12817 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12826 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)));
  
#line 12834 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovL_regUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12852 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1960 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 12860 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 12869 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)));
  
#line 12877 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 12892 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 12900 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  addI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void addI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 12927 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 12942 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void incI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x40 /*primary()*/) + opnd_array(1)->reg(ra_,this,idx1));
  
#line 12957 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  incI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 1, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 1);
}
void leaI_eReg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 12976 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2163 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base         = opnd_array(1)->reg(ra_,this,idx1);      // 0xFFFFFFFF indicates no base
    int index        = 0x04;            // 0x04 indicates no index
    int scale        = 0x00;            // 0x00 indicates no scale
    int displace     = opnd_array(2)->constant(); // 0x00 indicates no displacement
    bool disp_is_oop = false;
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 12990 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void leaP_eReg_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8D /*primary()*/));
  
#line 13005 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2163 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base         = opnd_array(1)->reg(ra_,this,idx1);      // 0xFFFFFFFF indicates no base
    int index        = 0x04;            // 0x04 indicates no index
    int scale        = 0x00;            // 0x00 indicates no scale
    int displace     = opnd_array(2)->constant(); // 0x00 indicates no displacement
    bool disp_is_oop = false;
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13019 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void decI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x48 /*primary()*/) + opnd_array(1)->reg(ra_,this,idx1));
  
#line 13034 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  decI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 1, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 1);
}
void addP_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 13053 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 13061 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  addP_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void addP_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 13088 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 13103 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 13118 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13132 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 13147 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13161 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 13176 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13190 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x01 /*primary()*/));
  
#line 13205 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13219 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1622 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 13240 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 13254 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 13269 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void incI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 13284 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 13298 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void decI_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 13313 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x01);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 13327 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  checkCastPPNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 13366 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13380 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadLLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 3619 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xDF);
    int rm_byte_opcode = 0x05;
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
    store_to_stackslot( cbuf, 0x0DF, 0x07, opnd_array(0)->disp(ra_,this,0) );
  
#line 13402 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadLX_LockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7853 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdbl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 13419 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadLX_reg_LockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7869 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ movdl(opnd_array(0)->as_Register(ra_,this), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    __ psrlq(opnd_array(2)->as_XMMRegister(ra_,this,idx2), 32);
    __ movdl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 13438 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storePConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2006 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);         // [Lock]
  
#line 13455 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 13463 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xB1));
  
#line 13471 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13485 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeIConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2006 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);         // [Lock]
  
#line 13502 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F));
  
#line 13510 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xB1));
  
#line 13518 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13532 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void storeLConditionalNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 7909 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Note: we need to swap rbx, and rcx before and after the
    //       cmpxchg8 instruction because the instruction uses
    //       rcx as the high order word of the new value to store but
    //       our register encoding uses rbx.
    __ xchgl(as_Register(EBX_enc), as_Register(ECX_enc));
    if( os::is_MP() )
      __ lock();
    __ cmpxchg8(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
    __ xchgl(as_Register(EBX_enc), as_Register(ECX_enc));
  
#line 13557 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compareAndSwapLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2016 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"


    // XCHG  rbx,ecx
    emit_opcode(cbuf,0x87);
    emit_opcode(cbuf,0xD9);
    // [Lock]
    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);
    // CMPXCHG8 [Eptr]
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xC7);
    emit_rm( cbuf, 0x0, 1, opnd_array(1)->reg(ra_,this,idx1) );
    // XCHG  rbx,ecx
    emit_opcode(cbuf,0x87);
    emit_opcode(cbuf,0xD9);
  
#line 13586 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int res_encoding = opnd_array(0)->reg(ra_,this);

    // MOV  res,0
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 0 );
    // JNE,s  fail
    emit_opcode(cbuf,0x75);
    emit_d8(cbuf, 5 );
    // MOV  res,1
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 1 );
    // fail:
  
#line 13605 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compareAndSwapPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2033 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // [Lock]
    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);

    // CMPXCHG [Eptr]
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xB1);
    emit_rm( cbuf, 0x0, 1, opnd_array(1)->reg(ra_,this,idx1) );
  
#line 13628 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int res_encoding = opnd_array(0)->reg(ra_,this);

    // MOV  res,0
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 0 );
    // JNE,s  fail
    emit_opcode(cbuf,0x75);
    emit_d8(cbuf, 5 );
    // MOV  res,1
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 1 );
    // fail:
  
#line 13647 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compareAndSwapINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2033 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // [Lock]
    if( os::is_MP() )
      emit_opcode(cbuf,0xF0);

    // CMPXCHG [Eptr]
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xB1);
    emit_rm( cbuf, 0x0, 1, opnd_array(1)->reg(ra_,this,idx1) );
  
#line 13670 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2044 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int res_encoding = opnd_array(0)->reg(ra_,this);

    // MOV  res,0
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 0 );
    // JNE,s  fail
    emit_opcode(cbuf,0x75);
    emit_d8(cbuf, 5 );
    // MOV  res,1
    emit_opcode( cbuf, 0xB8 + res_encoding);
    emit_d32( cbuf, 1 );
    // fail:
  
#line 13689 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 13704 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 13712 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  subI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void subI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 13739 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 13754 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 13769 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13783 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x29 /*primary()*/));
  
#line 13798 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 13812 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subP_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 13828 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(3)->reg(ra_,this,idx3));
  
#line 13836 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  subP_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void negI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 13855 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x03 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 13863 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  negI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void mulI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*secondary()*/));
  
#line 13882 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xAF /*primary()*/));
  
#line 13890 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 13898 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  mulI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 3);
}
void mulI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1622 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 13923 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this), opnd_array(1)->reg(ra_,this,idx1));
  
#line 13931 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 13946 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loadConL_low_onlyNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1906 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Load immediate does not have a zero or sign extended version
    // for 8-bit immediates
    int dst_enc = opnd_array(0)->reg(ra_,this);
    int src_con = opnd_array(1)->constantL() & 0x0FFFFFFFFL;
    if (src_con == 0) {
      // xor dst, dst
      emit_opcode(cbuf, 0x33);
      emit_rm(cbuf, 0x3, dst_enc, dst_enc);
    } else {
      emit_opcode(cbuf, (0xB8 /*primary()*/) + dst_enc);
      emit_d32(cbuf, src_con);
    }
  
#line 13971 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI_imm_highNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2748 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(1)->reg(ra_,this,idx1) );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this) );
      emit_d8(cbuf, shift_count);
    }
  
#line 13996 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI_imm_high_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2748 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(2)->reg(ra_,this,idx2) );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this) );
      emit_d8(cbuf, shift_count);
    }
  
#line 14021 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI_imm_RShift_highNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2748 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(1)->reg(ra_,this,idx1) );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this) );
      emit_d8(cbuf, shift_count);
    }
  
#line 14046 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI_imm_RShift_high_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2748 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // IMUL   EDX:EAX,$src1
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(2)->reg(ra_,this,idx2) );
    // SAR    EDX,$cnt-32
    int shift_count = ((int)opnd_array(3)->constant()) - 32;
    if (shift_count > 0) {
      emit_opcode(cbuf, 0xC1);
      emit_rm(cbuf, 0x3, 7, opnd_array(0)->reg(ra_,this) );
      emit_d8(cbuf, shift_count);
    }
  
#line 14071 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1622 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x69 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x69 /*primary()*/));
    }
  
#line 14092 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14106 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 14121 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*secondary()*/));
  
#line 14136 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xAF /*primary()*/));
  
#line 14144 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14158 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0F /*secondary()*/));
  
#line 14173 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xAF /*primary()*/));
  
#line 14181 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 14195 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2774 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: long = (long)int * (long)int
    // IMUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(2)->reg(ra_,this,idx2));
  
#line 14213 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulI2L_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2774 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: long = (long)int * (long)int
    // IMUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x5, opnd_array(1)->reg(ra_,this,idx1));
  
#line 14231 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulIS_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2781 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic Idea:  long = (int & 0xffffffffL) * (int & 0xffffffffL)
    // MUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, opnd_array(3)->reg(ra_,this,idx3));
  
#line 14250 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulIS_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2781 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic Idea:  long = (int & 0xffffffffL) * (int & 0xffffffffL)
    // MUL EDX:EAX, src
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, opnd_array(1)->reg(ra_,this,idx1));
  
#line 14269 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2788 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: lo(result) = lo(x_lo * y_lo)
    //             hi(result) = hi(x_lo * y_lo) + lo(x_hi * y_lo) + lo(x_lo * y_hi)
    // MOV    $tmp,$src.lo
    encode_Copy( cbuf, opnd_array(3)->reg(ra_,this,idx3), opnd_array(2)->reg(ra_,this,idx2) );
    // IMUL   $tmp,EDX
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0xAF );
    emit_rm( cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
    // MOV    EDX,$src.hi
    encode_Copy( cbuf, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)) );
    // IMUL   EDX,EAX
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0xAF );
    emit_rm( cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), opnd_array(1)->reg(ra_,this,idx1) );
    // ADD    $tmp,EDX
    emit_opcode( cbuf, 0x03 );
    emit_rm( cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
    // MUL   EDX:EAX,$src.lo
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, opnd_array(2)->reg(ra_,this,idx2) );
    // ADD    EDX,ESI
    emit_opcode( cbuf, 0x03 );
    emit_rm( cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), opnd_array(3)->reg(ra_,this,idx3) );
  
#line 14307 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulL_eReg_lhi0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8182 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(2)->as_Register(ra_,this,idx2)));
    __ imull(opnd_array(3)->as_Register(ra_,this,idx3), rax);
    __ mull(opnd_array(2)->as_Register(ra_,this,idx2));
    __ addl(rdx, opnd_array(3)->as_Register(ra_,this,idx3));
  
#line 14327 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulL_eReg_rhi0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8203 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3), opnd_array(2)->as_Register(ra_,this,idx2));
    __ imull(opnd_array(3)->as_Register(ra_,this,idx3), rdx);
    __ mull(opnd_array(2)->as_Register(ra_,this,idx2));
    __ addl(rdx, opnd_array(3)->as_Register(ra_,this,idx3));
  
#line 14347 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulL_eReg_hi0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8221 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ mull(opnd_array(2)->as_Register(ra_,this,idx2));
  
#line 14363 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulL_eReg_conNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2814 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Basic idea: lo(result) = lo(src * y_lo)
    //             hi(result) = hi(src * y_lo) + lo(src * y_hi)
    // IMUL   $tmp,EDX,$src
    emit_opcode( cbuf, 0x6B );
    emit_rm( cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
    emit_d8( cbuf, (int)opnd_array(2)->constantL() );
    // MOV    EDX,$src
    emit_opcode(cbuf, 0xB8 + EDX_enc);
    emit_d32( cbuf, (int)opnd_array(2)->constantL() );
    // MUL   EDX:EAX,EDX
    emit_opcode( cbuf, 0xF7 );
    emit_rm( cbuf, 0x3, 0x4, EDX_enc );
    // ADD    EDX,ESI
    emit_opcode( cbuf, 0x03 );
    emit_rm( cbuf, 0x3, EDX_enc, opnd_array(3)->reg(ra_,this,idx3) );
  
#line 14393 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  mulL_eReg_conNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 12);
}
void divI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1574 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax,: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax,: quotient  (= rax, idiv reg)       min_int
    //         rdx: remainder (= rax, irem reg)       0
    //
    //  Code sequnce:
    //
    //  81 F8 00 00 00 80    cmp         rax,80000000h
    //  0F 85 0B 00 00 00    jne         normal_case
    //  33 D2                xor         rdx,edx
    //  83 F9 FF             cmp         rcx,0FFh
    //  0F 84 03 00 00 00    je          done
    //                  normal_case:
    //  99                   cdq
    //  F7 F9                idiv        rax,ecx
    //                  done:
    //
    emit_opcode(cbuf,0x81); emit_d8(cbuf,0xF8);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x80);                     // cmp rax,80000000h
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x85);
    emit_opcode(cbuf,0x0B); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // jne normal_case
    emit_opcode(cbuf,0x33); emit_d8(cbuf,0xD2);                     // xor rdx,edx
    emit_opcode(cbuf,0x83); emit_d8(cbuf,0xF9); emit_d8(cbuf,0xFF); // cmp rcx,0FFh
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x84);
    emit_opcode(cbuf,0x03); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // je done
    // normal_case:
    emit_opcode(cbuf,0x99);                                         // cdq
    // idiv (note: must be emitted by the user of this rule)
    // normal:
  
#line 14449 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 14457 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 14465 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  divI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 26, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 26);
}
void divL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2832 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // PUSH src1.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(1)->reg(ra_,this,idx1)) );
    // PUSH src1.lo
    emit_opcode(cbuf,               0x50+opnd_array(1)->reg(ra_,this,idx1)  );
    // PUSH src2.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(2)->reg(ra_,this,idx2)) );
    // PUSH src2.lo
    emit_opcode(cbuf,               0x50+opnd_array(2)->reg(ra_,this,idx2)  );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (CAST_FROM_FN_PTR(address, SharedRuntime::ldiv) - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Restore stack
    emit_opcode(cbuf, 0x83); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 4*4);
  
#line 14499 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divModI_eReg_divmodNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1574 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax,: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax,: quotient  (= rax, idiv reg)       min_int
    //         rdx: remainder (= rax, irem reg)       0
    //
    //  Code sequnce:
    //
    //  81 F8 00 00 00 80    cmp         rax,80000000h
    //  0F 85 0B 00 00 00    jne         normal_case
    //  33 D2                xor         rdx,edx
    //  83 F9 FF             cmp         rcx,0FFh
    //  0F 84 03 00 00 00    je          done
    //                  normal_case:
    //  99                   cdq
    //  F7 F9                idiv        rax,ecx
    //                  done:
    //
    emit_opcode(cbuf,0x81); emit_d8(cbuf,0xF8);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x80);                     // cmp rax,80000000h
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x85);
    emit_opcode(cbuf,0x0B); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // jne normal_case
    emit_opcode(cbuf,0x33); emit_d8(cbuf,0xD2);                     // xor rdx,edx
    emit_opcode(cbuf,0x83); emit_d8(cbuf,0xF9); emit_d8(cbuf,0xFF); // cmp rcx,0FFh
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x84);
    emit_opcode(cbuf,0x03); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // je done
    // normal_case:
    emit_opcode(cbuf,0x99);                                         // cdq
    // idiv (note: must be emitted by the user of this rule)
    // normal:
  
#line 14551 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 14559 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 14567 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  divModI_eReg_divmodNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 26, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 26);
}
void modI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1574 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Full implementation of Java idiv and irem; checks for
    // special case as described in JVM spec., p.243 & p.271.
    //
    //         normal case                           special case
    //
    // input : rax,: dividend                         min_int
    //         reg: divisor                          -1
    //
    // output: rax,: quotient  (= rax, idiv reg)       min_int
    //         rdx: remainder (= rax, irem reg)       0
    //
    //  Code sequnce:
    //
    //  81 F8 00 00 00 80    cmp         rax,80000000h
    //  0F 85 0B 00 00 00    jne         normal_case
    //  33 D2                xor         rdx,edx
    //  83 F9 FF             cmp         rcx,0FFh
    //  0F 84 03 00 00 00    je          done
    //                  normal_case:
    //  99                   cdq
    //  F7 F9                idiv        rax,ecx
    //                  done:
    //
    emit_opcode(cbuf,0x81); emit_d8(cbuf,0xF8);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x80);                     // cmp rax,80000000h
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x85);
    emit_opcode(cbuf,0x0B); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // jne normal_case
    emit_opcode(cbuf,0x33); emit_d8(cbuf,0xD2);                     // xor rdx,edx
    emit_opcode(cbuf,0x83); emit_d8(cbuf,0xF9); emit_d8(cbuf,0xFF); // cmp rcx,0FFh
    emit_opcode(cbuf,0x0F); emit_d8(cbuf,0x84);
    emit_opcode(cbuf,0x03); emit_d8(cbuf,0x00);
    emit_opcode(cbuf,0x00); emit_d8(cbuf,0x00);                     // je done
    // normal_case:
    emit_opcode(cbuf,0x99);                                         // cdq
    // idiv (note: must be emitted by the user of this rule)
    // normal:
  
#line 14623 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 14631 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 14639 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  modI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 26, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 26);
}
void modL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2851 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // PUSH src1.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(1)->reg(ra_,this,idx1)) );
    // PUSH src1.lo
    emit_opcode(cbuf,               0x50+opnd_array(1)->reg(ra_,this,idx1)  );
    // PUSH src2.hi
    emit_opcode(cbuf, HIGH_FROM_LOW(0x50+opnd_array(2)->reg(ra_,this,idx2)) );
    // PUSH src2.lo
    emit_opcode(cbuf,               0x50+opnd_array(2)->reg(ra_,this,idx2)  );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (CAST_FROM_FN_PTR(address, SharedRuntime::lrem ) - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Restore stack
    emit_opcode(cbuf, 0x83); // add  SP, #framesize
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 4*4);
  
#line 14673 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divL_eReg_imm32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8352 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int con = (int)opnd_array(2)->constantL();
    assert(con != 0 && con != -1 && con != min_jint, "wrong divisor");
    int pcon = (con > 0) ? con : -con;
    Label Lfast, Lpos, Ldone;

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3), pcon);
    __ xorl(opnd_array(4)->as_Register(ra_,this,idx4),opnd_array(4)->as_Register(ra_,this,idx4));
    __ cmpl(opnd_array(3)->as_Register(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ jccb(Assembler::above, Lfast); // result fits into 32 bit

    __ movl(opnd_array(4)->as_Register(ra_,this,idx4), opnd_array(1)->as_Register(ra_,this,idx1)); // save
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1), HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ movl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),0); // preserve flags
    __ jccb(Assembler::lessEqual, Lpos); // result is positive

    // Negative dividend.
    // convert value to positive to use unsigned division
    __ lneg(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(4)->as_Register(ra_,this,idx4));
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3));
    __ xchgl(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(4)->as_Register(ra_,this,idx4));
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3));
    // revert result back to negative
    __ lneg(opnd_array(4)->as_Register(ra_,this,idx4), opnd_array(1)->as_Register(ra_,this,idx1));
    __ jmpb(Ldone);

    __ bind(Lpos);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)); // Use unsigned division
    __ xchgl(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(4)->as_Register(ra_,this,idx4));
    // Fallthrow for final divide, tmp2 has 32 bit hi result

    __ bind(Lfast);
    // fast path: src is positive
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3)); // Use unsigned division

    __ bind(Ldone);
    __ movl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),opnd_array(4)->as_Register(ra_,this,idx4));
    if (con < 0) {
      __ lneg(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)), opnd_array(1)->as_Register(ra_,this,idx1));
    }
  
#line 14729 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void modL_eReg_imm32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8422 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int con = (int)opnd_array(2)->constantL();
    assert(con != 0 && con != -1 && con != min_jint, "wrong divisor");
    int pcon = (con > 0) ? con : -con;
    Label  Lfast, Lpos, Ldone;

    __ movl(opnd_array(3)->as_Register(ra_,this,idx3), pcon);
    __ cmpl(opnd_array(3)->as_Register(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ jccb(Assembler::above, Lfast); // src is positive and result fits into 32 bit

    __ movl(opnd_array(4)->as_Register(ra_,this,idx4), opnd_array(1)->as_Register(ra_,this,idx1)); // save
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1), HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ movl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),0); // preserve flags
    __ jccb(Assembler::lessEqual, Lpos); // result is positive

    // Negative dividend.
    // convert value to positive to use unsigned division
    __ lneg(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(4)->as_Register(ra_,this,idx4));
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3));
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(4)->as_Register(ra_,this,idx4));
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3));
    // revert remainder back to negative
    __ negl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ jmpb(Ldone);

    __ bind(Lpos);
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3));
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(4)->as_Register(ra_,this,idx4));

    __ bind(Lfast);
    // fast path: src is positive
    __ divl(opnd_array(3)->as_Register(ra_,this,idx3));

    __ bind(Ldone);
    __ movl(opnd_array(1)->as_Register(ra_,this,idx1), HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ sarl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)), 31); // result sign

  
#line 14782 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shlI_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 14797 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 14805 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  shlI_eReg_1Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void salI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1886 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 14826 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  salI_eReg_immNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 3);
}
void salI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 14845 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 14853 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  salI_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void sarI_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 14872 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 14880 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  sarI_eReg_1Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void sarI_mem_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 14899 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14913 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sarI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1886 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 14930 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  sarI_eReg_immNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 3);
}
void sarI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC1 /*primary()*/));
  
#line 14949 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x7 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 14963 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 14978 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sarI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 14993 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 15001 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  sarI_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void shrI_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 15020 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 15028 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  shrI_eReg_1Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void shrI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1886 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 15049 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  shrI_eReg_immNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 3);
}
void i2bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8589 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movsbl(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 15069 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  i2bNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 3);
}
void i2sNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8602 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movswl(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 15089 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  i2sNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 3, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 3);
}
void shrI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 15108 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 15116 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  shrI_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void andI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 15135 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 15143 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  andI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void andI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 15170 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15185 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 15200 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15214 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 15229 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15243 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 15258 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15272 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x21 /*primary()*/));
  
#line 15287 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15301 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1622 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 15322 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x4 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 15336 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15351 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 15366 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 15374 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  orI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void orI_eReg_castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 15393 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 15401 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  orI_eReg_castP2XNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void orI_eReg_castP2X_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 15420 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(2)->reg(ra_,this,idx2), opnd_array(1)->reg(ra_,this,idx1));
  
#line 15428 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  orI_eReg_castP2X_0Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void orI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 15455 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15470 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 15485 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15499 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 15514 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15528 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 15543 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15557 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x09 /*primary()*/));
  
#line 15572 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15586 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1622 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 15607 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x1 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 15621 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15636 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void rolI_eReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 15651 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 15659 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void rolI_eReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1886 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 15676 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void rolI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 15691 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 15699 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void rorI_eReg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1 /*primary()*/));
  
#line 15714 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 15722 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void rorI_eReg_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1886 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    emit_d8(cbuf, opnd_array(2)->constant());
  
#line 15739 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void rorI_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD3 /*primary()*/));
  
#line 15754 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 15762 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 15777 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 15785 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  xorI_eRegNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void xorI_eReg_im1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 8912 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

     __ notl(opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 15805 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  xorI_eReg_im1Node::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void xorI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 15832 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 15847 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 15862 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15876 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorI_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 15891 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15905 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorI_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 15920 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15934 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorI_mem_eReg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x31 /*primary()*/));
  
#line 15949 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 15963 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorI_mem_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1622 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);
    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
  
#line 15984 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x6 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 15998 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 16013 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void movI_nocopyNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1938 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 16027 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void ci2bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2216 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // NEG $dst
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0x03, opnd_array(1)->reg(ra_,this,idx1) );
  
#line 16044 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,(0x13));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16053 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  ci2bNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 4);
}
void movP_nocopyNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1938 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 16071 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cp2bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2216 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // NEG $dst
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0x03, opnd_array(1)->reg(ra_,this,idx1) );
  
#line 16088 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,(0x13));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16097 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,(0x33));
    emit_rm(cbuf, 0x3, opnd_array(0)->reg(ra_,this), opnd_array(0)->reg(ra_,this));
  
#line 16113 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,(0x3B));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16122 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2222 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // SETLT $dst
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0x9C);
    emit_rm( cbuf, 0x3, 0x4, opnd_array(0)->reg(ra_,this) );
  
#line 16133 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2216 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // NEG $dst
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0x03, opnd_array(0)->reg(ra_,this) );
  
#line 16143 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpLTMask0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1886 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    emit_d8(cbuf, (0x1F));
  
#line 16160 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cadd_cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2229 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int tmpReg = ECX_enc;

    // SUB $p,$q
    emit_opcode(cbuf,0x2B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
    // SBB $tmp,$tmp
    emit_opcode(cbuf,0x1B);
    emit_rm(cbuf, 0x3, tmpReg, tmpReg);
    // AND $tmp,$y
    emit_opcode(cbuf,0x23);
    emit_rm(cbuf, 0x3, tmpReg, opnd_array(3)->reg(ra_,this,idx3));
    // ADD $p,$tmp
    emit_opcode(cbuf,0x03);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), tmpReg);
  
#line 16189 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cadd_cmpLTMask_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2229 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int tmpReg = ECX_enc;

    // SUB $p,$q
    emit_opcode(cbuf,0x2B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
    // SBB $tmp,$tmp
    emit_opcode(cbuf,0x1B);
    emit_rm(cbuf, 0x3, tmpReg, tmpReg);
    // AND $tmp,$y
    emit_opcode(cbuf,0x23);
    emit_rm(cbuf, 0x3, tmpReg, opnd_array(3)->reg(ra_,this,idx3));
    // ADD $p,$tmp
    emit_opcode(cbuf,0x03);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), tmpReg);
  
#line 16218 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cadd_cmpLTMask_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2229 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int tmpReg = ECX_enc;

    // SUB $p,$q
    emit_opcode(cbuf,0x2B);
    emit_rm(cbuf, 0x3, opnd_array(2)->reg(ra_,this,idx2), opnd_array(3)->reg(ra_,this,idx3));
    // SBB $tmp,$tmp
    emit_opcode(cbuf,0x1B);
    emit_rm(cbuf, 0x3, tmpReg, tmpReg);
    // AND $tmp,$y
    emit_opcode(cbuf,0x23);
    emit_rm(cbuf, 0x3, tmpReg, opnd_array(1)->reg(ra_,this,idx1));
    // ADD $p,$tmp
    emit_opcode(cbuf,0x03);
    emit_rm(cbuf, 0x3, opnd_array(2)->reg(ra_,this,idx2), tmpReg);
  
#line 16247 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cadd_cmpLTMask_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2229 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int tmpReg = ECX_enc;

    // SUB $p,$q
    emit_opcode(cbuf,0x2B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
    // SBB $tmp,$tmp
    emit_opcode(cbuf,0x1B);
    emit_rm(cbuf, 0x3, tmpReg, tmpReg);
    // AND $tmp,$y
    emit_opcode(cbuf,0x23);
    emit_rm(cbuf, 0x3, tmpReg, opnd_array(3)->reg(ra_,this,idx3));
    // ADD $p,$tmp
    emit_opcode(cbuf,0x03);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), tmpReg);
  
#line 16276 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1950 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x03 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16292 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1955 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x13 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)));
  
#line 16301 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addL_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1655 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16323 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1666 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x02 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16338 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addL_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 16353 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16367 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x13 /*secondary()*/));
  
#line 16375 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1));  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 16389 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addL_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x03 /*primary()*/));
  
#line 16404 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16418 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x13 /*secondary()*/));
  
#line 16426 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2));  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 16440 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1950 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x2B /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16456 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1955 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x1B /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)));
  
#line 16465 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subL_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1655 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16487 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1666 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x03 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16502 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subL_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x2B /*primary()*/));
  
#line 16517 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16531 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x1B /*secondary()*/));
  
#line 16539 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1));  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 16553 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void negL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2916 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xF7);    // NEG hi
    emit_rm    (cbuf,0x3, 0x3, HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)));
    emit_opcode(cbuf,0xF7);    // NEG lo
    emit_rm    (cbuf,0x3, 0x3,               opnd_array(2)->reg(ra_,this,idx2) );
    emit_opcode(cbuf,0x83);    // SBB hi,0
    emit_rm    (cbuf,0x3, 0x3, HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)));
    emit_d8    (cbuf,0 );
  
#line 16574 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andL_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1950 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x23 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16590 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1955 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x23 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)));
  
#line 16599 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andL_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1655 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16621 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1666 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x04 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16636 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andL_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 16651 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16665 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*secondary()*/));
  
#line 16673 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1));  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 16687 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void andL_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*primary()*/));
  
#line 16702 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16716 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x23 /*secondary()*/));
  
#line 16724 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2));  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 16738 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orl_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1950 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0B /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16754 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1955 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0B /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)));
  
#line 16763 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orl_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1655 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16785 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1666 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x01 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16800 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orl_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 16815 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16829 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*secondary()*/));
  
#line 16837 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1));  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 16851 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void orl_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*primary()*/));
  
#line 16866 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 16880 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x0B /*secondary()*/));
  
#line 16888 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2));  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 16902 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorl_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1950 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*primary()*/));
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 16918 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1955 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x33 /*secondary()*/));
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)));
  
#line 16927 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorl_eReg_im1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9240 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

     __ notl(opnd_array(1)->as_Register(ra_,this,idx1));
     __ notl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
  
#line 16944 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorl_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1655 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)opnd_array(2)->constantL(); // Throw away top bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16966 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1666 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    int con = (int)(opnd_array(2)->constantL() >> 32); // Throw away bottom bits
    emit_opcode(cbuf, ((con >= -128) && (con <= 127)) ? ((0x81 /*primary()*/) | 0x02) : (0x81 /*primary()*/));
    // Emit r/m byte with tertiary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x06 /*tertiary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    if ((con >= -128) && (con <= 127)) emit_d8 (cbuf,con);
    else                               emit_d32(cbuf,con);
  
#line 16981 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorl_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 16996 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17010 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*secondary()*/));
  
#line 17018 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1));  // Hi register of pair, computed from lo
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(2)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 17032 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void xorl_eReg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 17047 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(2)->reg(ra_,this,idx2);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 17061 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*secondary()*/));
  
#line 17069 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2));  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 17083 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shlL_eReg_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9278 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1),opnd_array(1)->as_Register(ra_,this,idx1));
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
  
#line 17100 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shlL_eReg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9295 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1),opnd_array(1)->as_Register(ra_,this,idx1));
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ addl(opnd_array(1)->as_Register(ra_,this,idx1),opnd_array(1)->as_Register(ra_,this,idx1));
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
  
#line 17119 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shlL_eReg_3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9316 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ addl(opnd_array(1)->as_Register(ra_,this,idx1),opnd_array(1)->as_Register(ra_,this,idx1));
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ addl(opnd_array(1)->as_Register(ra_,this,idx1),opnd_array(1)->as_Register(ra_,this,idx1));
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ addl(opnd_array(1)->as_Register(ra_,this,idx1),opnd_array(1)->as_Register(ra_,this,idx1));
    __ adcl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)),HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
  
#line 17140 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shlL_eReg_1_31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2083 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0xA4 /*tertiary()*/) == 0xA4 ) { r1 = opnd_array(1)->reg(ra_,this,idx1);  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1);  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,(0xA4 /*tertiary()*/));
    emit_rm(cbuf, 0x3, r1, r2);
    emit_d8(cbuf,opnd_array(2)->constant());
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), r1);
    emit_d8(cbuf,opnd_array(2)->constant());
  
#line 17164 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shlL_eReg_32_63Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2109 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0x4 /*secondary()*/) == 0x5 ) { r1 = opnd_array(1)->reg(ra_,this,idx1);  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1);  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }

    emit_opcode( cbuf, 0x8B ); // Move r1,r2
    emit_rm(cbuf, 0x3, r1, r2);
    if( opnd_array(2)->constant() > 32 ) { // Shift, if not by zero
      emit_opcode(cbuf,(0xC1 /*primary()*/));
      emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), r1);
      emit_d8(cbuf,opnd_array(2)->constant()-32);
    }
    emit_opcode(cbuf,0x33);  // XOR r2,r2
    emit_rm(cbuf, 0x3, r2, r2);
  
#line 17191 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void salL_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2270 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // TEST shift,32
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0, ECX_enc);
    emit_d32(cbuf,0x20);
    // JEQ,s small
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x04);
    // MOV    $dst.hi,$dst.lo
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), opnd_array(1)->reg(ra_,this,idx1) );
    // CLR    $dst.lo
    emit_opcode(cbuf, 0x33);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(1)->reg(ra_,this,idx1));
// small:
    // SHLD   $dst.hi,$dst.lo,$shift
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xA5);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    // SHL    $dst.lo,$shift"
    emit_opcode(cbuf,0xD3);
    emit_rm(cbuf, 0x3, 0x4, opnd_array(1)->reg(ra_,this,idx1) );
  
#line 17226 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  salL_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 17, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 17);
}
void shrL_eReg_1_31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2083 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0xAC /*tertiary()*/) == 0xA4 ) { r1 = opnd_array(1)->reg(ra_,this,idx1);  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1);  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,(0xAC /*tertiary()*/));
    emit_rm(cbuf, 0x3, r1, r2);
    emit_d8(cbuf,opnd_array(2)->constant());
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), r1);
    emit_d8(cbuf,opnd_array(2)->constant());
  
#line 17254 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shrL_eReg_32_63Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2109 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0x5 /*secondary()*/) == 0x5 ) { r1 = opnd_array(1)->reg(ra_,this,idx1);  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1);  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }

    emit_opcode( cbuf, 0x8B ); // Move r1,r2
    emit_rm(cbuf, 0x3, r1, r2);
    if( opnd_array(2)->constant() > 32 ) { // Shift, if not by zero
      emit_opcode(cbuf,(0xC1 /*primary()*/));
      emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), r1);
      emit_d8(cbuf,opnd_array(2)->constant()-32);
    }
    emit_opcode(cbuf,0x33);  // XOR r2,r2
    emit_rm(cbuf, 0x3, r2, r2);
  
#line 17281 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void shrL_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2294 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // TEST shift,32
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0, ECX_enc);
    emit_d32(cbuf,0x20);
    // JEQ,s small
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x04);
    // MOV    $dst.lo,$dst.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
    // CLR    $dst.hi
    emit_opcode(cbuf, 0x33);
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
// small:
    // SHRD   $dst.lo,$dst.hi,$shift
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xAD);
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), opnd_array(1)->reg(ra_,this,idx1));
    // SHR    $dst.hi,$shift"
    emit_opcode(cbuf,0xD3);
    emit_rm(cbuf, 0x3, 0x5, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
  
#line 17316 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  shrL_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 17, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 17);
}
void sarL_eReg_1_31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2083 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int r1, r2;
    if( (0xAC /*tertiary()*/) == 0xA4 ) { r1 = opnd_array(1)->reg(ra_,this,idx1);  r2 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    else                    { r2 = opnd_array(1)->reg(ra_,this,idx1);  r1 = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)); }
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,(0xAC /*tertiary()*/));
    emit_rm(cbuf, 0x3, r1, r2);
    emit_d8(cbuf,opnd_array(2)->constant());
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), r1);
    emit_d8(cbuf,opnd_array(2)->constant());
  
#line 17344 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sarL_eReg_32_63Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2096 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0x8B ); // Move
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    if( opnd_array(2)->constant() > 32 ) { // Shift, if not by zero
      emit_d8(cbuf,(0xC1 /*primary()*/));
      emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
      emit_d8(cbuf,opnd_array(2)->constant()-32);
    }
    emit_d8(cbuf,(0xC1 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    emit_d8(cbuf,31);
  
#line 17368 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sarL_eReg_CLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2318 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // TEST shift,32
    emit_opcode(cbuf,0xF7);
    emit_rm(cbuf, 0x3, 0, ECX_enc);
    emit_d32(cbuf,0x20);
    // JEQ,s small
    emit_opcode(cbuf, 0x74);
    emit_d8(cbuf, 0x05);
    // MOV    $dst.lo,$dst.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
    // SAR    $dst.hi,31
    emit_opcode(cbuf, 0xC1);
    emit_rm(cbuf, 0x3, 7, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
    emit_d8(cbuf, 0x1F );
// small:
    // SHRD   $dst.lo,$dst.hi,$shift
    emit_opcode(cbuf,0x0F);
    emit_opcode(cbuf,0xAD);
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), opnd_array(1)->reg(ra_,this,idx1));
    // SAR    $dst.hi,$shift"
    emit_opcode(cbuf,0xD3);
    emit_rm(cbuf, 0x3, 0x7, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
  
#line 17404 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  sarL_eReg_CLNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 18, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 18);
}
void cmpDPR_cc_P6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 17424 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 17432 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 17440 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Fixup the integer flags in case comparison involved a NaN
    //
    // JNP exit (no unordered comparison, P-flag is set by NaN)
    emit_opcode( cbuf, 0x7B );
    emit_d8    ( cbuf, 0x03 );
    // MOV AH,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // SAHF
    emit_opcode( cbuf, 0x9E);
    // NOP     // target for branch to avoid branch to branch
    emit_opcode( cbuf, 0x90);
  
#line 17459 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpDPR_cc_P6CFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 17475 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 17483 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 17491 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpDPR_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 17507 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 17515 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 17523 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // test ax,0x0400
    emit_opcode( cbuf, 0x66 );   // operand-size prefix for 16-bit immediate
    emit_opcode( cbuf, 0xA9 );
    emit_d16   ( cbuf, 0x0400 );
    // // // This sequence works, but stalls for 12-16 cycles on PPro
    // // test rax,0x0400
    // emit_opcode( cbuf, 0xA9 );
    // emit_d32   ( cbuf, 0x00000400 );
    //
    // jz exit (no unordered comparison)
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x02 );
    // mov ah,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // sahf
    emit_opcode( cbuf, 0x9E);
  
#line 17550 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpDPR_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 17566 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 17574 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE4 /*primary()*/));
  
#line 17582 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2352 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 17591 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2674 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 1 );
  
#line 17624 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 17640 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 17648 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 17656 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2674 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 1 );
  
#line 17689 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpD_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9546 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    emit_cmpfp_fixup(_masm);
  
#line 17706 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpD_ccCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9558 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 17722 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpD_ccmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9575 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp_fixup(_masm);
  
#line 17739 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpD_ccmemCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9587 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 17755 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9606 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this));
  
#line 17772 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpD_regmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9626 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomisd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this));
  
#line 17789 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 17805 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 17813 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 17821 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subDPR_reg_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 17837 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 17845 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 17853 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2409 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 17861 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subDPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 17876 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 17890 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 17898 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 17906 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void absDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 17920 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE1 /*primary()*/));
  
#line 17928 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void negDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 17942 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE0 /*primary()*/));
  
#line 17950 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 17966 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 17974 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 17982 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  addDPR_regNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 4);
}
void addDPR_reg_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 18002 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 18010 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18018 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2409 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 18026 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 18041 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18055 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18063 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18071 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 18086 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18100 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18108 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 18116 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 18131 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18145 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 18153 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 18161 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 18169 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 18177 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x03);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18191 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_mem_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 18206 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18220 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 18228 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 18236 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 18244 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 18252 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x03);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18266 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld1();
    __ faddp(opnd_array(1)->reg(ra_,this,idx1));
  
#line 18283 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9773 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ faddp(opnd_array(1)->reg(ra_,this,idx1));
  
#line 18300 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 9774 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 18308 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_imm_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9787 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fadd(opnd_array(1)->reg(ra_,this,idx1));
    __ fstp_d(Address(rsp, opnd_array(0)->disp(ra_,this,0)));
  
#line 18326 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_reg_imm_roundNode::eval_constant(Compile* C) {
  {

#line 9788 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 18334 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 18350 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18358 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18366 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void strictfp_mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2368 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias1() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18385 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 18394 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18402 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18410 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2376 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias2() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18422 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 9840 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_d(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fmulp(opnd_array(1)->reg(ra_,this,idx1));
  
#line 18439 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 9841 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 18447 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 18462 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18476 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18484 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18492 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*tertiary()*/));
  
#line 18507 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18521 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18529 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 18537 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_reg_mem_ciscNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 18552 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18566 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18575 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 18584 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulDPR_reg_mem_cisc_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 18599 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 18613 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 18622 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 18631 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18648 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2));
  
#line 18659 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3578 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3));
  
#line 18669 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addDPR_mulDPR_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
  
#line 18686 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(3)->reg(ra_,this,idx3));
  
#line 18697 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3578 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1));
  
#line 18707 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subDPR_mulDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18724 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2));
  
#line 18735 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE));
  
#line 18743 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1616 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE0) + opnd_array(3)->reg(ra_,this,idx3));
  
#line 18751 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 18767 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18775 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18783 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void strictfp_divDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2368 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias1() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18802 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 18811 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 18819 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18827 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2376 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDB );           // FLD m80real
    emit_opcode( cbuf, 0x2D );
    emit_d32( cbuf, (int)StubRoutines::addr_fpu_subnormal_bias2() );
    emit_opcode( cbuf, 0xDE );           // FMULP ST(dst), ST0
    emit_opcode( cbuf, 0xC8+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18839 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divDPR_reg_roundNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 18855 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 18863 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x6 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 18871 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2409 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 18879 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void modDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2458 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // load dst in FPR0
    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
    if (opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // swap src with FPR1:
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2) );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
  
#line 18908 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2599 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 18934 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2570 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2) );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
    // // following asm replaced with Pop_Reg_F or Pop_Mem_F
    // // FSTP   FPR$dst$$reg
    // emit_opcode( cbuf, 0xDD );
    // emit_d8( cbuf, 0xD8+$dst$$reg );
  
#line 18956 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 18965 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void modD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2476 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    __ fld_d(Address(rsp, 0));
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 18985 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2599 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 19011 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19022 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2352 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 19031 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sinDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 19045 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFE /*secondary()*/));
  
#line 19053 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sinD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 19070 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 19078 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFE /*secondary()*/));
  
#line 19086 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19097 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cosDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 19111 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*secondary()*/));
  
#line 19119 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cosD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 19136 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 19144 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*secondary()*/));
  
#line 19152 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19163 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void tanDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19177 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF2));
  
#line 19185 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 19193 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 19201 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void tanD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 19218 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19226 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF2));
  
#line 19234 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD));
  
#line 19242 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8));
  
#line 19250 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19261 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void atanDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );   // FLD ST(i-1)
  
#line 19277 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 19285 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF3 /*secondary()*/));
  
#line 19293 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0xF3 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 19301 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void atanD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    __ fld_d(Address(rsp, 0));
  
#line 19319 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 19327 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF3 /*secondary()*/));
  
#line 19335 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19346 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 19361 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 19369 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFA /*primary()*/));
  
#line 19377 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 19386 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void powDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2515 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
  
#line 19402 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 19411 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19419 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 19427 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2533 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FPR1 holds Y*ln2(X).  Compute FPR1 = 2^(Y*ln2(X))
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xC0);  // fdup = fld st(0)          Q       Q
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xFC);  // frndint               int(Q)      Q
    emit_opcode(cbuf,0xDC); emit_opcode(cbuf,0xE9);  // fsub st(1) -= st(0);  int(Q) frac(Q)
    emit_opcode(cbuf,0xDB);                          // FISTP [ESP]           frac(Q)
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xF0);  // f2xm1                 2^frac(Q)-1
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xE8);  // fld1                  1 2^frac(Q)-1
    emit_opcode(cbuf,0xDE); emit_opcode(cbuf,0xC1);  // faddp                 2^frac(Q)
    emit_opcode(cbuf,0x8B);                          // mov rax,[esp+0]=int(Q)
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 0, false);
    emit_opcode(cbuf,0xC7);                          // mov rcx,0xFFFFF800 - overflow mask
    emit_rm(cbuf, 0x3, 0x0, ECX_enc);
    emit_d32(cbuf,0xFFFFF800);
    emit_opcode(cbuf,0x81);                          // add rax,1023 - the double exponent bias
    emit_rm(cbuf, 0x3, 0x0, EAX_enc);
    emit_d32(cbuf,1023);
    emit_opcode(cbuf,0x8B);                          // mov rbx,eax
    emit_rm(cbuf, 0x3, EBX_enc, EAX_enc);
    emit_opcode(cbuf,0xC1);                          // shl rax,20 - Slide to exponent position
    emit_rm(cbuf,0x3,0x4,EAX_enc);
    emit_d8(cbuf,20);
    emit_opcode(cbuf,0x85);                          // test rbx,ecx - check for overflow
    emit_rm(cbuf, 0x3, EBX_enc, ECX_enc);
    emit_opcode(cbuf,0x0F); emit_opcode(cbuf,0x45);  // CMOVne rax,ecx - overflow; stuff NAN into EAX
    emit_rm(cbuf, 0x3, EAX_enc, ECX_enc);
    emit_opcode(cbuf,0x89);                          // mov [esp+4],eax - Store as part of double word
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 4, false);
    emit_opcode(cbuf,0xC7);                          // mov [esp+0],0   - [ESP] = (double)(1<<int(Q)) = 2^int(Q)
    encode_RegMem(cbuf, 0x0, ESP_enc, 0x4, 0, 0, false);
    emit_d32(cbuf,0);
    emit_opcode(cbuf,0xDC);                          // fmul dword st(0),[esp+0]; FPR1 = 2^int(Q)*2^frac(Q) = 2^Q
    encode_RegMem(cbuf, 0x1, ESP_enc, 0x4, 0, 0, false);
  
#line 19468 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2520 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ addptr(rsp, 8);
  
#line 19477 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void powD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2515 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
  
#line 19493 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2525 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ movdbl(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    __ fld_d(Address(rsp, 0));
  
#line 19503 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2525 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 19513 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19521 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 19529 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2533 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FPR1 holds Y*ln2(X).  Compute FPR1 = 2^(Y*ln2(X))
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xC0);  // fdup = fld st(0)          Q       Q
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xFC);  // frndint               int(Q)      Q
    emit_opcode(cbuf,0xDC); emit_opcode(cbuf,0xE9);  // fsub st(1) -= st(0);  int(Q) frac(Q)
    emit_opcode(cbuf,0xDB);                          // FISTP [ESP]           frac(Q)
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xF0);  // f2xm1                 2^frac(Q)-1
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xE8);  // fld1                  1 2^frac(Q)-1
    emit_opcode(cbuf,0xDE); emit_opcode(cbuf,0xC1);  // faddp                 2^frac(Q)
    emit_opcode(cbuf,0x8B);                          // mov rax,[esp+0]=int(Q)
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 0, false);
    emit_opcode(cbuf,0xC7);                          // mov rcx,0xFFFFF800 - overflow mask
    emit_rm(cbuf, 0x3, 0x0, ECX_enc);
    emit_d32(cbuf,0xFFFFF800);
    emit_opcode(cbuf,0x81);                          // add rax,1023 - the double exponent bias
    emit_rm(cbuf, 0x3, 0x0, EAX_enc);
    emit_d32(cbuf,1023);
    emit_opcode(cbuf,0x8B);                          // mov rbx,eax
    emit_rm(cbuf, 0x3, EBX_enc, EAX_enc);
    emit_opcode(cbuf,0xC1);                          // shl rax,20 - Slide to exponent position
    emit_rm(cbuf,0x3,0x4,EAX_enc);
    emit_d8(cbuf,20);
    emit_opcode(cbuf,0x85);                          // test rbx,ecx - check for overflow
    emit_rm(cbuf, 0x3, EBX_enc, ECX_enc);
    emit_opcode(cbuf,0x0F); emit_opcode(cbuf,0x45);  // CMOVne rax,ecx - overflow; stuff NAN into EAX
    emit_rm(cbuf, 0x3, EAX_enc, ECX_enc);
    emit_opcode(cbuf,0x89);                          // mov [esp+4],eax - Store as part of double word
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 4, false);
    emit_opcode(cbuf,0xC7);                          // mov [esp+0],0   - [ESP] = (double)(1<<int(Q)) = 2^int(Q)
    encode_RegMem(cbuf, 0x0, ESP_enc, 0x4, 0, 0, false);
    emit_d32(cbuf,0);
    emit_opcode(cbuf,0xDC);                          // fmul dword st(0),[esp+0]; FPR1 = 2^int(Q)*2^frac(Q) = 2^Q
    encode_RegMem(cbuf, 0x1, ESP_enc, 0x4, 0, 0, false);
  
#line 19570 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19581 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void expDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2515 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
  
#line 19596 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19604 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xEA));
  
#line 19612 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE));
  
#line 19620 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC9));
  
#line 19628 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2533 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FPR1 holds Y*ln2(X).  Compute FPR1 = 2^(Y*ln2(X))
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xC0);  // fdup = fld st(0)          Q       Q
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xFC);  // frndint               int(Q)      Q
    emit_opcode(cbuf,0xDC); emit_opcode(cbuf,0xE9);  // fsub st(1) -= st(0);  int(Q) frac(Q)
    emit_opcode(cbuf,0xDB);                          // FISTP [ESP]           frac(Q)
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xF0);  // f2xm1                 2^frac(Q)-1
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xE8);  // fld1                  1 2^frac(Q)-1
    emit_opcode(cbuf,0xDE); emit_opcode(cbuf,0xC1);  // faddp                 2^frac(Q)
    emit_opcode(cbuf,0x8B);                          // mov rax,[esp+0]=int(Q)
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 0, false);
    emit_opcode(cbuf,0xC7);                          // mov rcx,0xFFFFF800 - overflow mask
    emit_rm(cbuf, 0x3, 0x0, ECX_enc);
    emit_d32(cbuf,0xFFFFF800);
    emit_opcode(cbuf,0x81);                          // add rax,1023 - the double exponent bias
    emit_rm(cbuf, 0x3, 0x0, EAX_enc);
    emit_d32(cbuf,1023);
    emit_opcode(cbuf,0x8B);                          // mov rbx,eax
    emit_rm(cbuf, 0x3, EBX_enc, EAX_enc);
    emit_opcode(cbuf,0xC1);                          // shl rax,20 - Slide to exponent position
    emit_rm(cbuf,0x3,0x4,EAX_enc);
    emit_d8(cbuf,20);
    emit_opcode(cbuf,0x85);                          // test rbx,ecx - check for overflow
    emit_rm(cbuf, 0x3, EBX_enc, ECX_enc);
    emit_opcode(cbuf,0x0F); emit_opcode(cbuf,0x45);  // CMOVne rax,ecx - overflow; stuff NAN into EAX
    emit_rm(cbuf, 0x3, EAX_enc, ECX_enc);
    emit_opcode(cbuf,0x89);                          // mov [esp+4],eax - Store as part of double word
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 4, false);
    emit_opcode(cbuf,0xC7);                          // mov [esp+0],0   - [ESP] = (double)(1<<int(Q)) = 2^int(Q)
    encode_RegMem(cbuf, 0x0, ESP_enc, 0x4, 0, 0, false);
    emit_d32(cbuf,0);
    emit_opcode(cbuf,0xDC);                          // fmul dword st(0),[esp+0]; FPR1 = 2^int(Q)*2^frac(Q) = 2^Q
    encode_RegMem(cbuf, 0x1, ESP_enc, 0x4, 0, 0, false);
  
#line 19669 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2520 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ addptr(rsp, 8);
  
#line 19678 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void expD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 19695 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19703 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xEA));
  
#line 19711 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE));
  
#line 19719 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC9));
  
#line 19727 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2533 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FPR1 holds Y*ln2(X).  Compute FPR1 = 2^(Y*ln2(X))
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xC0);  // fdup = fld st(0)          Q       Q
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xFC);  // frndint               int(Q)      Q
    emit_opcode(cbuf,0xDC); emit_opcode(cbuf,0xE9);  // fsub st(1) -= st(0);  int(Q) frac(Q)
    emit_opcode(cbuf,0xDB);                          // FISTP [ESP]           frac(Q)
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xF0);  // f2xm1                 2^frac(Q)-1
    emit_opcode(cbuf,0xD9); emit_opcode(cbuf,0xE8);  // fld1                  1 2^frac(Q)-1
    emit_opcode(cbuf,0xDE); emit_opcode(cbuf,0xC1);  // faddp                 2^frac(Q)
    emit_opcode(cbuf,0x8B);                          // mov rax,[esp+0]=int(Q)
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 0, false);
    emit_opcode(cbuf,0xC7);                          // mov rcx,0xFFFFF800 - overflow mask
    emit_rm(cbuf, 0x3, 0x0, ECX_enc);
    emit_d32(cbuf,0xFFFFF800);
    emit_opcode(cbuf,0x81);                          // add rax,1023 - the double exponent bias
    emit_rm(cbuf, 0x3, 0x0, EAX_enc);
    emit_d32(cbuf,1023);
    emit_opcode(cbuf,0x8B);                          // mov rbx,eax
    emit_rm(cbuf, 0x3, EBX_enc, EAX_enc);
    emit_opcode(cbuf,0xC1);                          // shl rax,20 - Slide to exponent position
    emit_rm(cbuf,0x3,0x4,EAX_enc);
    emit_d8(cbuf,20);
    emit_opcode(cbuf,0x85);                          // test rbx,ecx - check for overflow
    emit_rm(cbuf, 0x3, EBX_enc, ECX_enc);
    emit_opcode(cbuf,0x0F); emit_opcode(cbuf,0x45);  // CMOVne rax,ecx - overflow; stuff NAN into EAX
    emit_rm(cbuf, 0x3, EAX_enc, ECX_enc);
    emit_opcode(cbuf,0x89);                          // mov [esp+4],eax - Store as part of double word
    encode_RegMem(cbuf, EAX_enc, ESP_enc, 0x4, 0, 4, false);
    emit_opcode(cbuf,0xC7);                          // mov [esp+0],0   - [ESP] = (double)(1<<int(Q)) = 2^int(Q)
    encode_RegMem(cbuf, 0x0, ESP_enc, 0x4, 0, 0, false);
    emit_d32(cbuf,0);
    emit_opcode(cbuf,0xDC);                          // fmul dword st(0),[esp+0]; FPR1 = 2^int(Q)*2^frac(Q) = 2^Q
    encode_RegMem(cbuf, 0x1, ESP_enc, 0x4, 0, 0, false);
  
#line 19768 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19779 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void log10DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19793 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xEC));
  
#line 19801 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19809 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC9));
  
#line 19817 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19825 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 19833 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void log10D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19847 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xEC));
  
#line 19855 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 19866 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19874 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 19882 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 19893 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void logDPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19907 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xED));
  
#line 19915 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19923 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC9));
  
#line 19931 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19939 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 19947 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void logD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19961 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xED));
  
#line 19969 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2508 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
  
#line 19980 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9));
  
#line 19988 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF1));
  
#line 19996 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 20007 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpFPR_cc_P6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 20023 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 20031 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20039 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Fixup the integer flags in case comparison involved a NaN
    //
    // JNP exit (no unordered comparison, P-flag is set by NaN)
    emit_opcode( cbuf, 0x7B );
    emit_d8    ( cbuf, 0x03 );
    // MOV AH,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // SAHF
    emit_opcode( cbuf, 0x9E);
    // NOP     // target for branch to avoid branch to branch
    emit_opcode( cbuf, 0x90);
  
#line 20058 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpFPR_cc_P6CFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 20074 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDF /*primary()*/));
  
#line 20082 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x05 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20090 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpFPR_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 20106 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20114 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20122 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2621 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // test ax,0x0400
    emit_opcode( cbuf, 0x66 );   // operand-size prefix for 16-bit immediate
    emit_opcode( cbuf, 0xA9 );
    emit_d16   ( cbuf, 0x0400 );
    // // // This sequence works, but stalls for 12-16 cycles on PPro
    // // test rax,0x0400
    // emit_opcode( cbuf, 0xA9 );
    // emit_d32   ( cbuf, 0x00000400 );
    //
    // jz exit (no unordered comparison)
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x02 );
    // mov ah,1 - treat as LT case (set carry flag)
    emit_opcode( cbuf, 0xB4 );
    emit_d8    ( cbuf, 0x01 );
    // sahf
    emit_opcode( cbuf, 0x9E);
  
#line 20149 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpFPR_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 20165 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 20173 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE4 /*primary()*/));
  
#line 20181 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2352 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 20190 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2674 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 1 );
  
#line 20223 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 20239 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20247 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x3 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20255 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2674 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fnstsw_ax();
    emit_opcode( cbuf, 0xDF);
    emit_opcode( cbuf, 0xE0);
    // sahf
    emit_opcode( cbuf, 0x9E);
    // movl(dst, nan_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::parity, exit);
    emit_opcode( cbuf, 0x7A );
    emit_d8    ( cbuf, 0x13 );
    // movl(dst, less_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, -1 );
    // jcc(Assembler::below, exit);
    emit_opcode( cbuf, 0x72 );
    emit_d8    ( cbuf, 0x0C );
    // movl(dst, equal_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 0 );
    // jcc(Assembler::equal, exit);
    emit_opcode( cbuf, 0x74 );
    emit_d8    ( cbuf, 0x05 );
    // movl(dst, greater_result);
    emit_opcode( cbuf, 0xB8 + opnd_array(0)->reg(ra_,this));
    emit_d32( cbuf, 1 );
  
#line 20288 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpF_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10432 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    emit_cmpfp_fixup(_masm);
  
#line 20305 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpF_ccCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10444 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 20321 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpF_ccmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10461 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp_fixup(_masm);
  
#line 20338 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpF_ccmemCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10473 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 20354 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10492 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this));
  
#line 20371 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpF_regmemNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10512 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ ucomiss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
    emit_cmpfp3(_masm, opnd_array(0)->as_Register(ra_,this));
  
#line 20388 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 20404 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20413 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20421 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20437 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20445 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x5 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 20453 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20469 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 20478 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20486 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20502 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20510 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 20518 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void absFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 20532 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE1 /*primary()*/));
  
#line 20540 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void negFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*secondary()*/));
  
#line 20554 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xE0 /*primary()*/));
  
#line 20562 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20577 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20591 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 20600 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20608 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20623 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20637 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20646 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20654 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20669 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20683 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20691 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 20699 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20714 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20728 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 20736 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20744 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20759 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20773 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x0 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 20782 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20790 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_mem_ciscNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20805 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20819 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 20827 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20835 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x0 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20849 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20857 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_mem_cisc_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20872 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20886 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 20894 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20902 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x0 /*secondary()*/);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20916 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20924 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_mem_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 20939 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20953 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 20961 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 20969 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x0 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 20983 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 20991 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10670 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)- 1);  // FLD ST(i-1)
    __ fadd_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_s(Address(rsp, opnd_array(0)->disp(ra_,this,0)));
  
#line 21009 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR24_reg_immNode::eval_constant(Compile* C) {
  {

#line 10672 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 21017 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10685 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)- 1);  // FLD ST(i-1)
    __ fadd_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 21035 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 10687 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 21043 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21059 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21068 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 21076 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21092 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21101 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21110 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR24_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21125 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21139 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21148 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 21156 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR24_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21171 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21185 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21194 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 21202 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21217 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21231 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21240 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21249 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21264 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21278 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21287 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21296 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR24_mem_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21311 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21325 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2059 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();            // Mark start of opcode for reloc info in mem operand
  
#line 21333 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD8 /*primary()*/));
  
#line 21341 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x1 /*secondary()*/);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21355 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 21363 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR24_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10776 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)- 1);  // FLD ST(i-1)
    __ fmul_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_s(Address(rsp, opnd_array(0)->disp(ra_,this,0)));
  
#line 21381 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR24_reg_immNode::eval_constant(Compile* C) {
  {

#line 10778 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 21389 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 10792 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ fld_s(opnd_array(1)->reg(ra_,this,idx1)- 1);  // FLD ST(i-1)
    __ fmul_s(InternalAddress(__ code()->consts()->start() + constant_offset()));
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 21407 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_immNode::eval_constant(Compile* C) {
  {

#line 10794 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 21415 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_load1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21430 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21444 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21453 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21462 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulFPR_reg_load1_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*tertiary()*/));
  
#line 21477 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21491 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x1 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21500 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21509 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_mulFPR_reg_load1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21525 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21539 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2));
  
#line 21550 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3571 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3));
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 21561 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21570 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_mulFPR_reg_load1_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21586 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21600 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(3)->reg(ra_,this,idx3));
  
#line 21611 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3571 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1));
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 21622 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21631 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_mulFPR_reg_load1_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21647 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(2)->base(ra_,this,idx2);
    int index    = opnd_array(2)->index(ra_,this,idx2);
    int scale    = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21661 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(1)->reg(ra_,this,idx1));
  
#line 21672 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3571 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3));
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 21683 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21692 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_mulFPR_reg_load1_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 21708 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(3)->base(ra_,this,idx3);
    int index    = opnd_array(3)->index(ra_,this,idx3);
    int scale    = opnd_array(3)->scale();
    int displace = opnd_array(3)->disp(ra_,this,idx3);
    bool disp_is_oop = opnd_array(3)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 21722 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2));
  
#line 21733 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3571 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  ST,src2  /* D8 C0+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1));
    //could use FADDP  src2,fpST  /* DE C0+i */
  
#line 21744 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21753 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_mulFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21770 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(2)->reg(ra_,this,idx2));
  
#line 21781 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3578 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(3)->reg(ra_,this,idx3));
  
#line 21791 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addFPR_mulFPR_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21808 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand was loaded from memory into fp ST (stack top)
    // FMUL   ST,$src  /* D8 C8+i */
    emit_opcode(cbuf, 0xD8);
    emit_opcode(cbuf, 0xC8 + opnd_array(3)->reg(ra_,this,idx3));
  
#line 21819 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3578 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // FADDP  src2,ST  /* DE C0+i */
    emit_opcode(cbuf, 0xDE);
    emit_opcode(cbuf, 0xC0 + opnd_array(1)->reg(ra_,this,idx1));
  
#line 21829 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subFPR_divFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21846 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3584 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Operand has been loaded into fp ST (stack top)
      // FSUB   ST,$src1
      emit_opcode(cbuf, 0xD8);
      emit_opcode(cbuf, 0xE0 + opnd_array(2)->reg(ra_,this,idx2));

      // FDIV
      emit_opcode(cbuf, 0xD8);
      emit_opcode(cbuf, 0xF0 + opnd_array(3)->reg(ra_,this,idx3));
  
#line 21861 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 21870 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21886 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2346 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0xD8 /*primary()*/));
    emit_rm(cbuf, 0x3, (0x6 /*secondary()*/), opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21895 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 21903 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(2)->reg(ra_,this,idx2) );
  
#line 21919 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDE /*primary()*/));
  
#line 21927 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x7 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 21935 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void modFPR24_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2458 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // load dst in FPR0
    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
    if (opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // swap src with FPR1:
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2) );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
  
#line 21964 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2599 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 21990 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2570 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2) );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
    // // following asm replaced with Pop_Reg_F or Pop_Mem_F
    // // FSTP   FPR$dst$$reg
    // emit_opcode( cbuf, 0xDD );
    // emit_d8( cbuf, 0xD8+$dst$$reg );
  
#line 22012 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 22020 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void modFPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2458 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // load dst in FPR0
    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
    if (opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // swap src with FPR1:
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2) );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
  
#line 22049 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2599 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 22075 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2570 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (opnd_array(2)->reg(ra_,this,idx2) != FPR1L_enc) {
      // fincstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF7);
      // FXCH FPR1 with src
      emit_opcode(cbuf, 0xD9);
      emit_d8(cbuf, 0xC8-1+opnd_array(2)->reg(ra_,this,idx2) );
      // fdecstp
      emit_opcode (cbuf, 0xD9);
      emit_opcode (cbuf, 0xF6);
    }
    // // following asm replaced with Pop_Reg_F or Pop_Mem_F
    // // FSTP   FPR$dst$$reg
    // emit_opcode( cbuf, 0xDD );
    // emit_d8( cbuf, 0xD8+$dst$$reg );
  
#line 22097 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 22106 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void modF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2485 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
    __ fld_s(Address(rsp, 0));
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_s(Address(rsp, 0));
  
#line 22126 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2599 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // fprem must be iterative
    // :: loop
    // fprem
    emit_opcode( cbuf, 0xD9 );
    emit_opcode( cbuf, 0xF8 );
    // wait
    emit_opcode( cbuf, 0x9b );
    // fnstsw ax
    emit_opcode( cbuf, 0xDF );
    emit_opcode( cbuf, 0xE0 );
    // sahf
    emit_opcode( cbuf, 0x9E );
    // jp  ::loop
    emit_opcode( cbuf, 0x0F );
    emit_opcode( cbuf, 0x8A );
    emit_opcode( cbuf, 0xF4 );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
    emit_opcode( cbuf, 0xFF );
  
#line 22152 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2501 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_s(Address(rsp, 0));
    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, (0x4));
  
#line 22163 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2352 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, 0xD8 );
  
#line 22172 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void roundFloat_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2424 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1) != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xD9, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_S  [ESP+dst]
  
#line 22192 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void roundDouble_mem_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2435 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1) != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xDD, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_D  [ESP+dst]
  
#line 22212 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convDPR2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 10992 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ subptr(rsp, 4);
    if (opnd_array(1)->reg(ra_,this,idx1)!= FPR1L_enc) {
      __ fld_s(opnd_array(1)->reg(ra_,this,idx1)-1);
      __ fstp_s(Address(rsp, 0));
    } else {
      __ fst_s(Address(rsp, 0));
    }
    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, 4);
  
#line 22235 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11011 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsd2ss (opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
  
#line 22250 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convFPR2DPR_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2446 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0xD0 - 1; // -1 since we skip FLD
    if (opnd_array(1)->reg(ra_,this,idx1) != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(src-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
      pop = 0xD8;
    }
    emit_opcode( cbuf, 0xDD );
    emit_d8( cbuf, pop+opnd_array(0)->reg(ra_,this) );      // FST<P> ST(i)
  
#line 22271 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convF2DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11043 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_s(Address(rsp, 0));
    __ addptr(rsp, 4);
    __ fstp_d(opnd_array(0)->reg(ra_,this));
  
#line 22290 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11057 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtss2sd (opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
  
#line 22305 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convDPR2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 22320 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3479 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Flip to round-to-zero mode.  We attempted to allow invalid-op
    // exceptions here, so that a NAN or other corner-case value will
    // thrown an exception (but normal values get converted at full speed).
    // However, I2C adapters and other float-stack manglers leave pending
    // invalid-op exceptions hanging.  We would have to clear them before
    // enabling them and that is more expensive than just testing for the
    // invalid value Intel stores down in the corner cases.
    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,4
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x04);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as an int, popping the FPU stack
    emit_opcode(cbuf,0xDB);            // FISTP [ESP]
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x3D);       // CMP EAX,imm
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2i_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 22367 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11097 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ cvttsd2sil(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ cmpl(opnd_array(0)->as_Register(ra_,this), 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
    __ addptr(rsp, 8);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2i_wrapper())));
    __ bind(fast);
  
#line 22391 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convDPR2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );   // FLD ST(i-1)
  
#line 22406 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3522 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,8
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x08);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as a long, popping the FPU stack
    emit_opcode(cbuf,0xDF);            // FISTP [ESP]
    emit_opcode(cbuf,0x3C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x5A);       // POP EDX
    emit_opcode(cbuf,0x81);       // CMP EDX,imm
    emit_d8    (cbuf,0xFA);       // rdx
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07+4);     // Size of slow_call
    emit_opcode(cbuf,0x85);       // TEST EAX,EAX
    emit_opcode(cbuf,0xC0);       // 2/rax,/rax,
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2l_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 22452 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11157 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
    __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_trunc()));
    __ fistp_d(Address(rsp, 0));
    // Restore the rounding mode, mask the exception
    if (Compile::current()->in_24_bit_fp_mode()) {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    } else {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    // Load the converted long, adjust CPU stack
    __ pop(rax);
    __ pop(rdx);
    __ cmpl(rdx, 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ testl(rax, rax);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 8);
    __ movdbl(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_d(Address(rsp, 0));
    __ addptr(rsp, 8);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2l_wrapper())));
    __ bind(fast);
  
#line 22491 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convFPR2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 22506 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3479 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Flip to round-to-zero mode.  We attempted to allow invalid-op
    // exceptions here, so that a NAN or other corner-case value will
    // thrown an exception (but normal values get converted at full speed).
    // However, I2C adapters and other float-stack manglers leave pending
    // invalid-op exceptions hanging.  We would have to clear them before
    // enabling them and that is more expensive than just testing for the
    // invalid value Intel stores down in the corner cases.
    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,4
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x04);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as an int, popping the FPU stack
    emit_opcode(cbuf,0xDB);            // FISTP [ESP]
    emit_opcode(cbuf,0x1C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x3D);       // CMP EAX,imm
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2i_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 22553 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convF2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11227 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ cvttss2sil(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ cmpl(opnd_array(0)->as_Register(ra_,this), 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_s(Address(rsp, 0));
    __ addptr(rsp, 4);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2i_wrapper())));
    __ bind(fast);
  
#line 22577 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convFPR2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xD9 );           // FLD    ST(i-1)
    emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
  
#line 22592 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 3522 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0xD9);            // FLDCW  trunc
    emit_opcode(cbuf,0x2D);
    emit_d32(cbuf,(int)StubRoutines::addr_fpu_cntrl_wrd_trunc());
    // Allocate a word
    emit_opcode(cbuf,0x83);            // SUB ESP,8
    emit_opcode(cbuf,0xEC);
    emit_d8(cbuf,0x08);
    // Encoding assumes a double has been pushed into FPR0.
    // Store down the double as a long, popping the FPU stack
    emit_opcode(cbuf,0xDF);            // FISTP [ESP]
    emit_opcode(cbuf,0x3C);
    emit_d8(cbuf,0x24);
    // Restore the rounding mode; mask the exception
    emit_opcode(cbuf,0xD9);            // FLDCW   std/24-bit mode
    emit_opcode(cbuf,0x2D);
    emit_d32( cbuf, Compile::current()->in_24_bit_fp_mode()
        ? (int)StubRoutines::addr_fpu_cntrl_wrd_24()
        : (int)StubRoutines::addr_fpu_cntrl_wrd_std());

    // Load the converted int; adjust CPU stack
    emit_opcode(cbuf,0x58);       // POP EAX
    emit_opcode(cbuf,0x5A);       // POP EDX
    emit_opcode(cbuf,0x81);       // CMP EDX,imm
    emit_d8    (cbuf,0xFA);       // rdx
    emit_d32   (cbuf,0x80000000); //         0x80000000
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07+4);     // Size of slow_call
    emit_opcode(cbuf,0x85);       // TEST EAX,EAX
    emit_opcode(cbuf,0xC0);       // 2/rax,/rax,
    emit_opcode(cbuf,0x75);       // JNE around_slow_call
    emit_d8    (cbuf,0x07);       // Size of slow_call
    // Push src onto stack slow-path
    emit_opcode(cbuf,0xD9 );      // FLD     ST(i)
    emit_d8    (cbuf,0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
    // CALL directly to the runtime
    cbuf.set_insts_mark();
    emit_opcode(cbuf,0xE8);       // Call into runtime
    emit_d32_reloc(cbuf, (StubRoutines::d2l_wrapper() - cbuf.insts_end()) - 4, runtime_call_Relocation::spec(), RELOC_IMM32 );
    // Carry on here...
  
#line 22638 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convF2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11288 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label fast;
    __ subptr(rsp, 8);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_s(Address(rsp, 0));
    __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_trunc()));
    __ fistp_d(Address(rsp, 0));
    // Restore the rounding mode, mask the exception
    if (Compile::current()->in_24_bit_fp_mode()) {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    } else {
      __ fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    // Load the converted long, adjust CPU stack
    __ pop(rax);
    __ pop(rdx);
    __ cmpl(rdx, 0x80000000);
    __ jccb(Assembler::notEqual, fast);
    __ testl(rax, rax);
    __ jccb(Assembler::notEqual, fast);
    __ subptr(rsp, 4);
    __ movflt(Address(rsp, 0), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ fld_s(Address(rsp, 0));
    __ addptr(rsp, 4);
    __ call(RuntimeAddress(CAST_FROM_FN_PTR(address, StubRoutines::d2l_wrapper())));
    __ bind(fast);
  
#line 22677 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2398 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 22691 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 22700 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11332 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsi2sdl (opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 22715 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2D_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 11342 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsi2sdl (opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 22730 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convXI2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11355 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
    __ cvtdq2pd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 22746 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2DPR_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDB /*primary()*/));
  
#line 22760 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 22774 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 22783 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void conv24I2FPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2398 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 22797 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 22806 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2FPR_SSFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2398 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 22820 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 22828 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2FPR_SSF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDB /*primary()*/));
  
#line 22842 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 22856 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 22864 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2FPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2398 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, (0xDB /*primary()*/), (0x0 /*secondary()*/), opnd_array(1)->disp(ra_,this,idx1) );
  
#line 22878 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 22887 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2FPR_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDB /*primary()*/));
  
#line 22901 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 22915 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 22924 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11440 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ cvtsi2ssl (opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 22939 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convXI2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11453 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
    __ cvtdq2ps(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 22955 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2719 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // mov $dst.lo,$src
    int dst_encoding = opnd_array(0)->reg(ra_,this);
    int src_encoding = opnd_array(1)->reg(ra_,this,idx1);
    encode_Copy( cbuf, dst_encoding  , src_encoding );
    // mov $dst.hi,$src
    encode_Copy( cbuf, HIGH_FROM_LOW(dst_encoding), src_encoding );
    // sar $dst.hi,31
    emit_opcode( cbuf, 0xC1 );
    emit_rm(cbuf, 0x3, 7, HIGH_FROM_LOW(dst_encoding) );
    emit_d8(cbuf, 0x1F );
  
#line 22978 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convI2L_reg_zexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1938 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 22993 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 23001 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)), HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)));
  
#line 23009 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void zerox_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1938 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 23024 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x33 /*primary()*/));
  
#line 23032 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)), HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this)));
  
#line 23040 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convL2DPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2732 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
    // pop stack
    emit_opcode(cbuf, 0x83); // add  SP, #8
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 0x8);
  
#line 23066 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2409 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xDD, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23074 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convL2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2762 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
  
#line 23096 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_d(Address(rsp, 0));
    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, 8);
  
#line 23107 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convL2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2762 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
  
#line 23129 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2501 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler _masm(&cbuf);
    __ fstp_s(Address(rsp, 0));
    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, 0));
    __ addptr(rsp, (0x8));
  
#line 23140 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convL2FPR_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2732 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // push $src.hi
    emit_opcode(cbuf, 0x50+HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
    // push $src.lo
    emit_opcode(cbuf, 0x50+opnd_array(1)->reg(ra_,this,idx1)  );
    // fild 64-bits at [SP]
    emit_opcode(cbuf,0xdf);
    emit_d8(cbuf, 0x6C);
    emit_d8(cbuf, 0x24);
    emit_d8(cbuf, 0x00);
    // pop stack
    emit_opcode(cbuf, 0x83); // add  SP, #8
    emit_rm(cbuf, 0x3, 0x00, ESP_enc);
    emit_d8(cbuf, 0x8);
  
#line 23166 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    store_to_stackslot( cbuf, 0xD9, 0x03, opnd_array(0)->disp(ra_,this,0) );
  
#line 23174 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1942 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    encode_Copy( cbuf, opnd_array(0)->reg(ra_,this), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 23188 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11566 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(opnd_array(0)->as_Register(ra_,this), Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23203 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveFPR2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2424 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1) != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xD9, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_S  [ESP+dst]
  
#line 23223 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveF2I_reg_stack_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11590 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
  
#line 23238 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveF2I_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11602 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
  
#line 23253 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11614 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 23268 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveI2FPR_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD9 /*primary()*/));
  
#line 23282 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 23296 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2413 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 23305 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveI2F_stack_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11642 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movflt(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23320 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveI2F_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11655 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 23335 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*primary()*/));
  
#line 23349 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(0)->reg(ra_,this);
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 23363 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x8B /*secondary()*/));
  
#line 23371 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(0)->reg(ra_,this));  // Hi register of pair, computed from lo
    int base  = opnd_array(1)->base(ra_,this,idx1);
    int index = opnd_array(1)->index(ra_,this,idx1);
    int scale = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(1)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 23385 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveDPR2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 2435 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int pop = 0x02;
    if (opnd_array(1)->reg(ra_,this,idx1) != FPR1L_enc) {
      emit_opcode( cbuf, 0xD9 );         // FLD    ST(i-1)
      emit_d8( cbuf, 0xC0-1+opnd_array(1)->reg(ra_,this,idx1) );
      pop = 0x03;
    }
    store_to_stackslot( cbuf, 0xDD, pop, opnd_array(0)->disp(ra_,this,0) ); // FST<P>_D  [ESP+dst]
  
#line 23405 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveD2L_reg_stack_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11690 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(Address(rsp, opnd_array(0)->disp(ra_,this,0)), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
  
#line 23420 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveD2L_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 11704 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_Register(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    __ pshuflw(opnd_array(2)->as_XMMRegister(ra_,this,idx2), opnd_array(1)->as_XMMRegister(ra_,this,idx1), 0x4e);
    __ movdl(HIGH_FROM_LOW(opnd_array(0)->as_Register(ra_,this)), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 23438 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*primary()*/));
  
#line 23452 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0);
    bool disp_is_oop = opnd_array(0)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 23466 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1547 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x89 /*secondary()*/));
  
#line 23474 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1));  // Hi register of pair, computed from lo
    int base  = opnd_array(0)->base(ra_,this,idx0);
    int index = opnd_array(0)->index(ra_,this,idx0);
    int scale = opnd_array(0)->scale();
    int displace = opnd_array(0)->disp(ra_,this,0) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(0)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 23488 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveL2DPR_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xDD /*primary()*/));
  
#line 23502 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2143 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    assert( !opnd_array(1)->disp_is_oop(), "No oops here because no relo info allowed" );
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, false);
  
#line 23516 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2358 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode( cbuf, 0xDD );           // FSTP   ST(i)
    emit_d8( cbuf, 0xD8+opnd_array(0)->reg(ra_,this) );
  
#line 23525 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveL2D_stack_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11747 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23540 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveL2D_stack_reg_sse_partialNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdbl(opnd_array(0)->as_XMMRegister(ra_,this), Address(rsp, opnd_array(1)->disp(ra_,this,idx1)));
  
#line 23555 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void MoveL2D_reg_reg_sseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 11774 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(2)->as_XMMRegister(ra_,this,idx2), opnd_array(1)->as_Register(ra_,this,idx1));
    __ movdl(opnd_array(3)->as_XMMRegister(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)));
    __ punpckldq(opnd_array(2)->as_XMMRegister(ra_,this,idx2), opnd_array(3)->as_XMMRegister(ra_,this,idx3));
  
#line 23574 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11789 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if (opnd_array(0)->reg(ra_,this)!= opnd_array(1)->reg(ra_,this,idx1)) {
      __ movdqa(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
    }
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this), 0x00);
  
#line 23593 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl8B_eRegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11806 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
    __ punpcklbw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this), 0x00);
  
#line 23610 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl8B_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11819 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 23625 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11830 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), 0x00);
  
#line 23640 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4S_eRegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11842 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this), 0x00);
  
#line 23656 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4S_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11854 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 23671 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4C_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11865 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), 0x00);
  
#line 23686 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4C_eRegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11877 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
    __ pshuflw(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this), 0x00);
  
#line 23702 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl4C_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11889 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 23717 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11900 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), 0x00);
  
#line 23732 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2I_eRegINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11912 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ movdl(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_Register(ra_,this,idx1));
    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this), 0x00);
  
#line 23748 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2I_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11924 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 23763 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11935 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), 0xe0);
  
#line 23778 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2F_regFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pshufd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), 0xe0);
  
#line 23793 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void Repl2F_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 11957 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ pxor(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(0)->as_XMMRegister(ra_,this));
  
#line 23808 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void rep_stosNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xD1));
  
#line 23823 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), (ECX_enc) );
  
#line 23831 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1564 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,(0x33));
    emit_rm(cbuf, 0x3, (EAX_enc), (EAX_enc));
  
#line 23840 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF3));
  
#line 23848 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1552 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xAB));
  
#line 23856 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void string_compareNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
    unsigned idx5 = idx4 + opnd_array(4)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 11984 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(3)->as_Register(ra_,this,idx3),
                      opnd_array(2)->as_Register(ra_,this,idx2), opnd_array(4)->as_Register(ra_,this,idx4), opnd_array(0)->as_Register(ra_,this),
                      opnd_array(5)->as_XMMRegister(ra_,this,idx5));
  
#line 23877 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void string_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
    unsigned idx5 = idx4 + opnd_array(4)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 11999 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ char_arrays_equals(false, opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(2)->as_Register(ra_,this,idx2),
                          opnd_array(3)->as_Register(ra_,this,idx3), opnd_array(0)->as_Register(ra_,this), as_Register(EBX_enc),
                          opnd_array(4)->as_XMMRegister(ra_,this,idx4), opnd_array(5)->as_XMMRegister(ra_,this,idx5));
  
#line 23898 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void string_indexof_conNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
    unsigned idx5 = idx4 + opnd_array(4)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12015 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int icnt2 = (int)opnd_array(4)->constant();
    if (icnt2 >= 8) {
      // IndexOf for constant substrings with size >= 8 elements
      // which don't need to be loaded through stack.
      __ string_indexofC8(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(3)->as_Register(ra_,this,idx3),
                          opnd_array(2)->as_Register(ra_,this,idx2), as_Register(EAX_enc),
                          icnt2, opnd_array(0)->as_Register(ra_,this),
                          opnd_array(5)->as_XMMRegister(ra_,this,idx5), as_Register(ECX_enc));
    } else {
      // Small strings are loaded through stack if they cross page boundary.
      __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(3)->as_Register(ra_,this,idx3),
                        opnd_array(2)->as_Register(ra_,this,idx2), as_Register(EAX_enc),
                        icnt2, opnd_array(0)->as_Register(ra_,this),
                        opnd_array(5)->as_XMMRegister(ra_,this,idx5), as_Register(ECX_enc));
    }
  
#line 23931 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void string_indexofNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
    unsigned idx5 = idx4 + opnd_array(4)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12042 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ string_indexof(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(3)->as_Register(ra_,this,idx3),
                      opnd_array(2)->as_Register(ra_,this,idx2), opnd_array(4)->as_Register(ra_,this,idx4),
                      (-1), opnd_array(0)->as_Register(ra_,this),
                      opnd_array(5)->as_XMMRegister(ra_,this,idx5), as_Register(ECX_enc));
  
#line 23953 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void array_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12060 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    __ char_arrays_equals(true, opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(2)->as_Register(ra_,this,idx2),
                          as_Register(ECX_enc), opnd_array(0)->as_Register(ra_,this), as_Register(EBX_enc),
                          opnd_array(3)->as_XMMRegister(ra_,this,idx3), opnd_array(4)->as_XMMRegister(ra_,this,idx4));
  
#line 23973 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 23988 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 23996 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compI_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 24019 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 24034 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compI_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 24049 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 24063 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void testI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 24078 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(1)->reg(ra_,this,idx1));
  
#line 24086 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void testI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 24102 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x00 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 24110 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1972 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Output immediate
    emit_d32(cbuf, opnd_array(2)->constant());
  
#line 24119 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void testI_reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 24135 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 24149 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compU_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 24164 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 24172 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compU_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 24195 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      emit_d32(cbuf, opnd_array(2)->constant());
    }
  
#line 24210 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compU_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 24225 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 24239 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void testU_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 24254 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(1)->reg(ra_,this,idx1));
  
#line 24262 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compP_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 24277 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 24285 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compP_eReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1632 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Emit primary opcode and set sign-extend bit
    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_opcode(cbuf, (0x81 /*primary()*/) | 0x02);    }
    else {                          // If 32-bit immediate
      emit_opcode(cbuf, (0x81 /*primary()*/));
    }
    // Emit r/m byte with secondary opcode, after primary opcode.
    emit_rm(cbuf, 0x3, (0x07 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1));
  
#line 24308 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1644 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Check for 8-bit immediate, and set sign extend bit in opcode
    if ((opnd_array(2)->constant() >= -128) && (opnd_array(2)->constant() <= 127)) {
      emit_d8(cbuf, opnd_array(2)->constant());
    }
    else {                          // If 32-bit immediate
      // Output immediate
      
if ( opnd_array(2)->constant_is_oop() ) {
  emit_d32_reloc(cbuf, opnd_array(2)->constant(), relocInfo::oop_type, 0);
} else {
  emit_d32(cbuf, opnd_array(2)->constant());
};
    }
  
#line 24328 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compP_eReg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 24343 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 24357 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void compP_mem_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x3B /*primary()*/));
  
#line 24372 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(1)->reg(ra_,this,idx1);
    int base  = opnd_array(2)->base(ra_,this,idx2);
    int index = opnd_array(2)->index(ra_,this,idx2);
    int scale = opnd_array(2)->scale();
    int displace = opnd_array(2)->disp(ra_,this,idx2);
    bool disp_is_oop = opnd_array(2)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 24386 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void testP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 24401 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(1)->reg(ra_,this,idx1));
  
#line 24409 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void testP_Reg_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xF7 /*primary()*/));
  
#line 24424 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2153 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int rm_byte_opcode = (0x00);
    int base     = opnd_array(1)->base(ra_,this,idx1);
    int index    = opnd_array(1)->index(ra_,this,idx1);
    int scale    = opnd_array(1)->scale();
    int displace = opnd_array(1)->disp(ra_,this,idx1);
    bool disp_is_oop = opnd_array(1)->disp_is_oop(); // disp-as-oop when working with static globals
    encode_RegMem(cbuf, rm_byte_opcode, base, index, scale, displace, disp_is_oop);
  
#line 24438 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1996 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d32(cbuf,(0xFFFFFFFF));
  
#line 24446 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void minI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2173 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Compare dst,src
    emit_opcode(cbuf,0x3B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
    // jmp dst < src around move
    emit_opcode(cbuf,0x7C);
    emit_d8(cbuf,2);
    // move dst,src
    emit_opcode(cbuf,0x8B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 24469 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void maxI_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2185 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Compare dst,src
    emit_opcode(cbuf,0x3B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
    // jmp dst > src around move
    emit_opcode(cbuf,0x7F);
    emit_d8(cbuf,2);
    // move dst,src
    emit_opcode(cbuf,0x8B);
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2));
  
#line 24492 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void loopLimit_eRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
    unsigned idx5 = idx4 + opnd_array(4)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12343 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int strd = (int)opnd_array(3)->constant();
    assert(strd != 1 && strd != -1, "sanity");
    int m1 = (strd > 0) ? 1 : -1;
    // Convert limit to long (EAX:EDX)
    __ cdql();
    // Convert init to long (init:tmp)
    __ movl(opnd_array(5)->as_Register(ra_,this,idx5), opnd_array(1)->as_Register(ra_,this,idx1));
    __ sarl(opnd_array(5)->as_Register(ra_,this,idx5), 31);
    // $limit - $init
    __ subl(opnd_array(2)->as_Register(ra_,this,idx2), opnd_array(1)->as_Register(ra_,this,idx1));
    __ sbbl(opnd_array(4)->as_Register(ra_,this,idx4), opnd_array(5)->as_Register(ra_,this,idx5));
    // + ($stride - 1)
    if (strd > 0) {
      __ addl(opnd_array(2)->as_Register(ra_,this,idx2), (strd - 1));
      __ adcl(opnd_array(4)->as_Register(ra_,this,idx4), 0);
      __ movl(opnd_array(5)->as_Register(ra_,this,idx5), strd);
    } else {
      __ addl(opnd_array(2)->as_Register(ra_,this,idx2), (strd + 1));
      __ adcl(opnd_array(4)->as_Register(ra_,this,idx4), -1);
      __ lneg(opnd_array(4)->as_Register(ra_,this,idx4), opnd_array(2)->as_Register(ra_,this,idx2));
      __ movl(opnd_array(5)->as_Register(ra_,this,idx5), -strd);
    }
    // signed devision: (EAX:EDX) / pos_stride
    __ idivl(opnd_array(5)->as_Register(ra_,this,idx5));
    if (strd < 0) {
      // restore sign
      __ negl(opnd_array(5)->as_Register(ra_,this,idx5));
    }
    // (EAX) * stride
    __ mull(opnd_array(5)->as_Register(ra_,this,idx5));
    // + init (ignore upper bits)
    __ addl(opnd_array(2)->as_Register(ra_,this,idx2), opnd_array(1)->as_Register(ra_,this,idx1));
  
#line 24542 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void jumpXtndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  ra_->C->constant_table().fill_jump_table(cbuf, (MachConstantNode*) this, _index2label);
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 12387 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // Jump to Address(table_base + switch_reg)
    Address index(noreg, opnd_array(1)->as_Register(ra_,this,idx1), Address::times_1);
    __ jump(ArrayAddress(InternalAddress(__ code()->consts()->start() + constant_offset()), index));
  
#line 24560 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void jumpXtndNode::eval_constant(Compile* C) {
  _constant = C->constant_table().add_jump_table(this);
  // User did not define an encode section.
}
void jmpDirNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 12403 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(1)->label();
    __ jmp(*L, false); // Always long jump
  
#line 24580 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpDirNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 5, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 5);
}
void jmpConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12418 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 24602 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpConNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12433 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 24624 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpLoopEndNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpLoopEndUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12448 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 24646 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpLoopEndUNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpLoopEndUCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12462 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 24668 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpLoopEndUCFNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12477 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 24690 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpConUNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpConUCFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12491 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jcc((Assembler::Condition)(opnd_array(1)->ccode()), *L, false); // Always long jump
  
#line 24712 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpConUCFNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 6);
}
void jmpConUCF2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12513 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* l = opnd_array(3)->label();
    if (opnd_array(1)->ccode()== Assembler::notEqual) {
      __ jcc(Assembler::parity, *l, false);
      __ jcc(Assembler::notEqual, *l, false);
    } else if (opnd_array(1)->ccode()== Assembler::equal) {
      Label done;
      __ jccb(Assembler::parity, done);
      __ jcc(Assembler::equal, *l, false);
      __ bind(done);
    } else {
       ShouldNotReachHere();
    }
  
#line 24744 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1717 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Redi = as_Register(EDI_enc); // result register
    Register Reax = as_Register(EAX_enc); // super class
    Register Recx = as_Register(ECX_enc); // killed
    Register Resi = as_Register(ESI_enc); // sub class
    Label miss;

    MacroAssembler _masm(&cbuf);
    __ check_klass_subtype_slow_path(Resi, Reax, Recx, Redi,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
    if ((0x1 /*primary()*/)) {
      __ xorptr(Redi, Redi);
    }
    __ bind(miss);
  
#line 24772 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void partialSubtypeCheck_vs_ZeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 1717 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register Redi = as_Register(EDI_enc); // result register
    Register Reax = as_Register(EAX_enc); // super class
    Register Recx = as_Register(ECX_enc); // killed
    Register Resi = as_Register(ESI_enc); // sub class
    Label miss;

    MacroAssembler _masm(&cbuf);
    __ check_klass_subtype_slow_path(Resi, Reax, Recx, Redi,
                                     NULL, &miss,
                                     /*set_cond_codes:*/ true);
    if ((0x0 /*primary()*/)) {
      __ xorptr(Redi, Redi);
    }
    __ bind(miss);
  
#line 24801 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void jmpDir_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 12592 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(1)->label();
    __ jmpb(*L);
  
#line 24817 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpDir_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpCon_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12608 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 24839 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpCon_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpLoopEnd_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12624 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 24861 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpLoopEnd_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpLoopEndU_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12640 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 24883 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpLoopEndU_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpLoopEndUCF_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12655 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 24905 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpLoopEndUCF_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpConU_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12671 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 24927 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpConU_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpConUCF_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12686 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* L = opnd_array(3)->label();
    __ jccb((Assembler::Condition)(opnd_array(1)->ccode()), *L);
  
#line 24949 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpConUCF_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 2, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 2);
}
void jmpConUCF2_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12710 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label* l = opnd_array(3)->label();
    if (opnd_array(1)->ccode()== Assembler::notEqual) {
      __ jccb(Assembler::parity, *l);
      __ jccb(Assembler::notEqual, *l);
    } else if (opnd_array(1)->ccode()== Assembler::equal) {
      Label done;
      __ jccb(Assembler::parity, done);
      __ jccb(Assembler::equal, *l);
      __ bind(done);
    } else {
       ShouldNotReachHere();
    }
  
#line 24981 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  jmpConUCF2_shortNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 4);
}
void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 12766 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Label p_one, m_one, done;
    __ xorptr(opnd_array(0)->as_Register(ra_,this), opnd_array(0)->as_Register(ra_,this));
    __ cmpl(HIGH_FROM_LOW(opnd_array(1)->as_Register(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->as_Register(ra_,this,idx2)));
    __ jccb(Assembler::less,    m_one);
    __ jccb(Assembler::greater, p_one);
    __ cmpl(opnd_array(1)->as_Register(ra_,this,idx1), opnd_array(2)->as_Register(ra_,this,idx2));
    __ jccb(Assembler::below,   m_one);
    __ jccb(Assembler::equal,   done);
    __ bind(p_one);
    __ incrementl(opnd_array(0)->as_Register(ra_,this));
    __ jmpb(done);
    __ bind(m_one);
    __ decrementl(opnd_array(0)->as_Register(ra_,this));
    __ bind(done);
  
#line 25014 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpL_zero_flags_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0x85 /*primary()*/));
  
#line 25029 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
  
#line 25037 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpL_reg_flags_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2891 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CMP    $src1.lo,$src2.lo\t! Long compare; set flags for low bits
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2) );
    // MOV    $tmp,$src1.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
    // SBB   $tmp,$src2.hi\t! Compute flags for long compare
    emit_opcode( cbuf, 0x1B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)) );
  
#line 25061 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovLL_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25079 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1960 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25087 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25096 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)));
  
#line 25104 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovLL_mem_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25122 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25136 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25145 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3));  // Hi register of pair, computed from lo
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(4)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 25159 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovII_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25177 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25185 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovII_mem_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25203 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25217 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovPP_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25235 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25243 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpL_zero_flags_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2870 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // MOV   $tmp,$src.lo
    emit_opcode(cbuf, 0x8B);
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(1)->reg(ra_,this,idx1));
    // OR    $tmp,$src.hi
    emit_opcode(cbuf, 0x0B);
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)));
  
#line 25264 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpL_reg_flags_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 2879 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CMP    $src1.lo,$src2.lo
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(1)->reg(ra_,this,idx1), opnd_array(2)->reg(ra_,this,idx2) );
    // JNE,s  skip
    emit_cc(cbuf, 0x70, 0x5);
    emit_d8(cbuf,2);
    // CMP    $src1.hi,$src2.hi
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)) );
  
#line 25287 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovLL_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25305 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1960 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25313 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25322 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)));
  
#line 25330 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovLL_mem_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25348 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25362 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25371 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3));  // Hi register of pair, computed from lo
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(4)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 25385 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovII_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25403 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25411 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovII_mem_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25429 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25443 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovPP_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25461 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25469 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpL_zero_flags_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2903 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // XOR    $tmp,$tmp
    emit_opcode(cbuf,0x33);  // XOR
    emit_rm(cbuf,0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(3)->reg(ra_,this,idx3));
    // CMP    $tmp,$src.lo
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(1)->reg(ra_,this,idx1) );
    // SBB    $tmp,$src.hi
    emit_opcode( cbuf, 0x1B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
  
#line 25493 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpL_reg_flags_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 2891 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CMP    $src1.lo,$src2.lo\t! Long compare; set flags for low bits
    emit_opcode( cbuf, 0x3B );
    emit_rm(cbuf, 0x3, opnd_array(2)->reg(ra_,this,idx2), opnd_array(1)->reg(ra_,this,idx1) );
    // MOV    $tmp,$src1.hi
    emit_opcode( cbuf, 0x8B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(2)->reg(ra_,this,idx2)) );
    // SBB   $tmp,$src2.hi\t! Compute flags for long compare
    emit_opcode( cbuf, 0x1B );
    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), HIGH_FROM_LOW(opnd_array(1)->reg(ra_,this,idx1)) );
  
#line 25517 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovLL_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25535 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1960 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25543 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25552 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1964 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3)), HIGH_FROM_LOW(opnd_array(4)->reg(ra_,this,idx4)));
  
#line 25560 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovLL_mem_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25578 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25592 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25601 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2073 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = HIGH_FROM_LOW(opnd_array(3)->reg(ra_,this,idx3));  // Hi register of pair, computed from lo
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4) + 4;      // Offset is 4 further in memory
    assert( !opnd_array(4)->disp_is_oop(), "Cannot add 4 to oop" );
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, false/*disp_is_oop*/);
  
#line 25615 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovII_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25633 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25641 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovII_mem_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25659 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 2063 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    int reg_encoding = opnd_array(3)->reg(ra_,this,idx3);
    int base  = opnd_array(4)->base(ra_,this,idx4);
    int index = opnd_array(4)->index(ra_,this,idx4);
    int scale = opnd_array(4)->scale();
    int displace = opnd_array(4)->disp(ra_,this,idx4);
    bool disp_is_oop = opnd_array(4)->disp_is_oop();
    encode_RegMem(cbuf, reg_encoding, base, index, scale, displace, disp_is_oop);
  
#line 25673 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmovPP_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 1699 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_d8(cbuf, (0x0F /*primary()*/));
    emit_cc(cbuf, (0x40 /*secondary()*/), opnd_array(1)->ccode());
  
#line 25691 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1946 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, opnd_array(3)->reg(ra_,this,idx3), opnd_array(4)->reg(ra_,this,idx4));
  
#line 25699 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1793 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_FPU_size(), "correct size prediction");
  
#line 25720 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1812 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    if ( !_method ) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     runtime_call_Relocation::spec(), RELOC_IMM32 );
    } else if(_optimized_virtual) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     opt_virtual_call_Relocation::spec(), RELOC_IMM32 );
    } else {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     static_call_Relocation::spec(), RELOC_IMM32 );
    }
    if( _method ) {  // Emit stub for static call
      emit_java_to_interp(cbuf);
    }
  
#line 25744 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 90 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 25762 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1804 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 25774 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void CallStaticJavaHandleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1793 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_FPU_size(), "correct size prediction");
  
#line 25795 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 75 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    debug_only(int off0 = cbuf.insts_size());
    MacroAssembler _masm(&cbuf);
    // RBP is preserved across all calls, even compiled calls.
    // Use it to preserve RSP in places where the callee might change the SP.
    __ movptr(rbp_mh_SP_save, rsp);
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == preserve_SP_size(), "correct size prediction");
  
#line 25809 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1812 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    if ( !_method ) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     runtime_call_Relocation::spec(), RELOC_IMM32 );
    } else if(_optimized_virtual) {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     opt_virtual_call_Relocation::spec(), RELOC_IMM32 );
    } else {
      emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                     static_call_Relocation::spec(), RELOC_IMM32 );
    }
    if( _method ) {  // Emit stub for static call
      emit_java_to_interp(cbuf);
    }
  
#line 25833 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 85 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    MacroAssembler _masm(&cbuf);
    __ movptr(rsp, rbp_mh_SP_save);
  
#line 25842 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 90 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 25860 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1804 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 25872 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1793 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_FPU_size(), "correct size prediction");
  
#line 25893 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1832 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // !!!!!
    // Generate  "Mov EAX,0x00", placeholder instruction to load oop-info
    // emit_call_dynamic_prologue( cbuf );
    cbuf.set_insts_mark();
    emit_opcode(cbuf, 0xB8 + EAX_enc);        // mov    EAX,-1
    emit_d32_reloc(cbuf, (int)Universe::non_oop_word(), oop_Relocation::spec_for_immediate(), RELOC_IMM32);
    address  virtual_call_oop_addr = cbuf.insts_mark();
    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                virtual_call_Relocation::spec(virtual_call_oop_addr), RELOC_IMM32 );
  
#line 25913 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 90 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    if (VerifyStackAtCalls) {
      // Check that stack depth is unchanged: find majik cookie on stack
      int framesize = ra_->reg2offset_unchecked(OptoReg::add(ra_->_matcher._old_SP, -3*VMRegImpl::slots_per_word));
      MacroAssembler _masm(&cbuf);
      Label L;
      __ cmpptr(Address(rsp, framesize), (int32_t)0xbadb100d);
      __ jccb(Assembler::equal, L);
      // Die if stack mismatch
      __ int3();
      __ bind(L);
    }
  
#line 25931 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1804 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 25943 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1793 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_FPU_size(), "correct size prediction");
  
#line 25964 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1734 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler masm(&cbuf);
    int start = masm.offset();
    if (UseSSE >= 2) {
      if (VerifyFPU) {
        masm.verify_FPU(0, "must be empty in SSE2+ mode");
      }
    } else {
      // External c_calling_convention expects the FPU stack to be 'clean'.
      // Compiled code leaves it dirty.  Do cleanup now.
      masm.empty_FPU_stack();
    }
    if (sizeof_FFree_Float_Stack_All == -1) {
      sizeof_FFree_Float_Stack_All = masm.offset() - start;
    } else {
      assert(masm.offset() - start == sizeof_FFree_Float_Stack_All, "wrong size");
    }
  
#line 25987 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is the instruction starting address for relocation info.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    // CALL directly to the runtime
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                runtime_call_Relocation::spec(), RELOC_IMM32 );

    if (UseSSE >= 2) {
      MacroAssembler _masm(&cbuf);
      BasicType rt = tf()->return_type();

      if ((rt == T_FLOAT || rt == T_DOUBLE) && !return_value_is_used()) {
        // A C runtime call where the return value is unused.  In SSE2+
        // mode the result needs to be removed from the FPU stack.  It's
        // likely that this function call could be removed by the
        // optimizer if the C function is a pure function.
        __ ffree(0);
      } else if (rt == T_FLOAT) {
        __ lea(rsp, Address(rsp, -4));
        __ fstp_s(Address(rsp, 0));
        __ movflt(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  4));
      } else if (rt == T_DOUBLE) {
        __ lea(rsp, Address(rsp, -8));
        __ fstp_d(Address(rsp, 0));
        __ movdbl(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  8));
      }
    }
  
#line 26023 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1804 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 26035 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1793 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word restore it here
    debug_only(int off0 = cbuf.insts_size());
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_std()));
    }
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == pre_call_FPU_size(), "correct size prediction");
  
#line 26056 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1734 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    MacroAssembler masm(&cbuf);
    int start = masm.offset();
    if (UseSSE >= 2) {
      if (VerifyFPU) {
        masm.verify_FPU(0, "must be empty in SSE2+ mode");
      }
    } else {
      // External c_calling_convention expects the FPU stack to be 'clean'.
      // Compiled code leaves it dirty.  Do cleanup now.
      masm.empty_FPU_stack();
    }
    if (sizeof_FFree_Float_Stack_All == -1) {
      sizeof_FFree_Float_Stack_All = masm.offset() - start;
    } else {
      assert(masm.offset() - start == sizeof_FFree_Float_Stack_All, "wrong size");
    }
  
#line 26079 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is the instruction starting address for relocation info.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    // CALL directly to the runtime
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                runtime_call_Relocation::spec(), RELOC_IMM32 );

    if (UseSSE >= 2) {
      MacroAssembler _masm(&cbuf);
      BasicType rt = tf()->return_type();

      if ((rt == T_FLOAT || rt == T_DOUBLE) && !return_value_is_used()) {
        // A C runtime call where the return value is unused.  In SSE2+
        // mode the result needs to be removed from the FPU stack.  It's
        // likely that this function call could be removed by the
        // optimizer if the C function is a pure function.
        __ ffree(0);
      } else if (rt == T_FLOAT) {
        __ lea(rsp, Address(rsp, -4));
        __ fstp_s(Address(rsp, 0));
        __ movflt(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  4));
      } else if (rt == T_DOUBLE) {
        __ lea(rsp, Address(rsp, -8));
        __ fstp_d(Address(rsp, 0));
        __ movdbl(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  8));
      }
    }
  
#line 26115 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1753 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    if( VerifyFPU ) {
      MacroAssembler masm(&cbuf);
      masm.verify_FPU( -3, "Returning from Runtime Leaf call");
    }
  
#line 26126 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1804 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // If method sets FPU control word do it here also
    if( Compile::current()->in_24_bit_fp_mode() ) {
      MacroAssembler masm(&cbuf);
      masm.fldcw(ExternalAddress(StubRoutines::addr_fpu_cntrl_wrd_24()));
    }
  
#line 26138 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {

#line 1760 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is the instruction starting address for relocation info.
    cbuf.set_insts_mark();
    emit_d8(cbuf, (0xE8 /*primary()*/));
    // CALL directly to the runtime
    emit_d32_reloc(cbuf, (opnd_array(1)->method() - (int)(cbuf.insts_end()) - 4),
                runtime_call_Relocation::spec(), RELOC_IMM32 );

    if (UseSSE >= 2) {
      MacroAssembler _masm(&cbuf);
      BasicType rt = tf()->return_type();

      if ((rt == T_FLOAT || rt == T_DOUBLE) && !return_value_is_used()) {
        // A C runtime call where the return value is unused.  In SSE2+
        // mode the result needs to be removed from the FPU stack.  It's
        // likely that this function call could be removed by the
        // optimizer if the C function is a pure function.
        __ ffree(0);
      } else if (rt == T_FLOAT) {
        __ lea(rsp, Address(rsp, -4));
        __ fstp_s(Address(rsp, 0));
        __ movflt(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  4));
      } else if (rt == T_DOUBLE) {
        __ lea(rsp, Address(rsp, -8));
        __ fstp_d(Address(rsp, 0));
        __ movdbl(xmm0, Address(rsp, 0));
        __ lea(rsp, Address(rsp,  8));
      }
    }
  
#line 26180 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 5;
    unsigned idx1 = 5;
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xC3 /*primary()*/));
  
#line 26194 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 5;
    unsigned idx1 = 5;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 26209 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 26217 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void tailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 5;
    unsigned idx1 = 5;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {

#line 3462 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf,0x5A);
  
#line 26232 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_opcode(cbuf, (0xFF /*primary()*/));
  
#line 26240 "../generated/adfiles/ad_x86_32.cpp"
  }
  {

#line 1695 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    emit_rm(cbuf, 0x3, (0x4 /*secondary()*/), opnd_array(1)->reg(ra_,this,idx1) );
  
#line 26248 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  // User did not define which encode class to use.
}
uint  CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 0);
}
void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 5;
    unsigned idx1 = 5;
  {

#line 3466 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.set_insts_mark();
    emit_opcode(cbuf, 0xE9);        // jmp    entry
    emit_d32_reloc(cbuf, (int)OptoRuntime::rethrow_stub() - ((int)cbuf.insts_end())-4,
                   runtime_call_Relocation::spec(), RELOC_IMM32 );
  
#line 26276 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
    unsigned idx4 = idx3 + opnd_array(3)->num_edges();
  {

#line 3001 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"


    Register objReg = as_Register(opnd_array(1)->reg(ra_,this,idx1));
    Register boxReg = as_Register(opnd_array(2)->reg(ra_,this,idx2));
    Register tmpReg = as_Register(opnd_array(3)->reg(ra_,this,idx3));
    Register scrReg = as_Register(opnd_array(4)->reg(ra_,this,idx4));

    // Ensure the register assignents are disjoint
    guarantee (objReg != boxReg, "") ;
    guarantee (objReg != tmpReg, "") ;
    guarantee (objReg != scrReg, "") ;
    guarantee (boxReg != tmpReg, "") ;
    guarantee (boxReg != scrReg, "") ;
    guarantee (tmpReg == as_Register(EAX_enc), "") ;

    MacroAssembler masm(&cbuf);

    if (_counters != NULL) {
      masm.atomic_incl(ExternalAddress((address) _counters->total_entry_count_addr()));
    }
    if (EmitSync & 1) {
        // set box->dhw = unused_mark (3)
        // Force all sync thru slow-path: slow_enter() and slow_exit() 
        masm.movptr (Address(boxReg, 0), int32_t(markOopDesc::unused_mark())) ;             
        masm.cmpptr (rsp, (int32_t)0) ;                        
    } else 
    if (EmitSync & 2) { 
        Label DONE_LABEL ;           
        if (UseBiasedLocking) {
           // Note: tmpReg maps to the swap_reg argument and scrReg to the tmp_reg argument.
           masm.biased_locking_enter(boxReg, objReg, tmpReg, scrReg, false, DONE_LABEL, NULL, _counters);
        }

        masm.movptr(tmpReg, Address(objReg, 0)) ;          // fetch markword 
        masm.orptr (tmpReg, 0x1);
        masm.movptr(Address(boxReg, 0), tmpReg);           // Anticipate successful CAS 
        if (os::is_MP()) { masm.lock();  }
        masm.cmpxchgptr(boxReg, Address(objReg, 0));          // Updates tmpReg
        masm.jcc(Assembler::equal, DONE_LABEL);
        // Recursive locking
        masm.subptr(tmpReg, rsp);
        masm.andptr(tmpReg, (int32_t) 0xFFFFF003 );
        masm.movptr(Address(boxReg, 0), tmpReg);
        masm.bind(DONE_LABEL) ; 
    } else {  
      // Possible cases that we'll encounter in fast_lock 
      // ------------------------------------------------
      // * Inflated
      //    -- unlocked
      //    -- Locked
      //       = by self
      //       = by other
      // * biased
      //    -- by Self
      //    -- by other
      // * neutral
      // * stack-locked
      //    -- by self
      //       = sp-proximity test hits
      //       = sp-proximity test generates false-negative
      //    -- by other
      //

      Label IsInflated, DONE_LABEL, PopDone ;

      // TODO: optimize away redundant LDs of obj->mark and improve the markword triage
      // order to reduce the number of conditional branches in the most common cases.
      // Beware -- there's a subtle invariant that fetch of the markword
      // at [FETCH], below, will never observe a biased encoding (*101b).
      // If this invariant is not held we risk exclusion (safety) failure.
      if (UseBiasedLocking && !UseOptoBiasInlining) {
        masm.biased_locking_enter(boxReg, objReg, tmpReg, scrReg, false, DONE_LABEL, NULL, _counters);
      }

      masm.movptr(tmpReg, Address(objReg, 0)) ;         // [FETCH]
      masm.testptr(tmpReg, 0x02) ;                      // Inflated v (Stack-locked or neutral)
      masm.jccb  (Assembler::notZero, IsInflated) ;

      // Attempt stack-locking ...
      masm.orptr (tmpReg, 0x1);
      masm.movptr(Address(boxReg, 0), tmpReg);          // Anticipate successful CAS
      if (os::is_MP()) { masm.lock();  }
      masm.cmpxchgptr(boxReg, Address(objReg, 0));           // Updates tmpReg
      if (_counters != NULL) {
        masm.cond_inc32(Assembler::equal,
                        ExternalAddress((address)_counters->fast_path_entry_count_addr()));
      }
      masm.jccb (Assembler::equal, DONE_LABEL);

      // Recursive locking
      masm.subptr(tmpReg, rsp);
      masm.andptr(tmpReg, 0xFFFFF003 );
      masm.movptr(Address(boxReg, 0), tmpReg);
      if (_counters != NULL) {
        masm.cond_inc32(Assembler::equal,
                        ExternalAddress((address)_counters->fast_path_entry_count_addr()));
      }
      masm.jmp  (DONE_LABEL) ;

      masm.bind (IsInflated) ;

      // The object is inflated.
      //
      // TODO-FIXME: eliminate the ugly use of manifest constants:
      //   Use markOopDesc::monitor_value instead of "2".
      //   use markOop::unused_mark() instead of "3".
      // The tmpReg value is an objectMonitor reference ORed with
      // markOopDesc::monitor_value (2).   We can either convert tmpReg to an
      // objectmonitor pointer by masking off the "2" bit or we can just
      // use tmpReg as an objectmonitor pointer but bias the objectmonitor
      // field offsets with "-2" to compensate for and annul the low-order tag bit.
      //
      // I use the latter as it avoids AGI stalls.
      // As such, we write "mov r, [tmpReg+OFFSETOF(Owner)-2]"
      // instead of "mov r, [tmpReg+OFFSETOF(Owner)]".
      //
      #define OFFSET_SKEWED(f) ((ObjectMonitor::f ## _offset_in_bytes())-2)

      // boxReg refers to the on-stack BasicLock in the current frame.
      // We'd like to write:
      //   set box->_displaced_header = markOop::unused_mark().  Any non-0 value suffices.
      // This is convenient but results a ST-before-CAS penalty.  The following CAS suffers
      // additional latency as we have another ST in the store buffer that must drain.

      if (EmitSync & 8192) { 
         masm.movptr(Address(boxReg, 0), 3) ;            // results in ST-before-CAS penalty
         masm.get_thread (scrReg) ; 
         masm.movptr(boxReg, tmpReg);                    // consider: LEA box, [tmp-2] 
         masm.movptr(tmpReg, NULL_WORD);                 // consider: xor vs mov
         if (os::is_MP()) { masm.lock(); } 
         masm.cmpxchgptr(scrReg, Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2)) ; 
      } else 
      if ((EmitSync & 128) == 0) {                      // avoid ST-before-CAS
         masm.movptr(scrReg, boxReg) ; 
         masm.movptr(boxReg, tmpReg);                   // consider: LEA box, [tmp-2] 

         // Using a prefetchw helps avoid later RTS->RTO upgrades and cache probes
         if ((EmitSync & 2048) && VM_Version::supports_3dnow_prefetch() && os::is_MP()) {
            // prefetchw [eax + Offset(_owner)-2]
            masm.prefetchw(Address(rax, ObjectMonitor::owner_offset_in_bytes()-2));
         }

         if ((EmitSync & 64) == 0) {
           // Optimistic form: consider XORL tmpReg,tmpReg
           masm.movptr(tmpReg, NULL_WORD) ; 
         } else { 
           // Can suffer RTS->RTO upgrades on shared or cold $ lines
           // Test-And-CAS instead of CAS
           masm.movptr(tmpReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;   // rax, = m->_owner
           masm.testptr(tmpReg, tmpReg) ;                   // Locked ? 
           masm.jccb  (Assembler::notZero, DONE_LABEL) ;                   
         }

         // Appears unlocked - try to swing _owner from null to non-null.
         // Ideally, I'd manifest "Self" with get_thread and then attempt
         // to CAS the register containing Self into m->Owner.
         // But we don't have enough registers, so instead we can either try to CAS
         // rsp or the address of the box (in scr) into &m->owner.  If the CAS succeeds
         // we later store "Self" into m->Owner.  Transiently storing a stack address
         // (rsp or the address of the box) into  m->owner is harmless.
         // Invariant: tmpReg == 0.  tmpReg is EAX which is the implicit cmpxchg comparand.
         if (os::is_MP()) { masm.lock();  }
         masm.cmpxchgptr(scrReg, Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2)) ; 
         masm.movptr(Address(scrReg, 0), 3) ;          // box->_displaced_header = 3
         masm.jccb  (Assembler::notZero, DONE_LABEL) ; 
         masm.get_thread (scrReg) ;                    // beware: clobbers ICCs
         masm.movptr(Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2), scrReg) ; 
         masm.xorptr(boxReg, boxReg) ;                 // set icc.ZFlag = 1 to indicate success
                       
         // If the CAS fails we can either retry or pass control to the slow-path.  
         // We use the latter tactic.  
         // Pass the CAS result in the icc.ZFlag into DONE_LABEL
         // If the CAS was successful ...
         //   Self has acquired the lock
         //   Invariant: m->_recursions should already be 0, so we don't need to explicitly set it.
         // Intentional fall-through into DONE_LABEL ...
      } else {
         masm.movptr(Address(boxReg, 0), 3) ;       // results in ST-before-CAS penalty
         masm.movptr(boxReg, tmpReg) ; 

         // Using a prefetchw helps avoid later RTS->RTO upgrades and cache probes
         if ((EmitSync & 2048) && VM_Version::supports_3dnow_prefetch() && os::is_MP()) {
            // prefetchw [eax + Offset(_owner)-2]
            masm.prefetchw(Address(rax, ObjectMonitor::owner_offset_in_bytes()-2));
         }

         if ((EmitSync & 64) == 0) {
           // Optimistic form
           masm.xorptr  (tmpReg, tmpReg) ; 
         } else { 
           // Can suffer RTS->RTO upgrades on shared or cold $ lines
           masm.movptr(tmpReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;   // rax, = m->_owner
           masm.testptr(tmpReg, tmpReg) ;                   // Locked ? 
           masm.jccb  (Assembler::notZero, DONE_LABEL) ;                   
         }

         // Appears unlocked - try to swing _owner from null to non-null.
         // Use either "Self" (in scr) or rsp as thread identity in _owner.
         // Invariant: tmpReg == 0.  tmpReg is EAX which is the implicit cmpxchg comparand.
         masm.get_thread (scrReg) ;
         if (os::is_MP()) { masm.lock(); }
         masm.cmpxchgptr(scrReg, Address(boxReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;

         // If the CAS fails we can either retry or pass control to the slow-path.
         // We use the latter tactic.
         // Pass the CAS result in the icc.ZFlag into DONE_LABEL
         // If the CAS was successful ...
         //   Self has acquired the lock
         //   Invariant: m->_recursions should already be 0, so we don't need to explicitly set it.
         // Intentional fall-through into DONE_LABEL ...
      }

      // DONE_LABEL is a hot target - we'd really like to place it at the
      // start of cache line by padding with NOPs.
      // See the AMD and Intel software optimization manuals for the
      // most efficient "long" NOP encodings.
      // Unfortunately none of our alignment mechanisms suffice.
      masm.bind(DONE_LABEL);

      // Avoid branch-to-branch on AMD processors
      // This appears to be superstition.
      if (EmitSync & 32) masm.nop() ;


      // At DONE_LABEL the icc ZFlag is set as follows ...
      // Fast_Unlock uses the same protocol.
      // ZFlag == 1 -> Success
      // ZFlag == 0 -> Failure - force control through the slow-path
    }
  
#line 26520 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
    unsigned idx3 = idx2 + opnd_array(2)->num_edges();
  {

#line 3259 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"


    Register objReg = as_Register(opnd_array(1)->reg(ra_,this,idx1));
    Register boxReg = as_Register(opnd_array(2)->reg(ra_,this,idx2));
    Register tmpReg = as_Register(opnd_array(3)->reg(ra_,this,idx3));

    guarantee (objReg != boxReg, "") ;
    guarantee (objReg != tmpReg, "") ;
    guarantee (boxReg != tmpReg, "") ;
    guarantee (boxReg == as_Register(EAX_enc), "") ;
    MacroAssembler masm(&cbuf);

    if (EmitSync & 4) {
      // Disable - inhibit all inlining.  Force control through the slow-path
      masm.cmpptr (rsp, 0) ; 
    } else 
    if (EmitSync & 8) {
      Label DONE_LABEL ;
      if (UseBiasedLocking) {
         masm.biased_locking_exit(objReg, tmpReg, DONE_LABEL);
      }
      // classic stack-locking code ...
      masm.movptr(tmpReg, Address(boxReg, 0)) ;
      masm.testptr(tmpReg, tmpReg) ;
      masm.jcc   (Assembler::zero, DONE_LABEL) ;
      if (os::is_MP()) { masm.lock(); }
      masm.cmpxchgptr(tmpReg, Address(objReg, 0));          // Uses EAX which is box
      masm.bind(DONE_LABEL);
    } else {
      Label DONE_LABEL, Stacked, CheckSucc, Inflated ;

      // Critically, the biased locking test must have precedence over
      // and appear before the (box->dhw == 0) recursive stack-lock test.
      if (UseBiasedLocking && !UseOptoBiasInlining) {
         masm.biased_locking_exit(objReg, tmpReg, DONE_LABEL);
      }
      
      masm.cmpptr(Address(boxReg, 0), 0) ;            // Examine the displaced header
      masm.movptr(tmpReg, Address(objReg, 0)) ;       // Examine the object's markword
      masm.jccb  (Assembler::zero, DONE_LABEL) ;      // 0 indicates recursive stack-lock

      masm.testptr(tmpReg, 0x02) ;                     // Inflated? 
      masm.jccb  (Assembler::zero, Stacked) ;

      masm.bind  (Inflated) ;
      // It's inflated.
      // Despite our balanced locking property we still check that m->_owner == Self
      // as java routines or native JNI code called by this thread might
      // have released the lock.
      // Refer to the comments in synchronizer.cpp for how we might encode extra
      // state in _succ so we can avoid fetching EntryList|cxq.
      //
      // I'd like to add more cases in fast_lock() and fast_unlock() --
      // such as recursive enter and exit -- but we have to be wary of
      // I$ bloat, T$ effects and BP$ effects.
      //
      // If there's no contention try a 1-0 exit.  That is, exit without
      // a costly MEMBAR or CAS.  See synchronizer.cpp for details on how
      // we detect and recover from the race that the 1-0 exit admits.
      //
      // Conceptually Fast_Unlock() must execute a STST|LDST "release" barrier
      // before it STs null into _owner, releasing the lock.  Updates
      // to data protected by the critical section must be visible before
      // we drop the lock (and thus before any other thread could acquire
      // the lock and observe the fields protected by the lock).
      // IA32's memory-model is SPO, so STs are ordered with respect to
      // each other and there's no need for an explicit barrier (fence).
      // See also http://gee.cs.oswego.edu/dl/jmm/cookbook.html.

      masm.get_thread (boxReg) ;
      if ((EmitSync & 4096) && VM_Version::supports_3dnow_prefetch() && os::is_MP()) {
        // prefetchw [ebx + Offset(_owner)-2]
        masm.prefetchw(Address(rbx, ObjectMonitor::owner_offset_in_bytes()-2));
      }

      // Note that we could employ various encoding schemes to reduce
      // the number of loads below (currently 4) to just 2 or 3.
      // Refer to the comments in synchronizer.cpp.
      // In practice the chain of fetches doesn't seem to impact performance, however.
      if ((EmitSync & 65536) == 0 && (EmitSync & 256)) {
         // Attempt to reduce branch density - AMD's branch predictor.
         masm.xorptr(boxReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;  
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::recursions_offset_in_bytes()-2)) ;
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::EntryList_offset_in_bytes()-2)) ; 
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::cxq_offset_in_bytes()-2)) ; 
         masm.jccb  (Assembler::notZero, DONE_LABEL) ; 
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), NULL_WORD) ; 
         masm.jmpb  (DONE_LABEL) ; 
      } else { 
         masm.xorptr(boxReg, Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2)) ;  
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::recursions_offset_in_bytes()-2)) ;
         masm.jccb  (Assembler::notZero, DONE_LABEL) ; 
         masm.movptr(boxReg, Address (tmpReg, ObjectMonitor::EntryList_offset_in_bytes()-2)) ; 
         masm.orptr(boxReg, Address (tmpReg, ObjectMonitor::cxq_offset_in_bytes()-2)) ; 
         masm.jccb  (Assembler::notZero, CheckSucc) ; 
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), NULL_WORD) ; 
         masm.jmpb  (DONE_LABEL) ; 
      }

      // The Following code fragment (EmitSync & 65536) improves the performance of
      // contended applications and contended synchronization microbenchmarks.
      // Unfortunately the emission of the code - even though not executed - causes regressions
      // in scimark and jetstream, evidently because of $ effects.  Replacing the code
      // with an equal number of never-executed NOPs results in the same regression.
      // We leave it off by default.

      if ((EmitSync & 65536) != 0) {
         Label LSuccess, LGoSlowPath ;

         masm.bind  (CheckSucc) ;

         // Optional pre-test ... it's safe to elide this
         if ((EmitSync & 16) == 0) { 
            masm.cmpptr(Address (tmpReg, ObjectMonitor::succ_offset_in_bytes()-2), 0) ; 
            masm.jccb  (Assembler::zero, LGoSlowPath) ; 
         }

         // We have a classic Dekker-style idiom:
         //    ST m->_owner = 0 ; MEMBAR; LD m->_succ
         // There are a number of ways to implement the barrier:
         // (1) lock:andl &m->_owner, 0
         //     is fast, but mask doesn't currently support the "ANDL M,IMM32" form.
         //     LOCK: ANDL [ebx+Offset(_Owner)-2], 0
         //     Encodes as 81 31 OFF32 IMM32 or 83 63 OFF8 IMM8
         // (2) If supported, an explicit MFENCE is appealing.
         //     In older IA32 processors MFENCE is slower than lock:add or xchg
         //     particularly if the write-buffer is full as might be the case if
         //     if stores closely precede the fence or fence-equivalent instruction.
         //     In more modern implementations MFENCE appears faster, however.
         // (3) In lieu of an explicit fence, use lock:addl to the top-of-stack
         //     The $lines underlying the top-of-stack should be in M-state.
         //     The locked add instruction is serializing, of course.
         // (4) Use xchg, which is serializing
         //     mov boxReg, 0; xchgl boxReg, [tmpReg + Offset(_owner)-2] also works
         // (5) ST m->_owner = 0 and then execute lock:orl &m->_succ, 0.
         //     The integer condition codes will tell us if succ was 0.
         //     Since _succ and _owner should reside in the same $line and
         //     we just stored into _owner, it's likely that the $line
         //     remains in M-state for the lock:orl.
         //
         // We currently use (3), although it's likely that switching to (2)
         // is correct for the future.
            
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), NULL_WORD) ; 
         if (os::is_MP()) { 
            if (VM_Version::supports_sse2() && 1 == FenceInstruction) { 
              masm.mfence();
            } else { 
              masm.lock () ; masm.addptr(Address(rsp, 0), 0) ; 
            }
         }
         // Ratify _succ remains non-null
         masm.cmpptr(Address (tmpReg, ObjectMonitor::succ_offset_in_bytes()-2), 0) ; 
         masm.jccb  (Assembler::notZero, LSuccess) ; 

         masm.xorptr(boxReg, boxReg) ;                  // box is really EAX
         if (os::is_MP()) { masm.lock(); }
         masm.cmpxchgptr(rsp, Address(tmpReg, ObjectMonitor::owner_offset_in_bytes()-2));
         masm.jccb  (Assembler::notEqual, LSuccess) ;
         // Since we're low on registers we installed rsp as a placeholding in _owner.
         // Now install Self over rsp.  This is safe as we're transitioning from
         // non-null to non=null
         masm.get_thread (boxReg) ;
         masm.movptr(Address (tmpReg, ObjectMonitor::owner_offset_in_bytes()-2), boxReg) ;
         // Intentional fall-through into LGoSlowPath ...

         masm.bind  (LGoSlowPath) ; 
         masm.orptr(boxReg, 1) ;                      // set ICC.ZF=0 to indicate failure
         masm.jmpb  (DONE_LABEL) ; 

         masm.bind  (LSuccess) ; 
         masm.xorptr(boxReg, boxReg) ;                 // set ICC.ZF=1 to indicate success
         masm.jmpb  (DONE_LABEL) ; 
      }

      masm.bind (Stacked) ;
      // It's not inflated and it's not recursively stack-locked and it's not biased.
      // It must be stack-locked.
      // Try to reset the header to displaced header.
      // The "box" value on the stack is stable, so we can reload
      // and be assured we observe the same value as above.
      masm.movptr(tmpReg, Address(boxReg, 0)) ;
      if (os::is_MP()) {   masm.lock();    }
      masm.cmpxchgptr(tmpReg, Address(objReg, 0)); // Uses EAX which is box
      // Intention fall-thru into DONE_LABEL


      // DONE_LABEL is a hot target - we'd really like to place it at the
      // start of cache line by padding with NOPs.
      // See the AMD and Intel software optimization manuals for the
      // most efficient "long" NOP encodings.
      // Unfortunately none of our alignment mechanisms suffice.
      if ((EmitSync & 65536) == 0) {
         masm.bind (CheckSucc) ;
      }
      masm.bind(DONE_LABEL);

      // Avoid branch to branch on AMD processors
      if (EmitSync & 32768) { masm.nop() ; }
    }
  
#line 26734 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void safePoint_pollNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 5;
    unsigned idx1 = 5;
  {

#line 3654 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    cbuf.relocate(cbuf.insts_mark(), relocInfo::poll_type, 0);
    emit_opcode(cbuf,0x85);
    emit_rm (cbuf, 0x0, 0x7, 0x5);
    emit_d32(cbuf, (intptr_t)os::get_polling_page());
  
#line 26751 "../generated/adfiles/ad_x86_32.cpp"
  }
}
uint  safePoint_pollNode::size(PhaseRegAlloc *ra_) const {
 assert(VerifyOops || MachNode::size(ra_) <= 6, "bad fixed size");
 return (VerifyOops ? MachNode::size(ra_) : 6);
}
void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 13404 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    Register dstReg = as_Register(opnd_array(0)->reg(ra_,this));
    __ get_thread(dstReg);
  
#line 26771 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 5;
    unsigned idx1 = 5;
  {
    MacroAssembler _masm(&cbuf);

#line 113 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ int3();
  
#line 26786 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 127 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 26802 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 26818 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 139 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 26834 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 150 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 26850 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addF_immNode::eval_constant(Compile* C) {
  {

#line 151 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 26858 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 162 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 26874 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 174 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 26890 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 174 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 26906 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 186 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 26922 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddF_immNode::eval_constant(Compile* C) {
  {

#line 187 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 26930 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 198 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 26946 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 210 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 26962 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 210 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 26978 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 221 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ addsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 26994 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void addD_immNode::eval_constant(Compile* C) {
  {

#line 222 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27002 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 233 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27018 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 245 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27034 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 245 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 27050 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 257 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vaddsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27066 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vaddD_immNode::eval_constant(Compile* C) {
  {

#line 258 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27074 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 269 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27090 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 281 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27106 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 292 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27122 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subF_immNode::eval_constant(Compile* C) {
  {

#line 293 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27130 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 304 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27146 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 316 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27162 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 328 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27178 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubF_immNode::eval_constant(Compile* C) {
  {

#line 329 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27186 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 340 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27202 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 352 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27218 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 363 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ subsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27234 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void subD_immNode::eval_constant(Compile* C) {
  {

#line 364 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27242 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 375 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27258 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 387 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27274 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 399 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vsubsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27290 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vsubD_immNode::eval_constant(Compile* C) {
  {

#line 400 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27298 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 411 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27314 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 423 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27330 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 423 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 27346 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 434 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27362 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulF_immNode::eval_constant(Compile* C) {
  {

#line 435 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27370 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 446 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27386 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 458 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27402 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulF_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 458 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 27418 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 470 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27434 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulF_immNode::eval_constant(Compile* C) {
  {

#line 471 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27442 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 482 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27458 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27474 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 494 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 27490 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 505 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ mulsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27506 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void mulD_immNode::eval_constant(Compile* C) {
  {

#line 506 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27514 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 517 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27530 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 529 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27546 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulD_mem_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 529 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(2)->as_XMMRegister(ra_,this,idx2), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 27562 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 541 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vmulsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27578 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vmulD_immNode::eval_constant(Compile* C) {
  {

#line 542 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27586 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 553 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27602 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 565 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27618 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 576 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divss(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27634 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divF_immNode::eval_constant(Compile* C) {
  {

#line 577 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27642 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 588 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27658 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 600 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27674 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 612 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27690 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivF_immNode::eval_constant(Compile* C) {
  {

#line 613 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27698 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 624 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27714 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 636 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27730 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 647 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ divsd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27746 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void divD_immNode::eval_constant(Compile* C) {
  {

#line 648 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27754 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 659 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), opnd_array(2)->as_XMMRegister(ra_,this,idx2));
  
#line 27770 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 671 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), Address::make_raw(opnd_array(2)->base(ra_,this,idx2), opnd_array(2)->index(ra_,this,idx2), opnd_array(2)->scale(), opnd_array(2)->disp(ra_,this,idx2), opnd_array(2)->disp_is_oop()));
  
#line 27786 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
    unsigned idx2 = idx1 + opnd_array(1)->num_edges();
  {
    MacroAssembler _masm(&cbuf);

#line 683 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vdivsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27802 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vdivD_immNode::eval_constant(Compile* C) {
  {

#line 684 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(2));
#line 27810 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 694 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ andps(opnd_array(1)->as_XMMRegister(ra_,this,idx1), ExternalAddress(float_signmask()));
  
#line 27825 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vabsF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 705 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vandps(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1),
              ExternalAddress(float_signmask()));
  
#line 27841 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 718 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ andpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), ExternalAddress(double_signmask()));
  
#line 27856 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vabsD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 730 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vandpd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1),
              ExternalAddress(double_signmask()));
  
#line 27872 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void negF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 742 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorps(opnd_array(1)->as_XMMRegister(ra_,this,idx1), ExternalAddress(float_signflip()));
  
#line 27887 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vnegF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 753 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vxorps(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1),
              ExternalAddress(float_signflip()));
  
#line 27903 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void negD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 766 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ xorpd(opnd_array(1)->as_XMMRegister(ra_,this,idx1), ExternalAddress(double_signflip()));
  
#line 27918 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void vnegD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 778 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ vxorpd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1),
              ExternalAddress(double_signflip()));
  
#line 27934 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 791 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
  
#line 27949 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtF_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 803 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 27964 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtF_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 814 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtss(opnd_array(0)->as_XMMRegister(ra_,this), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 27979 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtF_immNode::eval_constant(Compile* C) {
  {

#line 815 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 27987 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 826 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this), opnd_array(1)->as_XMMRegister(ra_,this,idx1));
  
#line 28002 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtD_memNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 2;
    unsigned idx1 = 2;
  {
    MacroAssembler _masm(&cbuf);

#line 838 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this), Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_is_oop()));
  
#line 28017 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtD_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
    // Start at oper_input_base() and count operands
    unsigned idx0 = 1;
    unsigned idx1 = 1;
  {
    MacroAssembler _masm(&cbuf);

#line 849 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"

    __ sqrtsd(opnd_array(0)->as_XMMRegister(ra_,this), InternalAddress(__ code()->consts()->start() + constant_offset()));
  
#line 28032 "../generated/adfiles/ad_x86_32.cpp"
  }
}
void sqrtD_immNode::eval_constant(Compile* C) {
  {

#line 850 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86.ad"
    _constant = C->constant_table().add(this, opnd_array(1));
#line 28040 "../generated/adfiles/ad_x86_32.cpp"
  }
}
const MachOper* popCountI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* popCountL_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_immI8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_immI16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2UBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2SNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2USNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_65535Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLX_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLX_reg_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_partialNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadA8BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadA4SNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadA4CNode::memory_operand() const { return _opnds[1]; }
const MachOper* load2IUNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadA2FNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchr0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrT0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrT2Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchw0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchwNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchwNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAlloc0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocNTANode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocT0Node::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAllocT2Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL2INode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLX_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLX_reg_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmI16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmPNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeA8BNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeA4CNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeA2INode::memory_operand() const { return _opnds[1]; }
const MachOper* storeImmCMNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDPR_roundedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeA2FNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPRNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPR_roundedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPR_DroundedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFPR_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeF_immNode::memory_operand() const { return _opnds[1]; }
const TypePtr *membar_acquireNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquireNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_acquire_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquire_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_releaseNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_releaseNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_release_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_release_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_storestoreNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_storestoreNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* cmovI_memNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovI_memUNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovI_memUCFNode::memory_operand() const { return _opnds[4]; }
const MachOper* addI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* incI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* decI_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLLockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLX_LockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLX_reg_LockedNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeIConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLConditionalNode::memory_operand() const { return _opnds[1]; }
const MachOper* subI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* mulI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* mulINode::memory_operand() const { return _opnds[2]; }
const MachOper* mulI_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* sarI_mem_1Node::memory_operand() const { return _opnds[1]; }
const MachOper* sarI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* andI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* andI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* orI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* orI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* xorI_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_eRegNode::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_eReg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorI_mem_immNode::memory_operand() const { return _opnds[1]; }
const MachOper* addL_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addL_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* subL_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andL_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* andL_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* orl_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* orl_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* xorl_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* xorl_eReg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* cmpD_ccmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpD_ccmemCFNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpD_regmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* subDPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addDPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addDPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addDPR_mem_regNode::memory_operand() const { return _opnds[1]; }
const MachOper* addDPR_mem_reg_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulDPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulDPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulDPR_reg_mem_ciscNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulDPR_reg_mem_cisc_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* cmpF_ccmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpF_ccmemCFNode::memory_operand() const { return _opnds[2]; }
const MachOper* cmpF_regmemNode::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR24_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR24_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addFPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addFPR24_mem_regNode::memory_operand() const { return _opnds[1]; }
const TypePtr *addFPR24_mem_ciscNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* addFPR24_mem_ciscNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *addFPR24_mem_cisc_0Node::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* addFPR24_mem_cisc_0Node::memory_operand() const { return (MachOper*)-1; }
const TypePtr *addFPR24_mem_memNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* addFPR24_mem_memNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* mulFPR24_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulFPR24_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulFPR_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulFPR_reg_mem_0Node::memory_operand() const { return _opnds[1]; }
const TypePtr *mulFPR24_mem_memNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* mulFPR24_mem_memNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* mulFPR_reg_load1Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulFPR_reg_load1_0Node::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_mulFPR_reg_load1Node::memory_operand() const { return _opnds[1]; }
const MachOper* addFPR_mulFPR_reg_load1_1Node::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_mulFPR_reg_load1_0Node::memory_operand() const { return _opnds[2]; }
const MachOper* addFPR_mulFPR_reg_load1_2Node::memory_operand() const { return _opnds[3]; }
const MachOper* convI2D_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2DPR_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2FPR_SSF_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* convI2FPR_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* compI_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* testI_reg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compU_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compP_eReg_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* compP_mem_eRegNode::memory_operand() const { return _opnds[2]; }
const MachOper* testP_Reg_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* cmovLL_mem_LTGENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovII_mem_LTGENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovLL_mem_EQNENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovII_mem_EQNENode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovLL_mem_LEGTNode::memory_operand() const { return _opnds[4]; }
const MachOper* cmovII_mem_LEGTNode::memory_operand() const { return _opnds[4]; }
const MachOper* addF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* vaddF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vaddF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* addD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* addD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* vaddD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vaddD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* subF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsubF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* subD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vsubD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* vmulF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmulF_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* mulD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* mulD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* vmulD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vmulD_mem_0Node::memory_operand() const { return _opnds[1]; }
const MachOper* divF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdivF_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* divD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* vdivD_memNode::memory_operand() const { return _opnds[2]; }
const MachOper* sqrtF_memNode::memory_operand() const { return _opnds[1]; }
const MachOper* sqrtD_memNode::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // RegFlags
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    false,  // AbsI
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    true ,  // AryEq
    true ,  // AtanD
    true ,  // Binary
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // CProj
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastII
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    true ,  // CMoveF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    false,  // CMoveN
    false,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    false,  // CompareAndSwapN
    false,  // Con
    false,  // ConN
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    true ,  // CosD
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    false,  // DecodeN
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    true ,  // DivModI
    false,  // DivModL
    false,  // EncodeP
    true ,  // ExpD
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // Goto
    true ,  // Halt
    true ,  // If
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    true ,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    false,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadUI2L
    true ,  // LoadKlass
    false,  // LoadNKlass
    true ,  // LoadL
    false,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadLLocked
    true ,  // LoadP
    false,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    true ,  // LogD
    true ,  // Log10D
    false,  // Loop
    true ,  // LoopLimit
    false,  // Mach
    false,  // MachProj
    true ,  // MaxI
    true ,  // MemBarAcquire
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    true ,  // ModD
    true ,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    false,  // MulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    false,  // Opaque1
    false,  // Opaque2
    true ,  // OrI
    true ,  // OrL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    true ,  // PowD
    true ,  // PrefetchAllocation
    true ,  // PrefetchRead
    true ,  // PrefetchWrite
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    true ,  // RoundDouble
    true ,  // RoundFloat
    true ,  // SafePoint
    false,  // SafePointScalarObject
    false,  // SCMemProj
    true ,  // SinD
    true ,  // SqrtD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    true ,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    false,  // StoreN
    true ,  // StrComp
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    true ,  // TanD
    true ,  // ThreadLocal
    false,  // Unlock
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    false,  // AddVB
    false,  // AddVC
    false,  // AddVS
    false,  // AddVI
    false,  // AddVL
    false,  // AddVF
    false,  // AddVD
    false,  // SubVB
    false,  // SubVC
    false,  // SubVS
    false,  // SubVI
    false,  // SubVL
    false,  // SubVF
    false,  // SubVD
    false,  // MulVF
    false,  // MulVD
    false,  // DivVF
    false,  // DivVD
    false,  // LShiftVB
    false,  // LShiftVC
    false,  // LShiftVS
    false,  // LShiftVI
    false,  // URShiftVB
    false,  // URShiftVC
    false,  // URShiftVS
    false,  // URShiftVI
    false,  // AndV
    false,  // OrV
    false,  // XorV
    false,  // VectorLoad
    false,  // Load16B
    true ,  // Load8B
    false,  // Load4B
    false,  // Load8C
    true ,  // Load4C
    false,  // Load2C
    false,  // Load8S
    true ,  // Load4S
    false,  // Load2S
    false,  // Load4I
    true ,  // Load2I
    false,  // Load2L
    false,  // Load4F
    true ,  // Load2F
    false,  // Load2D
    false,  // VectorStore
    false,  // Store16B
    true ,  // Store8B
    false,  // Store4B
    false,  // Store8C
    true ,  // Store4C
    false,  // Store2C
    false,  // Store4I
    true ,  // Store2I
    false,  // Store2L
    false,  // Store4F
    true ,  // Store2F
    false,  // Store2D
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackC
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2x1B
    false,  // Pack2x2B
    false,  // Replicate16B
    true ,  // Replicate8B
    false,  // Replicate4B
    false,  // Replicate8S
    true ,  // Replicate4S
    false,  // Replicate2S
    false,  // Replicate8C
    true ,  // Replicate4C
    false,  // Replicate2C
    false,  // Replicate4I
    true ,  // Replicate2I
    false,  // Replicate2L
    false,  // Replicate4F
    true ,  // Replicate2F
    false,  // Replicate2D
    false,  // Extract
    false,  // ExtractB
    false,  // ExtractS
    false,  // ExtractC
    false,  // ExtractI
    false,  // ExtractL
    false,  // ExtractF
    false   // ExtractD
};


bool Matcher::stack_direction() const { return false; }

int Compile::sync_stack_slots() const { return 1; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 1 +
              round_to((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::in_preserve_stack_slots() { return 2+VerifyStackAtCalls; }

uint Compile::out_preserve_stack_slots() { return SharedRuntime::out_preserve_stack_slots(); }

uint Compile::varargs_C_out_slots_killed() const { return 0; }

void Matcher::calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length, bool is_outgoing) {

#line 3770 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // No difference between ingoing/outgoing just pass false
    SharedRuntime::java_calling_convention(sig_bt, regs, length, false);
  
#line 28619 "../generated/adfiles/ad_x86_32.cpp"

}

void Matcher::c_calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length) {

#line 3782 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    // This is obviously always outgoing
    (void) SharedRuntime::c_calling_convention(sig_bt, regs, length);
  
#line 28630 "../generated/adfiles/ad_x86_32.cpp"

}

OptoRegPair Matcher::return_value(int ideal_reg, bool is_outgoing) {

#line 3804 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    assert( ideal_reg >= Op_RegI && ideal_reg <= Op_RegL, "only return normal values" );
    static int lo[Op_RegL+1] = { 0, 0, OptoReg::Bad, EAX_num,      EAX_num,      FPR1L_num,    FPR1L_num, EAX_num };
    static int hi[Op_RegL+1] = { 0, 0, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, FPR1H_num, EDX_num };
    if( ideal_reg == Op_RegD && UseSSE>=2 )
      return OptoRegPair(XMM0b_num,XMM0a_num);
    if( ideal_reg == Op_RegF && UseSSE>=1 )
      return OptoRegPair(OptoReg::Bad,XMM0a_num);
    return OptoRegPair(hi[ideal_reg],lo[ideal_reg]);
  
#line 28647 "../generated/adfiles/ad_x86_32.cpp"

}

OptoRegPair Matcher::c_return_value(int ideal_reg, bool is_outgoing) {

#line 3788 "/builddir/build/BUILD/java-1.7.0-openjdk/openjdk/hotspot/src/cpu/x86/vm/x86_32.ad"

    assert( ideal_reg >= Op_RegI && ideal_reg <= Op_RegL, "only return normal values" );
    static int lo[Op_RegL+1] = { 0, 0, OptoReg::Bad, EAX_num,      EAX_num,      FPR1L_num,    FPR1L_num, EAX_num };
    static int hi[Op_RegL+1] = { 0, 0, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, FPR1H_num, EDX_num };

    // in SSE2+ mode we want to keep the FPU stack clean so pretend
    // that C functions return float and double results in XMM0.
    if( ideal_reg == Op_RegD && UseSSE>=2 )
      return OptoRegPair(XMM0b_num,XMM0a_num);
    if( ideal_reg == Op_RegF && UseSSE>=2 )
      return OptoRegPair(OptoReg::Bad,XMM0a_num);

    return OptoRegPair(hi[ideal_reg],lo[ideal_reg]);
  
#line 28668 "../generated/adfiles/ad_x86_32.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(EAX_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_method_oop_reg() { return OptoReg::Name(EBX_num); }

int Matcher::interpreter_method_oop_reg_encode() { return _regEncode[interpreter_method_oop_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(EBP_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(ESP_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DIA32=1
#ifndef IA32
#  error "IA32 must be defined"
#endif // IA32
// Check adlc -U_LP64
#ifdef _LP64
#  error "_LP64 must not be defined"
#endif // _LP64
